/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.51 from the
 * contents of Label.xs. Do not edit this file, edit Label.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "Label.xs"
    /*
    ###########################################################################
    # (@)PACKAGE:Win32::GUI::Label
    #
    # $Id: Label.xs,v 1.7 2006/01/11 21:26:16 robertemay Exp $
    #
    ###########################################################################
    */

#include "GUI.h"

void Label_onPreCreate(NOTXSPROC LPPERLWIN32GUI_CREATESTRUCT perlcs) {

    perlcs->cs.lpszClass = "STATIC";
    perlcs->cs.style = WS_VISIBLE | WS_CHILD | SS_LEFT;
}

BOOL
Label_onParseOption(NOTXSPROC char *option, SV* value, LPPERLWIN32GUI_CREATESTRUCT perlcs) {

    BOOL retval = TRUE;
    
    if(strcmp(option, "-align") == 0) {
        if(strcmp(SvPV_nolen(value), "left") == 0) {
            SwitchBit(perlcs->cs.style, SS_LEFT, 1);
            SwitchBit(perlcs->cs.style, SS_CENTER, 0);
            SwitchBit(perlcs->cs.style, SS_RIGHT, 0);
        } else if(strcmp(SvPV_nolen(value), "center") == 0) {
            SwitchBit(perlcs->cs.style, SS_LEFT, 0);
            SwitchBit(perlcs->cs.style, SS_CENTER, 1);
            SwitchBit(perlcs->cs.style, SS_RIGHT, 0);
        } else if(strcmp(SvPV_nolen(value), "right") == 0) {
            SwitchBit(perlcs->cs.style, SS_LEFT, 0);
            SwitchBit(perlcs->cs.style, SS_CENTER, 0);
            SwitchBit(perlcs->cs.style, SS_RIGHT, 1);
        } else {
            W32G_WARN("Win32::GUI: Invalid value for -align!");
        }
    } else if(strcmp(option, "-bitmap") == 0 || strcmp(option, "-picture") == 0) {
        SwitchBit(perlcs->cs.style, SS_BITMAP, 1);
        perlcs->hImageList = (HIMAGELIST) handle_From(NOTXSCALL value);
    } else if(strcmp(option, "-icon") == 0 ) {
        SwitchBit(perlcs->cs.style, SS_ICON, 1);
        perlcs->hImageList = (HIMAGELIST) handle_From(NOTXSCALL value);
    } else if(strcmp(option, "-truncate") == 0) {
        if(strcmp(SvPV_nolen(value), "path") == 0) {
			perlcs->cs.style &= ~SS_ELLIPSISMASK;
			perlcs->cs.style |= SS_PATHELLIPSIS;
        } else if(strcmp(SvPV_nolen(value), "word") == 0) {
			perlcs->cs.style &= ~SS_ELLIPSISMASK;
			perlcs->cs.style |= SS_WORDELLIPSIS;
        } else if(SvIV(value)) {
			perlcs->cs.style &= ~SS_ELLIPSISMASK;
			perlcs->cs.style |= SS_ENDELLIPSIS;
        } else {
			perlcs->cs.style &= ~SS_ELLIPSISMASK;
        }
    } else if(strcmp(option, "-frame") == 0) {
        if(strcmp(SvPV_nolen(value), "black") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKFRAME, 1);
            SwitchBit(perlcs->cs.style, SS_GRAYFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_WHITEFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_ETCHEDFRAME, 0);
        } else if(strcmp(SvPV_nolen(value), "gray") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYFRAME, 1);
            SwitchBit(perlcs->cs.style, SS_WHITEFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_ETCHEDFRAME, 0);
        } else if(strcmp(SvPV_nolen(value), "white") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_WHITEFRAME, 1);
            SwitchBit(perlcs->cs.style, SS_ETCHEDFRAME, 0);
        } else if(strcmp(SvPV_nolen(value), "etched") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_WHITEFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_ETCHEDFRAME, 1);
        } else {
            SwitchBit(perlcs->cs.style, SS_BLACKFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_WHITEFRAME, 0);
            SwitchBit(perlcs->cs.style, SS_ETCHEDFRAME, 0);
        }
    } else if(strcmp(option, "-fill") == 0) {
        if(strcmp(SvPV_nolen(value), "black") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKRECT, 1);
            SwitchBit(perlcs->cs.style, SS_GRAYRECT, 0);
            SwitchBit(perlcs->cs.style, SS_WHITERECT, 0);
        } else if(strcmp(SvPV_nolen(value), "gray") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKRECT, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYRECT, 1);
            SwitchBit(perlcs->cs.style, SS_WHITERECT, 0);
        } else if(strcmp(SvPV_nolen(value), "white") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKRECT, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYRECT, 0);
            SwitchBit(perlcs->cs.style, SS_WHITERECT, 1);
        } else if(strcmp(SvPV_nolen(value), "etched") == 0) {
            SwitchBit(perlcs->cs.style, SS_BLACKRECT, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYRECT, 0);
            SwitchBit(perlcs->cs.style, SS_WHITERECT, 0);
        } else {
            SwitchBit(perlcs->cs.style, SS_BLACKRECT, 0);
            SwitchBit(perlcs->cs.style, SS_GRAYRECT, 0);
            SwitchBit(perlcs->cs.style, SS_WHITERECT, 0);
        }
    } else if(strcmp(option, "-wrap") == 0) {
        if(SvIV(value)) {
            SwitchBit(perlcs->cs.style, SS_LEFTNOWORDWRAP, 0);
        } else {
            SwitchBit(perlcs->cs.style, SS_LEFTNOWORDWRAP, 1);
        }
    } else if BitmaskOptionValue("-sunken",   perlcs->cs.style, SS_SUNKEN)
    } else if BitmaskOptionValue("-notify",   perlcs->cs.style, SS_NOTIFY)
    } else if BitmaskOptionValue("-simple",   perlcs->cs.style, SS_SIMPLE)
    } else if BitmaskOptionValue("-noprefix", perlcs->cs.style, SS_NOPREFIX)
    } else retval = FALSE;

    return retval;
}

void
Label_onPostCreate(NOTXSPROC HWND myhandle, LPPERLWIN32GUI_CREATESTRUCT perlcs) {

    if(perlcs->hImageList != NULL) {
        if((perlcs->cs.style & SS_ICON) == SS_ICON)
            SendMessage(myhandle, STM_SETIMAGE, (WPARAM) IMAGE_ICON, (LPARAM) perlcs->hImageList);
        else
            SendMessage(myhandle, STM_SETIMAGE, (WPARAM) IMAGE_BITMAP, (LPARAM) perlcs->hImageList);
    }
}

BOOL
Label_onParseEvent(NOTXSPROC char *name, int* eventID) {

    BOOL retval = TRUE;

         if Parse_Event("DblClick",   PERLWIN32GUI_NEM_DBLCLICK)
    else if Parse_Event("Click",      PERLWIN32GUI_NEM_CLICK)
    else if Parse_Event("Anonymous",  PERLWIN32GUI_NEM_CONTROL1)
    else if Parse_Event("Enable",     PERLWIN32GUI_NEM_CONTROL2)
    else retval = FALSE;

    return retval;
}

int
Label_onEvent (NOTXSPROC LPPERLWIN32GUI_USERDATA perlud, UINT uMsg, WPARAM wParam, LPARAM lParam) {

    int PerlResult = 1;

    if ( uMsg == WM_COMMAND ) {
        switch(HIWORD(wParam)) {
        case STN_CLICKED:
            /*
             * (@)EVENT:Click()
             * (@)APPLIES_TO:Label
             */
            PerlResult = DoEvent(NOTXSCALL perlud, PERLWIN32GUI_NEM_CLICK, "Click", -1 );
            break;
        case STN_DBLCLK:
            /*
             * (@)EVENT:DblClick()
             * (@)APPLIES_TO:Label
             */
            PerlResult = DoEvent(NOTXSCALL perlud, PERLWIN32GUI_NEM_DBLCLICK, "DblClick", -1 );
            break;
        case STN_DISABLE:
        case STN_ENABLE:
            /*
             * (@)EVENT:Enable(State)
             * Sent when the enable state Label change.
             * (@)APPLIES_TO:Label
             */ 
            PerlResult = DoEvent(NOTXSCALL perlud, PERLWIN32GUI_NEM_CONTROL2, "Enable", 
                                 PERLWIN32GUI_ARGTYPE_INT, (HIWORD(wParam) == STN_ENABLE),
                                 -1 );
        default:
            PerlResult = DoEvent(NOTXSCALL perlud, PERLWIN32GUI_NEM_CONTROL1, "Anonymous", 
                PERLWIN32GUI_ARGTYPE_INT, HIWORD(wParam),
                -1 );
            break;
        }  
    }    
    return PerlResult;
}


#line 199 "Label.c"
#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#line 343 "Label.c"
#pragma message( "*** PACKAGE Win32::GUI::Label..." )

XS_EUPXS(XS_Win32__GUI__Label_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__Label_GetIcon)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "handle");
    {
	HWND	handle;
	LRESULT	RETVAL;
	dXSTARG;

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HWND,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HWND,SvIV(ST(0)))
;
#line 204 "Label.xs"
    RETVAL = SendMessage(handle, STM_GETICON, 0, 0);
#line 368 "Label.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Win32__GUI__Label_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__Label_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "handle, icon");
    {
	HWND	handle;
	HICON	icon;
	LRESULT	RETVAL;
	dXSTARG;

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HWND,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HWND,SvIV(ST(0)))
;

    if(SvROK(ST(1))) {
        SV** out=hv_fetch((HV*)SvRV(ST(1)), "-handle", 7, 0);
        if(out != NULL)
            icon = INT2PTR(HICON,SvIV(*out));
        else
            icon = NULL;
    } else
       icon = INT2PTR(HICON,SvIV(ST(1)))
;
#line 217 "Label.xs"
    RETVAL = SendMessage(handle, STM_SETICON, (WPARAM) icon, 0);
#line 409 "Label.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Win32__GUI__Label_GetImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__Label_GetImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "handle, type");
    {
	HWND	handle;
	WPARAM	type = (WPARAM)SvUV(ST(1))
;
	LRESULT	RETVAL;
	dXSTARG;

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HWND,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HWND,SvIV(ST(0)))
;
#line 231 "Label.xs"
    RETVAL = SendMessage(handle, STM_GETIMAGE, type, 0);
#line 441 "Label.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Win32__GUI__Label_SetImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__Label_SetImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "handle, icon");
    {
	HWND	handle;
	HICON	icon;
	LRESULT	RETVAL;
	dXSTARG;

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HWND,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HWND,SvIV(ST(0)))
;

    if(SvROK(ST(1))) {
        SV** out=hv_fetch((HV*)SvRV(ST(1)), "-handle", 7, 0);
        if(out != NULL)
            icon = INT2PTR(HICON,SvIV(*out));
        else
            icon = NULL;
    } else
       icon = INT2PTR(HICON,SvIV(ST(1)))
;
#line 245 "Label.xs"
    WPARAM type = IMAGE_BITMAP;
    if (sv_isobject(ST(1))) {
        if (sv_derived_from(ST(1), "Win32::GUI::Icon"))
            type = IMAGE_ICON;
        else if (sv_derived_from(ST(1), "Win32::GUI::Cursor"))
            type = IMAGE_CURSOR;
    }    
    RETVAL = SendMessage(handle, STM_SETIMAGE, type, (LPARAM) icon);
#line 489 "Label.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#ifdef __cplusplus
extern "C" {
#endif
XS_EXTERNAL(boot_Win32__GUI__Label); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Win32__GUI__Label)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Win32::GUI::Label::GetIcon", XS_Win32__GUI__Label_GetIcon);
        newXS_deffile("Win32::GUI::Label::SetIcon", XS_Win32__GUI__Label_SetIcon);
        newXS_deffile("Win32::GUI::Label::GetImage", XS_Win32__GUI__Label_GetImage);
        newXS_deffile("Win32::GUI::Label::SetImage", XS_Win32__GUI__Label_SetImage);
#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

#ifdef __cplusplus
}
#endif
