/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.51 from the
 * contents of DropFiles.xs. Do not edit this file, edit DropFiles.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "DropFiles.xs"
#define WIN32_MEAN_AND_LEAN

/* XS code for Win32::GUI::DropFiles
 * $Id: DropFiles.xs,v 1.1 2006/04/25 21:38:18 robertemay Exp $
 * (c) Robert May, 2006
 * Released under the same terms as Perl
 */

#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#include "ppport.h"

#include "windows.h"
#include "shellapi.h"

/* void newSVpvnW(SV* s, WCHAR* w, UINT c)
 *  - s [OUT] pointer to SV. Will be set to point to a newly created SV,
 *    with ref count 1.
 *  - w [IN]  pointer to WCHAR buffer.
 *  - c [IN]  number of characters (NOT bytes) to be copied from WCHAR.  Do
 *    not include any NULL termination. If c = -1, then length will be
 *    calculated, assuming w is NULL terminated.
 */
/* TODO: This macro probably better written as a function that returns the
 * pointer to the SV, and it is more 'perl like' if c==0 indicates the length
 * should be calculated. It would be good to get rid of the duplicated SvPVX() calls.
 */
#define newSVpvnW(s, w, c) \
    { UINT b = WideCharToMultiByte(CP_UTF8, 0, w, c, NULL, 0, NULL, NULL); \
      s = newSV(b); SvPOK_on(s); SvUTF8_on(s); SvCUR_set(s,b); \
      WideCharToMultiByte(CP_UTF8, 0, w, c, SvPVX(s), b, NULL, NULL); \
      *(SvPVX(s) + b) = 0; sv_utf8_downgrade(s, 1); }

/* BOOL INVALID_HANDLE(HDROP h)
 * Attempt to determine if a HDROP handle is valid
 * Returns TRUE  if handle is invalid
 * Returns FALSE if handle is valid
 * TODO: can we do better than this?
 */
BOOL INVALID_HANDLE(HDROP h) {
    if(GlobalLock((HGLOBAL)h)) {
        GlobalUnlock((HGLOBAL)h);
        return 0;
    }
    return 1;
}

#ifndef W32G_NO_WIN9X
/* BOOL IsWin9X()
 * Returns TRUE  if OS Version is Win95/98/ME
 * Returns FLASE if OS Version is NT/2K/XP/2003 or higher
 */
/* TODO: Better to cache the value to prevent the overhead of
 * GetVersion() on each call.  Eventually this needs extracting
 * somewhere central, so that we don't have repeat implementations
 * all over the place.  ??Can we efficiently access the Win32::IsWin95
 * function??
 */
BOOL IsWin9X() {
    return (GetVersion() & 0x80000000);
}
#endif

#line 76 "DropFiles.c"
#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#line 220 "DropFiles.c"

XS_EUPXS(XS_Win32__GUI__DropFiles_DragQueryFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__DropFiles_DragQueryFile)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "handle, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	HDROP	handle;
#line 76 "DropFiles.xs"
    UINT count, item, cch;
    SV* sv;
#line 235 "DropFiles.c"

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HDROP,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HDROP,SvIV(ST(0)))
;
#line 79 "DropFiles.xs"
    /* Shell32.dll crashes if we pass an invalid handle
     * to DragQueryFile, so ensure we have one
     */
    if(INVALID_HANDLE(handle)) {
        SetLastError(ERROR_INVALID_HANDLE); /* set $^E */
        errno = EINVAL;                     /* set $! */
        XSRETURN_UNDEF;                     /* and return undef */
    }
#ifndef W32G_NO_WIN9X
    if(IsWin9X())
        count = DragQueryFileA(handle, 0xFFFFFFFF, NULL, 0);
    else
#endif
        count = DragQueryFileW(handle, 0xFFFFFFFF, NULL, 0);

    if(items == 1) {
        mXPUSHu(count);
        XSRETURN(1);
    } else if (items == 2) {
        item = (UINT)SvIV(ST(1));
        if(item < count) {  /* item is in range */
#ifndef W32G_NO_WIN9X
            if(IsWin9X()) {
                CHAR buffer[MAX_PATH];

                cch = DragQueryFileA(handle, item, buffer, MAX_PATH);
                sv = newSVpvn(buffer,cch);
            } else {
#endif
                WCHAR wbuffer[MAX_PATH];

                cch = DragQueryFileW(handle, item, wbuffer, MAX_PATH);
                newSVpvnW(sv, wbuffer, cch);
#ifndef W32G_NO_WIN9X
            }
#endif
            XPUSHs(sv_2mortal(sv));
            XSRETURN(1);
        } else {                               /* item is out of range */
            SetLastError(ERROR_INVALID_INDEX); /* set $^E */
            errno = EINVAL;                    /* set $! */
            XSRETURN_UNDEF;                    /* and return undef */
        }
    } else {
        croak("Usage: DragQueryHandle(handle);\n   or: DragQueryHandle(handle, index);");
    }
#line 293 "DropFiles.c"
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Win32__GUI__DropFiles_DragQueryPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__DropFiles_DragQueryPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "handle");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	HDROP	handle;
#line 132 "DropFiles.xs"
    POINT pt;
    UV client;
#line 313 "DropFiles.c"

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HDROP,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HDROP,SvIV(ST(0)))
;
#line 135 "DropFiles.xs"
    /* DragQueryPoint returns garbage if passed
     * an invalid handle, so ensure we have one
     */
    if(INVALID_HANDLE(handle)) {
        SetLastError(ERROR_INVALID_HANDLE); /* set $^E */
        errno = EINVAL;                     /* set $! */
        XSRETURN_UNDEF;                     /* and return undef */
    }
    client = (UV)DragQueryPoint(handle, &pt);
    mXPUSHi(pt.x);
    mXPUSHi(pt.y);
    mXPUSHu(client);
    XSRETURN(3);
#line 338 "DropFiles.c"
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Win32__GUI__DropFiles_DragFinish); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Win32__GUI__DropFiles_DragFinish)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "handle");
    {
	HDROP	handle;

    if(SvROK(ST(0))) {
        SV** out=hv_fetch((HV*)SvRV(ST(0)), "-handle", 7, 0);
        if(out != NULL)
            handle = INT2PTR(HDROP,SvIV(*out));
        else
            handle = NULL;
    } else
       handle = INT2PTR(HDROP,SvIV(ST(0)))
;

	DragFinish(handle);
    }
    XSRETURN_EMPTY;
}

#ifdef __cplusplus
extern "C" {
#endif
XS_EXTERNAL(boot_Win32__GUI__DropFiles); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Win32__GUI__DropFiles)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        (void)newXSproto_portable("Win32::GUI::DropFiles::DragQueryFile", XS_Win32__GUI__DropFiles_DragQueryFile, file, "$;@");
        (void)newXSproto_portable("Win32::GUI::DropFiles::DragQueryPoint", XS_Win32__GUI__DropFiles_DragQueryPoint, file, "$");
        (void)newXSproto_portable("Win32::GUI::DropFiles::DragFinish", XS_Win32__GUI__DropFiles_DragFinish, file, "$");
#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

#ifdef __cplusplus
}
#endif
