/* phash.inc written by Constants.PL
 * at Sun Aug 18 09:04:33 2024.
 * Changes here will be lost, edit
 * Constants.PL instead
 *
 * Provides the hash definition and
 * lookup functions required by
 * the Win32::GUI::Constants XS code.
 */

/* some useful defines */
#define PHASHLEN   512  /* length of hash mapping table */
#define PHASHNKEYS 2031  /* How many keys were hashed */
#define PHASHRANGE 2048  /* Range any input might map to */
#define PHASHSALT 0x60fcfe57 /* internal, initialize normal hash */

/* phash calculation table */
static const USHORT tab[] = {
  1689,1689,1140,1151,1432,83,281,0,0,0,333,1791,1777,1140,1042,1892,
  1312,1613,2023,665,1453,630,0,913,894,1107,2014,525,1312,1095,721,1966,
  1823,1140,1481,1338,1042,323,1699,764,620,1481,1550,1550,1749,1042,1849,1312,
  629,823,0,1613,1232,1892,323,1044,1042,1042,351,111,764,764,988,440,
  0,1689,1295,668,0,1044,1312,1193,1636,2038,403,1048,517,1689,1654,1140,
  988,728,374,83,197,1639,1218,897,764,764,764,1399,1920,1550,340,764,
  1140,1140,1064,567,1922,823,1550,2014,1689,180,823,764,83,1042,1878,764,
  0,1165,1654,733,1636,1203,2038,1822,1822,1699,665,323,1550,1550,1550,517,
  0,0,1869,558,711,1108,4,336,829,428,211,528,443,159,0,83,
  64,281,0,1550,323,988,1140,146,1550,764,1204,884,2014,215,3,1636,
  553,1746,206,6,1519,1699,702,517,11,1759,1975,1050,1541,333,323,605,
  323,1550,864,525,11,1140,0,1432,592,1140,764,764,212,373,1140,83,
  1042,1636,1042,2014,702,605,1020,1552,1027,1204,665,2014,665,0,558,787,
  517,764,1140,11,1586,0,1140,1020,1019,1042,1379,1896,293,1839,2038,1213,
  1636,1089,1549,1791,517,605,745,1338,0,1689,1140,1550,1213,281,0,764,
  1105,605,1519,140,1689,1140,10,785,281,1042,1044,0,1443,1550,1513,197,
  1550,1044,1764,629,307,1140,323,1839,506,891,1240,0,1689,764,668,1189,
  684,281,1213,764,1550,1757,629,823,1591,1834,83,1896,940,1966,1949,1550,
  1480,1109,864,151,728,630,1849,1140,1550,1453,1481,988,605,333,932,1312,
  764,764,348,427,894,1140,764,508,629,83,988,1140,1232,327,451,1312,
  924,1550,764,665,163,1654,517,11,885,1896,0,508,1116,1738,1510,764,
  83,1140,76,1044,1295,303,721,665,896,11,1885,1169,1654,2014,821,1951,
  924,1896,0,721,2038,315,1645,1655,1331,793,1092,281,288,288,0,1473,
  2014,265,746,747,764,1549,348,1530,83,1109,323,764,1654,11,1550,83,
  1900,1042,1218,869,1678,1550,83,1925,1654,1195,898,1105,1044,765,287,988,
  62,1869,281,174,473,528,1301,1042,1869,703,1638,1295,271,1550,244,970,
  1664,1791,1050,1202,764,1218,1934,1689,1672,1074,746,2014,968,1639,0,1900,
  1836,1218,1990,271,0,1263,1307,1091,2016,1119,698,1689,1481,894,83,1426,
  691,111,0,1044,654,302,1560,305,6,684,1576,11,313,528,1959,265,
  1042,577,1165,702,1240,281,1639,11,440,1550,1645,1312,623,1713,858,1140,
  1603,1312,1203,665,517,1287,281,323,1165,856,353,1855,976,1484,714,553,
  578,1217,643,1519,288,577,1042,1151,1671,824,1103,605,552,0,1791,917,
};

/* constant names string table */
struct stringpool_t {
  CHAR str0[sizeof("CDRF_NEWFONT")];
  CHAR str1[sizeof("WM_IME_COMPOSITION")];
  CHAR str2[sizeof("WM_NCXBUTTONUP")];
  CHAR str3[sizeof("LR_COPYDELETEORG")];
  CHAR str4[sizeof("WS_VSCROLL")];
  CHAR str5[sizeof("BDR_OUTER")];
  CHAR str6[sizeof("VK_T")];
  CHAR str7[sizeof("ILD_MASK")];
  CHAR str8[sizeof("OPAQUE")];
  CHAR str9[sizeof("TBSTYLE_TRANSPARENT")];
  CHAR str10[sizeof("GA_ROOT")];
  CHAR str11[sizeof("HWND_TOPMOST")];
  CHAR str12[sizeof("VK_OEM_COMMA")];
  CHAR str13[sizeof("WM_MOUSELAST")];
  CHAR str14[sizeof("DTS_LONGDATEFORMAT")];
  CHAR str15[sizeof("ENM_OBJECTPOSITIONS")];
  CHAR str16[sizeof("DT_CALCRECT")];
  CHAR str17[sizeof("PATCOPY")];
  CHAR str18[sizeof("ILD_PRESERVEALPHA")];
  CHAR str19[sizeof("RDW_VALIDATE")];
  CHAR str20[sizeof("LVS_EX_REGIONAL")];
  CHAR str21[sizeof("COLOR_BTNSHADOW")];
  CHAR str22[sizeof("TBSTATE_CHECKED")];
  CHAR str23[sizeof("VK_F18")];
  CHAR str24[sizeof("ICON_SMALL")];
  CHAR str25[sizeof("TBSTYLE_FLAT")];
  CHAR str26[sizeof("CBS_DISABLENOSCROLL")];
  CHAR str27[sizeof("TTM_GETCURRENTTOOL")];
  CHAR str28[sizeof("IDI_WINLOGO")];
  CHAR str29[sizeof("LB_GETITEMDATA")];
  CHAR str30[sizeof("IDC_HAND")];
  CHAR str31[sizeof("RDW_ERASENOW")];
  CHAR str32[sizeof("FLOODFILLBORDER")];
  CHAR str33[sizeof("MB_OK")];
  CHAR str34[sizeof("TVHT_ONITEMBUTTON")];
  CHAR str35[sizeof("BS_PUSHLIKE")];
  CHAR str36[sizeof("HTMENU")];
  CHAR str37[sizeof("PS_SOLID")];
  CHAR str38[sizeof("WS_POPUP")];
  CHAR str39[sizeof("DFCS_ADJUSTRECT")];
  CHAR str40[sizeof("IDC_SIZENESW")];
  CHAR str41[sizeof("GA_ROOTOWNER")];
  CHAR str42[sizeof("NULL_PEN")];
  CHAR str43[sizeof("WM_USER")];
  CHAR str44[sizeof("MB_ICONERROR")];
  CHAR str45[sizeof("OBJ_DC")];
  CHAR str46[sizeof("VK_HANGEUL")];
  CHAR str47[sizeof("WM_NCACTIVATE")];
  CHAR str48[sizeof("WM_MDIREFRESHMENU")];
  CHAR str49[sizeof("WM_NULL")];
  CHAR str50[sizeof("TBSTYLE_SEP")];
  CHAR str51[sizeof("SM_CYSIZE")];
  CHAR str52[sizeof("WM_WININICHANGE")];
  CHAR str53[sizeof("SM_NETWORK")];
  CHAR str54[sizeof("CDRF_NOTIFYPOSTERASE")];
  CHAR str55[sizeof("BF_LEFT")];
  CHAR str56[sizeof("TRANSPARENT")];
  CHAR str57[sizeof("VK_ATTN")];
  CHAR str58[sizeof("OBM_MNARROW")];
  CHAR str59[sizeof("HTLEFT")];
  CHAR str60[sizeof("EM_GETWORDBREAKPROC")];
  CHAR str61[sizeof("TPM_VERPOSANIMATION")];
  CHAR str62[sizeof("CF_TEXT")];
  CHAR str63[sizeof("WM_THEMECHANGED")];
  CHAR str64[sizeof("LB_SETTOPINDEX")];
  CHAR str65[sizeof("PBM_SETRANGE32")];
  CHAR str66[sizeof("LB_INSERTSTRING")];
  CHAR str67[sizeof("MF_GRAYED")];
  CHAR str68[sizeof("MB_DEFBUTTON2")];
  CHAR str69[sizeof("TVGN_PARENT")];
  CHAR str70[sizeof("HTBOTTOM")];
  CHAR str71[sizeof("VK_SELECT")];
  CHAR str72[sizeof("STN_DISABLE")];
  CHAR str73[sizeof("PS_ENDCAP_MASK")];
  CHAR str74[sizeof("WA_ACTIVE")];
  CHAR str75[sizeof("ILS_GLOW")];
  CHAR str76[sizeof("WS_EX_CONTROLPARENT")];
  CHAR str77[sizeof("IDB_VIEW_LARGE_COLOR")];
  CHAR str78[sizeof("LB_MULTIPLEADDSTRING")];
  CHAR str79[sizeof("WS_TILEDWINDOW")];
  CHAR str80[sizeof("ODA_SELECT")];
  CHAR str81[sizeof("SM_MEDIACENTER")];
  CHAR str82[sizeof("COLOR_APPWORKSPACE")];
  CHAR str83[sizeof("MB_DEFAULT_DESKTOP_ONLY")];
  CHAR str84[sizeof("LR_MONOCHROME")];
  CHAR str85[sizeof("MF_SYSMENU")];
  CHAR str86[sizeof("SC_MONITORPOWER")];
  CHAR str87[sizeof("CS_VREDRAW")];
  CHAR str88[sizeof("EM_CHARFROMPOS")];
  CHAR str89[sizeof("MERGECOPY")];
  CHAR str90[sizeof("TTF_RTLREADING")];
  CHAR str91[sizeof("SWP_SHOWWINDOW")];
  CHAR str92[sizeof("WM_NCMOUSEHOVER")];
  CHAR str93[sizeof("WS_EX_TRANSPARENT")];
  CHAR str94[sizeof("WS_EX_CONTEXTHELP")];
  CHAR str95[sizeof("LVS_EX_BORDERSELECT")];
  CHAR str96[sizeof("CSIDL_DESKTOPDIRECTORY")];
  CHAR str97[sizeof("LR_LOADMAP3DCOLORS")];
  CHAR str98[sizeof("HTREDUCE")];
  CHAR str99[sizeof("LVIS_ACTIVATING")];
  CHAR str100[sizeof("OIC_QUES")];
  CHAR str101[sizeof("TVHT_TOLEFT")];
  CHAR str102[sizeof("VK_CLEAR")];
  CHAR str103[sizeof("ENM_SCROLL")];
  CHAR str104[sizeof("IDCANCEL")];
  CHAR str105[sizeof("HS_DIAGCROSS")];
  CHAR str106[sizeof("CF_LOCALE")];
  CHAR str107[sizeof("LBN_SELCHANGE")];
  CHAR str108[sizeof("GWL_EXSTYLE")];
  CHAR str109[sizeof("GW_HWNDPREV")];
  CHAR str110[sizeof("ES_UPPERCASE")];
  CHAR str111[sizeof("COLOR_INFOBK")];
  CHAR str112[sizeof("CDRF_NOTIFYSUBITEMDRAW")];
  CHAR str113[sizeof("LB_GETLISTBOXINFO")];
  CHAR str114[sizeof("WM_DESTROYCLIPBOARD")];
  CHAR str115[sizeof("R2_MASKPEN")];
  CHAR str116[sizeof("TA_MASK")];
  CHAR str117[sizeof("NOMIRRORBITMAP")];
  CHAR str118[sizeof("PBM_SETBARCOLOR")];
  CHAR str119[sizeof("SM_SERVERR2")];
  CHAR str120[sizeof("GCW_ATOM")];
  CHAR str121[sizeof("CSIDL_FLAG_NO_ALIAS")];
  CHAR str122[sizeof("WS_MINIMIZEBOX")];
  CHAR str123[sizeof("LB_DIR")];
  CHAR str124[sizeof("LVIR_LABEL")];
  CHAR str125[sizeof("EM_GETHANDLE")];
  CHAR str126[sizeof("WS_BORDER")];
  CHAR str127[sizeof("GT_RAWTEXT")];
  CHAR str128[sizeof("PS_USERSTYLE")];
  CHAR str129[sizeof("WM_MOUSEFIRST")];
  CHAR str130[sizeof("LVS_OWNERDRAWFIXED")];
  CHAR str131[sizeof("SM_DEBUG")];
  CHAR str132[sizeof("VK_BROWSER_STOP")];
  CHAR str133[sizeof("CB_GETLBTEXT")];
  CHAR str134[sizeof("DFCS_CAPTIONRESTORE")];
  CHAR str135[sizeof("CSIDL_FONTS")];
  CHAR str136[sizeof("TTF_TRANSPARENT")];
  CHAR str137[sizeof("TBSTYLE_TOOLTIPS")];
  CHAR str138[sizeof("SC_NEXTWINDOW")];
  CHAR str139[sizeof("SF_TEXT")];
  CHAR str140[sizeof("CWP_ALL")];
  CHAR str141[sizeof("SWP_NOZORDER")];
  CHAR str142[sizeof("LR_SHARED")];
  CHAR str143[sizeof("EM_UNDO")];
  CHAR str144[sizeof("OBM_COMBO")];
  CHAR str145[sizeof("MCS_NOTODAY")];
  CHAR str146[sizeof("STN_CLICKED")];
  CHAR str147[sizeof("SM_MOUSEPRESENT")];
  CHAR str148[sizeof("SM_CXFRAME")];
  CHAR str149[sizeof("SC_SCREENSAVE")];
  CHAR str150[sizeof("SC_TASKLIST")];
  CHAR str151[sizeof("CBS_OEMCONVERT")];
  CHAR str152[sizeof("SC_HSCROLL")];
  CHAR str153[sizeof("LVS_NOSORTHEADER")];
  CHAR str154[sizeof("BDR_SUNKENINNER")];
  CHAR str155[sizeof("TVGN_NEXT")];
  CHAR str156[sizeof("WM_COPY")];
  CHAR str157[sizeof("LVS_EX_SIMPLESELECT")];
  CHAR str158[sizeof("LVS_EX_UNDERLINECOLD")];
  CHAR str159[sizeof("WM_APPCOMMAND")];
  CHAR str160[sizeof("TVGN_ROOT")];
  CHAR str161[sizeof("EN_KILLFOCUS")];
  CHAR str162[sizeof("OBJ_BITMAP")];
  CHAR str163[sizeof("BTNS_SEP")];
  CHAR str164[sizeof("TTF_DI_SETITEM")];
  CHAR str165[sizeof("CSIDL_MYPICTURES")];
  CHAR str166[sizeof("EDGE_SUNKEN")];
  CHAR str167[sizeof("CP_MACCP")];
  CHAR str168[sizeof("LBS_OWNERDRAWVARIABLE")];
  CHAR str169[sizeof("WS_HSCROLL")];
  CHAR str170[sizeof("WM_SETICON")];
  CHAR str171[sizeof("SM_CYFULLSCREEN")];
  CHAR str172[sizeof("CF_DSPENHMETAFILE")];
  CHAR str173[sizeof("WS_EX_NOPARENTNOTIFY")];
  CHAR str174[sizeof("SC_ARRANGE")];
  CHAR str175[sizeof("SM_CYCAPTION")];
  CHAR str176[sizeof("VK_MEDIA_PLAY_PAUSE")];
  CHAR str177[sizeof("BS_AUTOCHECKBOX")];
  CHAR str178[sizeof("NM_CUSTOMDRAW")];
  CHAR str179[sizeof("SBS_SIZEBOXBOTTOMRIGHTALIGN")];
  CHAR str180[sizeof("CSIDL_COMMON_TEMPLATES")];
  CHAR str181[sizeof("OBM_RESTORED")];
  CHAR str182[sizeof("TTM_SETTIPBKCOLOR")];
  CHAR str183[sizeof("SBT_OWNERDRAW")];
  CHAR str184[sizeof("CSIDL_HISTORY")];
  CHAR str185[sizeof("VK_F12")];
  CHAR str186[sizeof("WM_MBUTTONUP")];
  CHAR str187[sizeof("BTNS_NOPREFIX")];
  CHAR str188[sizeof("TTM_SETTIPTEXTCOLOR")];
  CHAR str189[sizeof("WM_MDIRESTORE")];
  CHAR str190[sizeof("EM_SETWORDBREAKPROC")];
  CHAR str191[sizeof("DFCS_BUTTONRADIOIMAGE")];
  CHAR str192[sizeof("OBJ_METAFILE")];
  CHAR str193[sizeof("MB_USERICON")];
  CHAR str194[sizeof("BM_SETSTYLE")];
  CHAR str195[sizeof("OEM_FIXED_FONT")];
  CHAR str196[sizeof("CB_DIR")];
  CHAR str197[sizeof("HINST_COMMCTRL")];
  CHAR str198[sizeof("TTM_GETTEXT")];
  CHAR str199[sizeof("CB_GETLOCALE")];
  CHAR str200[sizeof("TVGN_PREVIOUS")];
  CHAR str201[sizeof("LB_INITSTORAGE")];
  CHAR str202[sizeof("SBM_SETRANGE")];
  CHAR str203[sizeof("TTM_ADDTOOL")];
  CHAR str204[sizeof("SB_PAGEUP")];
  CHAR str205[sizeof("LB_SELITEMRANGE")];
  CHAR str206[sizeof("MB_SETFOREGROUND")];
  CHAR str207[sizeof("PBM_GETRANGE")];
  CHAR str208[sizeof("CF_ENHMETAFILE")];
  CHAR str209[sizeof("SB_BOTTOM")];
  CHAR str210[sizeof("EM_LINEINDEX")];
  CHAR str211[sizeof("CB_RESETCONTENT")];
  CHAR str212[sizeof("VK_F24")];
  CHAR str213[sizeof("ES_WANTRETURN")];
  CHAR str214[sizeof("VK_OEM_FJ_MASSHOU")];
  CHAR str215[sizeof("SM_CXCURSOR")];
  CHAR str216[sizeof("WS_EX_LAYOUTRTL")];
  CHAR str217[sizeof("WM_KEYUP")];
  CHAR str218[sizeof("SB_THUMBPOSITION")];
  CHAR str219[sizeof("NM_RCLICK")];
  CHAR str220[sizeof("TVHT_ONITEMSTATEICON")];
  CHAR str221[sizeof("BCM_GETIMAGELIST")];
  CHAR str222[sizeof("CSIDL_COMMON_STARTMENU")];
  CHAR str223[sizeof("ICON_BIG")];
  CHAR str224[sizeof("WS_ICONIC")];
  CHAR str225[sizeof("DFCS_MENUARROWRIGHT")];
  CHAR str226[sizeof("VK_OEM_CUSEL")];
  CHAR str227[sizeof("ODT_STATIC")];
  CHAR str228[sizeof("ENM_REQUESTRESIZE")];
  CHAR str229[sizeof("EN_PAGECHANGE")];
  CHAR str230[sizeof("DFCS_SCROLLDOWN")];
  CHAR str231[sizeof("WM_SIZECLIPBOARD")];
  CHAR str232[sizeof("ODT_LISTVIEW")];
  CHAR str233[sizeof("VK_K")];
  CHAR str234[sizeof("TTM_ADJUSTRECT")];
  CHAR str235[sizeof("EN_STOPNOUNDO")];
  CHAR str236[sizeof("RBBS_FIXEDBMP")];
  CHAR str237[sizeof("MB_DEFBUTTON4")];
  CHAR str238[sizeof("SM_PENWINDOWS")];
  CHAR str239[sizeof("WS_GROUP")];
  CHAR str240[sizeof("VK_2")];
  CHAR str241[sizeof("BS_3STATE")];
  CHAR str242[sizeof("WM_LBUTTONDBLCLK")];
  CHAR str243[sizeof("DLGC_WANTMESSAGE")];
  CHAR str244[sizeof("EM_CANUNDO")];
  CHAR str245[sizeof("COLOR_HIGHLIGHTTEXT")];
  CHAR str246[sizeof("PBM_SETMARQUEE")];
  CHAR str247[sizeof("OCR_CROSS")];
  CHAR str248[sizeof("STRETCH_HALFTONE")];
  CHAR str249[sizeof("SF_UNICODE")];
  CHAR str250[sizeof("SBT_RTLREADING")];
  CHAR str251[sizeof("COLOR_INACTIVECAPTIONTEXT")];
  CHAR str252[sizeof("VK_CANCEL")];
  CHAR str253[sizeof("SIZE_MAXHIDE")];
  CHAR str254[sizeof("WM_POWER")];
  CHAR str255[sizeof("RDW_INTERNALPAINT")];
  CHAR str256[sizeof("GT_SELECTION")];
  CHAR str257[sizeof("VK_TAB")];
  CHAR str258[sizeof("WM_SYSCHAR")];
  CHAR str259[sizeof("SM_DBCSENABLED")];
  CHAR str260[sizeof("IDIGNORE")];
  CHAR str261[sizeof("EDGE_RAISED")];
  CHAR str262[sizeof("EN_MSGFILTER")];
  CHAR str263[sizeof("VK_LWIN")];
  CHAR str264[sizeof("VK_KANA")];
  CHAR str265[sizeof("ODS_NOFOCUSRECT")];
  CHAR str266[sizeof("DS_ABSALIGN")];
  CHAR str267[sizeof("DC_BRUSH")];
  CHAR str268[sizeof("SM_CXBORDER")];
  CHAR str269[sizeof("WM_NCLBUTTONUP")];
  CHAR str270[sizeof("OBJ_PAL")];
  CHAR str271[sizeof("WM_TIMER")];
  CHAR str272[sizeof("HTERROR")];
  CHAR str273[sizeof("OCR_HAND")];
  CHAR str274[sizeof("TA_CENTER")];
  CHAR str275[sizeof("HTRIGHT")];
  CHAR str276[sizeof("VK_OEM_7")];
  CHAR str277[sizeof("OCR_NORMAL")];
  CHAR str278[sizeof("BF_DIAGONAL_ENDBOTTOMRIGHT")];
  CHAR str279[sizeof("IDC_SIZEALL")];
  CHAR str280[sizeof("ICON_SMALL2")];
  CHAR str281[sizeof("LBS_DISABLENOSCROLL")];
  CHAR str282[sizeof("CB_SETEDITSEL")];
  CHAR str283[sizeof("SE_ERR_ASSOCINCOMPLETE")];
  CHAR str284[sizeof("WM_SPOOLERSTATUS")];
  CHAR str285[sizeof("LVS_REPORT")];
  CHAR str286[sizeof("VK_APPS")];
  CHAR str287[sizeof("VK_CAPITAL")];
  CHAR str288[sizeof("CP_UTF7")];
  CHAR str289[sizeof("AW_HOR_NEGATIVE")];
  CHAR str290[sizeof("TBSTYLE_DROPDOWN")];
  CHAR str291[sizeof("LVIR_ICON")];
  CHAR str292[sizeof("WM_PRINTCLIENT")];
  CHAR str293[sizeof("MCS_DAYSTATE")];
  CHAR str294[sizeof("HDS_BUTTONS")];
  CHAR str295[sizeof("VK_SHIFT")];
  CHAR str296[sizeof("SWP_HIDEWINDOW")];
  CHAR str297[sizeof("EM_POSFROMCHAR")];
  CHAR str298[sizeof("HALFTONE")];
  CHAR str299[sizeof("CB_GETHORIZONTALEXTENT")];
  CHAR str300[sizeof("TTM_HITTEST")];
  CHAR str301[sizeof("WM_PALETTEISCHANGING")];
  CHAR str302[sizeof("CBN_SETFOCUS")];
  CHAR str303[sizeof("DT_PATH_ELLIPSIS")];
  CHAR str304[sizeof("SM_ARRANGE")];
  CHAR str305[sizeof("BLACK_PEN")];
  CHAR str306[sizeof("DS_SHELLFONT")];
  CHAR str307[sizeof("HTCLIENT")];
  CHAR str308[sizeof("IDC_VSPLIT")];
  CHAR str309[sizeof("VK_F19")];
  CHAR str310[sizeof("SB_LINEUP")];
  CHAR str311[sizeof("WS_EX_LAYERED")];
  CHAR str312[sizeof("EM_LIMITTEXT")];
  CHAR str313[sizeof("CWP_SKIPTRANSPARENT")];
  CHAR str314[sizeof("WS_THICKFRAME")];
  CHAR str315[sizeof("SM_SAMEDISPLAYFORMAT")];
  CHAR str316[sizeof("WM_CHARTOITEM")];
  CHAR str317[sizeof("VK_BROWSER_HOME")];
  CHAR str318[sizeof("VK_NUMPAD8")];
  CHAR str319[sizeof("SM_CXSMICON")];
  CHAR str320[sizeof("VK_NUMPAD4")];
  CHAR str321[sizeof("EM_GETMARGINS")];
  CHAR str322[sizeof("TVHT_TORIGHT")];
  CHAR str323[sizeof("VK_E")];
  CHAR str324[sizeof("WM_UPDATEUISTATE")];
  CHAR str325[sizeof("BF_ADJUST")];
  CHAR str326[sizeof("WM_ENTERIDLE")];
  CHAR str327[sizeof("WM_MDIACTIVATE")];
  CHAR str328[sizeof("WM_MOUSELEAVE")];
  CHAR str329[sizeof("CP_THREAD_ACP")];
  CHAR str330[sizeof("COLOR_3DFACE")];
  CHAR str331[sizeof("VK_OEM_8")];
  CHAR str332[sizeof("SB_PAGEDOWN")];
  CHAR str333[sizeof("CSIDL_APPDATA")];
  CHAR str334[sizeof("R2_NOT")];
  CHAR str335[sizeof("CB_GETITEMHEIGHT")];
  CHAR str336[sizeof("LB_ERR")];
  CHAR str337[sizeof("DT_BOTTOM")];
  CHAR str338[sizeof("SFF_WRITEXTRAPAR")];
  CHAR str339[sizeof("DLGC_BUTTON")];
  CHAR str340[sizeof("RBBS_GRIPPERALWAYS")];
  CHAR str341[sizeof("WS_EX_LEFTSCROLLBAR")];
  CHAR str342[sizeof("BM_GETSTATE")];
  CHAR str343[sizeof("WM_CANCELJOURNAL")];
  CHAR str344[sizeof("WM_NCCREATE")];
  CHAR str345[sizeof("SBM_SETSCROLLINFO")];
  CHAR str346[sizeof("ES_RIGHT")];
  CHAR str347[sizeof("SM_CXMAXTRACK")];
  CHAR str348[sizeof("DLGC_DEFPUSHBUTTON")];
  CHAR str349[sizeof("SW_MINIMIZE")];
  CHAR str350[sizeof("MF_OWNERDRAW")];
  CHAR str351[sizeof("VK_F4")];
  CHAR str352[sizeof("VK_SCROLL")];
  CHAR str353[sizeof("EN_IMECHANGE")];
  CHAR str354[sizeof("SF_RTF")];
  CHAR str355[sizeof("WM_INITDIALOG")];
  CHAR str356[sizeof("SE_ERR_DDEFAIL")];
  CHAR str357[sizeof("VK_ADD")];
  CHAR str358[sizeof("RBBS_TOPALIGN")];
  CHAR str359[sizeof("LBS_NOINTEGRALHEIGHT")];
  CHAR str360[sizeof("CSIDL_RECENT")];
  CHAR str361[sizeof("WM_SETTINGCHANGE")];
  CHAR str362[sizeof("IDI_HAND")];
  CHAR str363[sizeof("TVGN_LASTVISIBLE")];
  CHAR str364[sizeof("CF_DSPMETAFILEPICT")];
  CHAR str365[sizeof("RDW_NOINTERNALPAINT")];
  CHAR str366[sizeof("HWND_BOTTOM")];
  CHAR str367[sizeof("PS_ENDCAP_ROUND")];
  CHAR str368[sizeof("WS_EX_LTRREADING")];
  CHAR str369[sizeof("WM_NCMOUSELEAVE")];
  CHAR str370[sizeof("LBS_NOTIFY")];
  CHAR str371[sizeof("TTM_UPDATE")];
  CHAR str372[sizeof("WM_IME_KEYLAST")];
  CHAR str373[sizeof("DFC_MENU")];
  CHAR str374[sizeof("WM_MENUSELECT")];
  CHAR str375[sizeof("ES_LOWERCASE")];
  CHAR str376[sizeof("TBSTATE_HIDDEN")];
  CHAR str377[sizeof("WM_SYNCPAINT")];
  CHAR str378[sizeof("ACM_PLAY")];
  CHAR str379[sizeof("AW_HIDE")];
  CHAR str380[sizeof("DKGRAY_BRUSH")];
  CHAR str381[sizeof("WM_MENUCHAR")];
  CHAR str382[sizeof("VK_9")];
  CHAR str383[sizeof("SB_ENDSCROLL")];
  CHAR str384[sizeof("WM_IME_ENDCOMPOSITION")];
  CHAR str385[sizeof("IMAGE_CURSOR")];
  CHAR str386[sizeof("DTS_SHORTDATEFORMAT")];
  CHAR str387[sizeof("TTM_ENUMTOOLS")];
  CHAR str388[sizeof("MB_TASKMODAL")];
  CHAR str389[sizeof("MCS_MULTISELECT")];
  CHAR str390[sizeof("BS_PUSHBUTTON")];
  CHAR str391[sizeof("BTNS_BUTTON")];
  CHAR str392[sizeof("WM_HANDHELDLAST")];
  CHAR str393[sizeof("COLOR_3DDKSHADOW")];
  CHAR str394[sizeof("R2_MASKPENNOT")];
  CHAR str395[sizeof("LR_VGACOLOR")];
  CHAR str396[sizeof("WM_TCARD")];
  CHAR str397[sizeof("TPM_VERTICAL")];
  CHAR str398[sizeof("WM_CANCELMODE")];
  CHAR str399[sizeof("LB_GETCOUNT")];
  CHAR str400[sizeof("VK_MENU")];
  CHAR str401[sizeof("SM_SLOWMACHINE")];
  CHAR str402[sizeof("SWP_NOSIZE")];
  CHAR str403[sizeof("OBM_ZOOMD")];
  CHAR str404[sizeof("BS_CHECKBOX")];
  CHAR str405[sizeof("VK_OEM_WSCTRL")];
  CHAR str406[sizeof("MF_DISABLED")];
  CHAR str407[sizeof("ACM_STOP")];
  CHAR str408[sizeof("EM_GETLIMITTEXT")];
  CHAR str409[sizeof("WM_GETOBJECT")];
  CHAR str410[sizeof("LB_SELECTSTRING")];
  CHAR str411[sizeof("VK_MEDIA_STOP")];
  CHAR str412[sizeof("SM_CYSIZEFRAME")];
  CHAR str413[sizeof("CSIDL_COMPUTERSNEARME")];
  CHAR str414[sizeof("VK_Z")];
  CHAR str415[sizeof("MB_NOFOCUS")];
  CHAR str416[sizeof("OCR_WAIT")];
  CHAR str417[sizeof("LB_ERRSPACE")];
  CHAR str418[sizeof("SM_CYMINSPACING")];
  CHAR str419[sizeof("BDR_INNER")];
  CHAR str420[sizeof("BN_HILITE")];
  CHAR str421[sizeof("ENM_DRAGDROPDONE")];
  CHAR str422[sizeof("VK_OEM_BACKTAB")];
  CHAR str423[sizeof("CSIDL_INTERNET_CACHE")];
  CHAR str424[sizeof("WM_ACTIVATE")];
  CHAR str425[sizeof("TVHT_BELOW")];
  CHAR str426[sizeof("AW_SLIDE")];
  CHAR str427[sizeof("WM_TIMECHANGE")];
  CHAR str428[sizeof("VK_LAUNCH_MEDIA_SELECT")];
  CHAR str429[sizeof("WM_GETHOTKEY")];
  CHAR str430[sizeof("HTTOP")];
  CHAR str431[sizeof("CDRF_SKIPDEFAULT")];
  CHAR str432[sizeof("DFCS_SCROLLCOMBOBOX")];
  CHAR str433[sizeof("DFCS_BUTTONPUSH")];
  CHAR str434[sizeof("VK_F10")];
  CHAR str435[sizeof("BF_TOPLEFT")];
  CHAR str436[sizeof("WM_SYSKEYUP")];
  CHAR str437[sizeof("VK_PRIOR")];
  CHAR str438[sizeof("RDW_NOCHILDREN")];
  CHAR str439[sizeof("CSIDL_STARTUP")];
  CHAR str440[sizeof("WM_ENABLE")];
  CHAR str441[sizeof("LB_SETCURSEL")];
  CHAR str442[sizeof("WM_QUERYENDSESSION")];
  CHAR str443[sizeof("VK_OEM_NEC_EQUAL")];
  CHAR str444[sizeof("ILS_SATURATE")];
  CHAR str445[sizeof("WS_OVERLAPPED")];
  CHAR str446[sizeof("LVS_OWNERDATA")];
  CHAR str447[sizeof("TBSTYLE_CHECK")];
  CHAR str448[sizeof("IDC_ARROW")];
  CHAR str449[sizeof("STN_DBLCLK")];
  CHAR str450[sizeof("CSIDL_FLAG_CREATE")];
  CHAR str451[sizeof("BDR_RAISED")];
  CHAR str452[sizeof("CSIDL_LOCAL_APPDATA")];
  CHAR str453[sizeof("PBM_SETBKCOLOR")];
  CHAR str454[sizeof("VK_F17")];
  CHAR str455[sizeof("HTTOPLEFT")];
  CHAR str456[sizeof("OIC_WINLOGO")];
  CHAR str457[sizeof("WM_IME_SELECT")];
  CHAR str458[sizeof("TBSTATE_INDETERMINATE")];
  CHAR str459[sizeof("HTHELP")];
  CHAR str460[sizeof("SC_SEPARATOR")];
  CHAR str461[sizeof("LB_GETHORIZONTALEXTENT")];
  CHAR str462[sizeof("CBES_EX_NOEDITIMAGE")];
  CHAR str463[sizeof("VK_OEM_FJ_ROYA")];
  CHAR str464[sizeof("WS_EX_LEFT")];
  CHAR str465[sizeof("BCM_SETIMAGELIST")];
  CHAR str466[sizeof("COLOR_INFOTEXT")];
  CHAR str467[sizeof("LB_GETITEMHEIGHT")];
  CHAR str468[sizeof("WM_MDISETMENU")];
  CHAR str469[sizeof("TVHT_ONITEMINDENT")];
  CHAR str470[sizeof("CF_TIFF")];
  CHAR str471[sizeof("VK_RCONTROL")];
  CHAR str472[sizeof("NM_LDOWN")];
  CHAR str473[sizeof("SB_RIGHT")];
  CHAR str474[sizeof("EM_GETMODIFY")];
  CHAR str475[sizeof("SW_NORMAL")];
  CHAR str476[sizeof("SM_RESERVED4")];
  CHAR str477[sizeof("LVIR_SELECTBOUNDS")];
  CHAR str478[sizeof("IMAGE_ICON")];
  CHAR str479[sizeof("WM_WINDOWPOSCHANGED")];
  CHAR str480[sizeof("HDS_FLAT")];
  CHAR str481[sizeof("WM_VSCROLLCLIPBOARD")];
  CHAR str482[sizeof("BS_GROUPBOX")];
  CHAR str483[sizeof("LBS_NOSEL")];
  CHAR str484[sizeof("ODT_LISTBOX")];
  CHAR str485[sizeof("R2_BLACK")];
  CHAR str486[sizeof("CB_SETITEMDATA")];
  CHAR str487[sizeof("CP_SYMBOL")];
  CHAR str488[sizeof("LVS_NOSCROLL")];
  CHAR str489[sizeof("BDR_SUNKENOUTER")];
  CHAR str490[sizeof("CSIDL_CDBURN_AREA")];
  CHAR str491[sizeof("ES_OEMCONVERT")];
  CHAR str492[sizeof("EN_UPDATE")];
  CHAR str493[sizeof("CF_DIB")];
  CHAR str494[sizeof("VK_BROWSER_FORWARD")];
  CHAR str495[sizeof("PBS_SMOOTH")];
  CHAR str496[sizeof("PBM_GETPOS")];
  CHAR str497[sizeof("RBBS_FIXEDSIZE")];
  CHAR str498[sizeof("WM_CREATE")];
  CHAR str499[sizeof("WM_HOTKEY")];
  CHAR str500[sizeof("EN_REQUESTRESIZE")];
  CHAR str501[sizeof("LB_ITEMFROMPOINT")];
  CHAR str502[sizeof("VK_F21")];
  CHAR str503[sizeof("SM_CXMINIMIZED")];
  CHAR str504[sizeof("ODS_INACTIVE")];
  CHAR str505[sizeof("WM_SETTEXT")];
  CHAR str506[sizeof("WM_CONTEXTMENU")];
  CHAR str507[sizeof("NM_THEMECHANGED")];
  CHAR str508[sizeof("ENM_UPDATE")];
  CHAR str509[sizeof("MF_MOUSESELECT")];
  CHAR str510[sizeof("WM_SETFONT")];
  CHAR str511[sizeof("VK_ACCEPT")];
  CHAR str512[sizeof("COLOR_SCROLLBAR")];
  CHAR str513[sizeof("MB_ICONHAND")];
  CHAR str514[sizeof("VK_6")];
  CHAR str515[sizeof("WM_RBUTTONDBLCLK")];
  CHAR str516[sizeof("VK_VOLUME_DOWN")];
  CHAR str517[sizeof("SW_FORCEMINIMIZE")];
  CHAR str518[sizeof("CDRF_NOTIFYITEMDRAW")];
  CHAR str519[sizeof("CF_PENDATA")];
  CHAR str520[sizeof("DS_MODALFRAME")];
  CHAR str521[sizeof("SRCPAINT")];
  CHAR str522[sizeof("VK_Y")];
  CHAR str523[sizeof("SBT_NOBORDERS")];
  CHAR str524[sizeof("STRETCH_ORSCANS")];
  CHAR str525[sizeof("CLR_INVALID")];
  CHAR str526[sizeof("SM_RESERVED1")];
  CHAR str527[sizeof("DFCS_MONO")];
  CHAR str528[sizeof("WM_CTLCOLORMSGBOX")];
  CHAR str529[sizeof("VK_PLAY")];
  CHAR str530[sizeof("TPM_HORNEGANIMATION")];
  CHAR str531[sizeof("LBS_USETABSTOPS")];
  CHAR str532[sizeof("CF_OEMTEXT")];
  CHAR str533[sizeof("MB_APPLMODAL")];
  CHAR str534[sizeof("SB_VERT")];
  CHAR str535[sizeof("VK_F20")];
  CHAR str536[sizeof("WM_DELETEITEM")];
  CHAR str537[sizeof("WM_IME_COMPOSITIONFULL")];
  CHAR str538[sizeof("SC_SIZE")];
  CHAR str539[sizeof("LVIS_STATEIMAGEMASK")];
  CHAR str540[sizeof("MCSC_TITLEBK")];
  CHAR str541[sizeof("VK_OEM_ATTN")];
  CHAR str542[sizeof("VK_ICO_HELP")];
  CHAR str543[sizeof("WM_COMPAREITEM")];
  CHAR str544[sizeof("ACS_CENTER")];
  CHAR str545[sizeof("TTM_GETMARGIN")];
  CHAR str546[sizeof("CDRF_DODEFAULT")];
  CHAR str547[sizeof("CB_ERRSPACE")];
  CHAR str548[sizeof("WM_MOUSEMOVE")];
  CHAR str549[sizeof("SM_CXMINTRACK")];
  CHAR str550[sizeof("EN_SELCHANGE")];
  CHAR str551[sizeof("SM_CYMENUSIZE")];
  CHAR str552[sizeof("DTS_APPCANPARSE")];
  CHAR str553[sizeof("EN_SETFOCUS")];
  CHAR str554[sizeof("SE_ERR_NOASSOC")];
  CHAR str555[sizeof("STRETCH_ANDSCANS")];
  CHAR str556[sizeof("TVHT_ONITEMRIGHT")];
  CHAR str557[sizeof("DEVICE_DEFAULT_FONT")];
  CHAR str558[sizeof("MF_ENABLED")];
  CHAR str559[sizeof("WM_SHOWWINDOW")];
  CHAR str560[sizeof("VK_J")];
  CHAR str561[sizeof("TME_QUERY")];
  CHAR str562[sizeof("CB_DELETESTRING")];
  CHAR str563[sizeof("HTSIZEFIRST")];
  CHAR str564[sizeof("COLOR_CAPTIONTEXT")];
  CHAR str565[sizeof("LB_GETSELITEMS")];
  CHAR str566[sizeof("VK_4")];
  CHAR str567[sizeof("TTM_GETTIPBKCOLOR")];
  CHAR str568[sizeof("DFC_CAPTION")];
  CHAR str569[sizeof("EM_GETLINECOUNT")];
  CHAR str570[sizeof("CF_SYLK")];
  CHAR str571[sizeof("HTNOWHERE")];
  CHAR str572[sizeof("TVHT_ONITEM")];
  CHAR str573[sizeof("BTNS_CHECK")];
  CHAR str574[sizeof("TBTS_TOP")];
  CHAR str575[sizeof("WM_SYSKEYDOWN")];
  CHAR str576[sizeof("RBBS_BREAK")];
  CHAR str577[sizeof("SWP_NOACTIVATE")];
  CHAR str578[sizeof("CS_BYTEALIGNWINDOW")];
  CHAR str579[sizeof("EM_EMPTYUNDOBUFFER")];
  CHAR str580[sizeof("DLGC_STATIC")];
  CHAR str581[sizeof("VK_PACKET")];
  CHAR str582[sizeof("MF_RIGHTJUSTIFY")];
  CHAR str583[sizeof("STM_MSGMAX")];
  CHAR str584[sizeof("TA_BOTTOM")];
  CHAR str585[sizeof("DFCS_CAPTIONCLOSE")];
  CHAR str586[sizeof("DFCS_BUTTON3STATE")];
  CHAR str587[sizeof("SBS_BOTTOMALIGN")];
  CHAR str588[sizeof("DLGC_UNDEFPUSHBUTTON")];
  CHAR str589[sizeof("LB_FINDSTRING")];
  CHAR str590[sizeof("SW_SHOWNOACTIVATE")];
  CHAR str591[sizeof("ENM_PARAGRAPHEXPANDED")];
  CHAR str592[sizeof("ENM_SELCHANGE")];
  CHAR str593[sizeof("ODT_COMBOBOX")];
  CHAR str594[sizeof("VK_END")];
  CHAR str595[sizeof("I_IMAGENONE")];
  CHAR str596[sizeof("LVS_SMALLICON")];
  CHAR str597[sizeof("WM_CTLCOLORBTN")];
  CHAR str598[sizeof("ILD_ROP")];
  CHAR str599[sizeof("LVIS_OVERLAYMASK")];
  CHAR str600[sizeof("DS_CONTROL")];
  CHAR str601[sizeof("CSIDL_COMMON_DESKTOPDIRECTORY")];
  CHAR str602[sizeof("DLGC_RADIOBUTTON")];
  CHAR str603[sizeof("RDW_INVALIDATE")];
  CHAR str604[sizeof("SM_CMETRICS")];
  CHAR str605[sizeof("DFCS_MENUCHECK")];
  CHAR str606[sizeof("EM_GETTHUMB")];
  CHAR str607[sizeof("WM_COPYDATA")];
  CHAR str608[sizeof("DFCS_CAPTIONMAX")];
  CHAR str609[sizeof("SM_CXMAXIMIZED")];
  CHAR str610[sizeof("DT_WORD_ELLIPSIS")];
  CHAR str611[sizeof("HTCLOSE")];
  CHAR str612[sizeof("VK_OEM_PLUS")];
  CHAR str613[sizeof("OIC_ERROR")];
  CHAR str614[sizeof("MCSC_TITLETEXT")];
  CHAR str615[sizeof("LVS_EX_MULTIWORKAREAS")];
  CHAR str616[sizeof("WM_RBUTTONUP")];
  CHAR str617[sizeof("WM_PENWINLAST")];
  CHAR str618[sizeof("COLOR_WINDOW")];
  CHAR str619[sizeof("OBJ_BRUSH")];
  CHAR str620[sizeof("MB_ICONASTERISK")];
  CHAR str621[sizeof("AW_ACTIVATE")];
  CHAR str622[sizeof("EN_CHANGE")];
  CHAR str623[sizeof("CSIDL_COMMON_ALTSTARTUP")];
  CHAR str624[sizeof("VK_DIVIDE")];
  CHAR str625[sizeof("ES_CENTER")];
  CHAR str626[sizeof("VK_RMENU")];
  CHAR str627[sizeof("BS_RADIOBUTTON")];
  CHAR str628[sizeof("NM_NCHITTEST")];
  CHAR str629[sizeof("DT_EDITCONTROL")];
  CHAR str630[sizeof("VTA_RIGHT")];
  CHAR str631[sizeof("MB_TYPEMASK")];
  CHAR str632[sizeof("GCL_STYLE")];
  CHAR str633[sizeof("BF_FLAT")];
  CHAR str634[sizeof("SBM_GETRANGE")];
  CHAR str635[sizeof("OCR_APPSTARTING")];
  CHAR str636[sizeof("PS_COSMETIC")];
  CHAR str637[sizeof("CBS_OWNERDRAWFIXED")];
  CHAR str638[sizeof("CBS_LOWERCASE")];
  CHAR str639[sizeof("WM_CHANGEUISTATE")];
  CHAR str640[sizeof("WM_AFXLAST")];
  CHAR str641[sizeof("EM_SETTABSTOPS")];
  CHAR str642[sizeof("EM_GETLINE")];
  CHAR str643[sizeof("WM_CTLCOLORSTATIC")];
  CHAR str644[sizeof("WM_NCPAINT")];
  CHAR str645[sizeof("WS_EX_NOINHERITLAYOUT")];
  CHAR str646[sizeof("WM_STYLECHANGING")];
  CHAR str647[sizeof("VK_NEXT")];
  CHAR str648[sizeof("SM_RESERVED3")];
  CHAR str649[sizeof("MF_DEFAULT")];
  CHAR str650[sizeof("TPM_LAYOUTRTL")];
  CHAR str651[sizeof("WM_CTLCOLORDLG")];
  CHAR str652[sizeof("EN_SAVECLIPBOARD")];
  CHAR str653[sizeof("WM_SETHOTKEY")];
  CHAR str654[sizeof("COLOR_3DLIGHT")];
  CHAR str655[sizeof("VK_N")];
  CHAR str656[sizeof("ODS_NOACCEL")];
  CHAR str657[sizeof("CB_OKAY")];
  CHAR str658[sizeof("SM_CYKANJIWINDOW")];
  CHAR str659[sizeof("OCR_SIZEWE")];
  CHAR str660[sizeof("ODA_DRAWENTIRE")];
  CHAR str661[sizeof("HDS_HORZ")];
  CHAR str662[sizeof("SBM_GETSCROLLINFO")];
  CHAR str663[sizeof("LVS_ALIGNTOP")];
  CHAR str664[sizeof("MF_CHANGE")];
  CHAR str665[sizeof("PS_DOT")];
  CHAR str666[sizeof("WM_HANDHELDFIRST")];
  CHAR str667[sizeof("LVS_AUTOARRANGE")];
  CHAR str668[sizeof("CS_CLASSDC")];
  CHAR str669[sizeof("TBSTATE_ENABLED")];
  CHAR str670[sizeof("WS_EX_ACCEPTFILES")];
  CHAR str671[sizeof("WM_POWERBROADCAST")];
  CHAR str672[sizeof("CWP_SKIPINVISIBLE")];
  CHAR str673[sizeof("TBSTYLE_CHECKGROUP")];
  CHAR str674[sizeof("GT_DEFAULT")];
  CHAR str675[sizeof("MA_ACTIVATE")];
  CHAR str676[sizeof("WS_EX_OVERLAPPEDWINDOW")];
  CHAR str677[sizeof("DEFAULT_PALETTE")];
  CHAR str678[sizeof("CDDS_ITEMPREERASE")];
  CHAR str679[sizeof("WS_CAPTION")];
  CHAR str680[sizeof("OBM_BTSIZE")];
  CHAR str681[sizeof("SM_MOUSEWHEELPRESENT")];
  CHAR str682[sizeof("WM_DRAWITEM")];
  CHAR str683[sizeof("DT_INTERNAL")];
  CHAR str684[sizeof("CB_LIMITTEXT")];
  CHAR str685[sizeof("ODA_FOCUS")];
  CHAR str686[sizeof("VK_LAUNCH_APP1")];
  CHAR str687[sizeof("BS_INDEXED")];
  CHAR str688[sizeof("ILC_COLOR32")];
  CHAR str689[sizeof("COLOR_MENU")];
  CHAR str690[sizeof("CDDS_PREERASE")];
  CHAR str691[sizeof("VK_JUNJA")];
  CHAR str692[sizeof("VK_DECIMAL")];
  CHAR str693[sizeof("COLOR_GRAYTEXT")];
  CHAR str694[sizeof("ILD_IMAGE")];
  CHAR str695[sizeof("VK_F5")];
  CHAR str696[sizeof("ILC_COLORDDB")];
  CHAR str697[sizeof("CB_GETDROPPEDWIDTH")];
  CHAR str698[sizeof("VK_OEM_FJ_JISHO")];
  CHAR str699[sizeof("WM_PAINTICON")];
  CHAR str700[sizeof("ACS_TRANSPARENT")];
  CHAR str701[sizeof("RDW_FRAME")];
  CHAR str702[sizeof("LVS_EX_UNDERLINEHOT")];
  CHAR str703[sizeof("EM_SETSEL")];
  CHAR str704[sizeof("WM_STYLECHANGED")];
  CHAR str705[sizeof("RGN_AND")];
  CHAR str706[sizeof("CSIDL_DESKTOP")];
  CHAR str707[sizeof("CAPTUREBLT")];
  CHAR str708[sizeof("VK_ZOOM")];
  CHAR str709[sizeof("TVGN_CARET")];
  CHAR str710[sizeof("CSIDL_COMMON_MUSIC")];
  CHAR str711[sizeof("DT_VCENTER")];
  CHAR str712[sizeof("OBM_LFARROWI")];
  CHAR str713[sizeof("VK_F15")];
  CHAR str714[sizeof("BCM_GETIDEALSIZE")];
  CHAR str715[sizeof("IDTRYAGAIN")];
  CHAR str716[sizeof("BN_DOUBLECLICKED")];
  CHAR str717[sizeof("RDW_NOERASE")];
  CHAR str718[sizeof("BS_MONOPATTERN")];
  CHAR str719[sizeof("SM_CYDRAG")];
  CHAR str720[sizeof("LVS_ALIGNLEFT")];
  CHAR str721[sizeof("CF_MAX")];
  CHAR str722[sizeof("VTA_BOTTOM")];
  CHAR str723[sizeof("HTSIZELAST")];
  CHAR str724[sizeof("SM_CXFOCUSBORDER")];
  CHAR str725[sizeof("WS_EX_NOACTIVATE")];
  CHAR str726[sizeof("SMTO_NOTIMEOUTIFNOTHUNG")];
  CHAR str727[sizeof("CS_NOCLOSE")];
  CHAR str728[sizeof("ENM_NONE")];
  CHAR str729[sizeof("CSIDL_PROGRAM_FILES")];
  CHAR str730[sizeof("HTSIZE")];
  CHAR str731[sizeof("CDRF_NOTIFYPOSTPAINT")];
  CHAR str732[sizeof("TTM_SETMAXTIPWIDTH")];
  CHAR str733[sizeof("VK_NUMPAD9")];
  CHAR str734[sizeof("SM_CYMAXIMIZED")];
  CHAR str735[sizeof("WM_CHILDACTIVATE")];
  CHAR str736[sizeof("DT_LEFT")];
  CHAR str737[sizeof("CB_GETDROPPEDSTATE")];
  CHAR str738[sizeof("BF_TOP")];
  CHAR str739[sizeof("MK_SHIFT")];
  CHAR str740[sizeof("VK_M")];
  CHAR str741[sizeof("IDC_CROSS")];
  CHAR str742[sizeof("RBBS_VARIABLEHEIGHT")];
  CHAR str743[sizeof("GWL_WNDPROC")];
  CHAR str744[sizeof("PBM_SETPOS")];
  CHAR str745[sizeof("ILD_SCALE")];
  CHAR str746[sizeof("SM_MENUDROPALIGNMENT")];
  CHAR str747[sizeof("SWP_NOCOPYBITS")];
  CHAR str748[sizeof("OBM_RGARROWI")];
  CHAR str749[sizeof("R2_NOTCOPYPEN")];
  CHAR str750[sizeof("ILD_BLEND25")];
  CHAR str751[sizeof("WM_IME_SETCONTEXT")];
  CHAR str752[sizeof("WM_CTLCOLORLISTBOX")];
  CHAR str753[sizeof("IDI_WARNING")];
  CHAR str754[sizeof("VK_F1")];
  CHAR str755[sizeof("SM_CYFOCUSBORDER")];
  CHAR str756[sizeof("OBM_CHECKBOXES")];
  CHAR str757[sizeof("WM_APP")];
  CHAR str758[sizeof("CSIDL_CONTROLS")];
  CHAR str759[sizeof("LVS_TYPEMASK")];
  CHAR str760[sizeof("ODS_CHECKED")];
  CHAR str761[sizeof("ODS_FOCUS")];
  CHAR str762[sizeof("SM_CYMIN")];
  CHAR str763[sizeof("PBM_SETRANGE")];
  CHAR str764[sizeof("SWP_NOOWNERZORDER")];
  CHAR str765[sizeof("LVS_EX_FLATSB")];
  CHAR str766[sizeof("GRAY_BRUSH")];
  CHAR str767[sizeof("CB_GETITEMDATA")];
  CHAR str768[sizeof("GW_OWNER")];
  CHAR str769[sizeof("SM_CYBORDER")];
  CHAR str770[sizeof("LVS_SORTASCENDING")];
  CHAR str771[sizeof("LBS_SORT")];
  CHAR str772[sizeof("DFCS_BUTTONRADIO")];
  CHAR str773[sizeof("RBBS_NOVERT")];
  CHAR str774[sizeof("LVS_EX_LABELTIP")];
  CHAR str775[sizeof("EN_CORRECTTEXT")];
  CHAR str776[sizeof("VK_F16")];
  CHAR str777[sizeof("BF_TOPRIGHT")];
  CHAR str778[sizeof("VTA_CENTER")];
  CHAR str779[sizeof("VK_INSERT")];
  CHAR str780[sizeof("IDB_VIEW_SMALL_COLOR")];
  CHAR str781[sizeof("SM_CYICONSPACING")];
  CHAR str782[sizeof("DT_NOCLIP")];
  CHAR str783[sizeof("MCS_WEEKNUMBERS")];
  CHAR str784[sizeof("R2_NOTXORPEN")];
  CHAR str785[sizeof("WM_GETMINMAXINFO")];
  CHAR str786[sizeof("CBN_DBLCLK")];
  CHAR str787[sizeof("ODS_COMBOBOXEDIT")];
  CHAR str788[sizeof("TVGN_PREVIOUSVISIBLE")];
  CHAR str789[sizeof("NM_TOOLTIPSCREATED")];
  CHAR str790[sizeof("VK_I")];
  CHAR str791[sizeof("WM_MENURBUTTONUP")];
  CHAR str792[sizeof("VK_1")];
  CHAR str793[sizeof("VK_F22")];
  CHAR str794[sizeof("EN_ALIGN_LTR_EC")];
  CHAR str795[sizeof("MERGEPAINT")];
  CHAR str796[sizeof("MB_SERVICE_NOTIFICATION")];
  CHAR str797[sizeof("MF_CHECKED")];
  CHAR str798[sizeof("VK_OEM_COPY")];
  CHAR str799[sizeof("CSIDL_FLAG_MASK")];
  CHAR str800[sizeof("CB_SETEXTENDEDUI")];
  CHAR str801[sizeof("SIMPLEREGION")];
  CHAR str802[sizeof("BF_BOTTOMLEFT")];
  CHAR str803[sizeof("DLGC_HASSETSEL")];
  CHAR str804[sizeof("SM_CYDLGFRAME")];
  CHAR str805[sizeof("WS_MAXIMIZE")];
  CHAR str806[sizeof("TBSTYLE_EX_HIDECLIPPEDBUTTONS")];
  CHAR str807[sizeof("LB_SETHORIZONTALEXTENT")];
  CHAR str808[sizeof("LR_COLOR")];
  CHAR str809[sizeof("WM_VKEYTOITEM")];
  CHAR str810[sizeof("CB_INITSTORAGE")];
  CHAR str811[sizeof("BN_SETFOCUS")];
  CHAR str812[sizeof("WS_EX_PALETTEWINDOW")];
  CHAR str813[sizeof("CSIDL_COMMON_PROGRAMS")];
  CHAR str814[sizeof("CS_BYTEALIGNCLIENT")];
  CHAR str815[sizeof("DFC_SCROLL")];
  CHAR str816[sizeof("WM_ERASEBKGND")];
  CHAR str817[sizeof("PBS_MARQUEE")];
  CHAR str818[sizeof("WM_NCMBUTTONUP")];
  CHAR str819[sizeof("SWP_DEFERERASE")];
  CHAR str820[sizeof("IMAGE_BITMAP")];
  CHAR str821[sizeof("TBSTYLE_NOPREFIX")];
  CHAR str822[sizeof("CSIDL_COOKIES")];
  CHAR str823[sizeof("WM_MOVE")];
  CHAR str824[sizeof("WM_FONTCHANGE")];
  CHAR str825[sizeof("VK_SEPARATOR")];
  CHAR str826[sizeof("WM_NCCALCSIZE")];
  CHAR str827[sizeof("WM_MDITILE")];
  CHAR str828[sizeof("HS_FDIAGONAL")];
  CHAR str829[sizeof("CSIDL_WINDOWS")];
  CHAR str830[sizeof("VK_MEDIA_PREV_TRACK")];
  CHAR str831[sizeof("ANSI_VAR_FONT")];
  CHAR str832[sizeof("DT_NOFULLWIDTHCHARBREAK")];
  CHAR str833[sizeof("ILC_MIRROR")];
  CHAR str834[sizeof("MF_POPUP")];
  CHAR str835[sizeof("WM_QUERYUISTATE")];
  CHAR str836[sizeof("CSIDL_PERSONAL")];
  CHAR str837[sizeof("HDS_HIDDEN")];
  CHAR str838[sizeof("NM_CHAR")];
  CHAR str839[sizeof("GCL_MENUNAME")];
  CHAR str840[sizeof("LVS_EX_DOUBLEBUFFER")];
  CHAR str841[sizeof("VK_CRSEL")];
  CHAR str842[sizeof("IDI_ASTERISK")];
  CHAR str843[sizeof("MB_DEFMASK")];
  CHAR str844[sizeof("CF_DSPBITMAP")];
  CHAR str845[sizeof("SM_CYSCREEN")];
  CHAR str846[sizeof("CSIDL_PROGRAM_FILESX86")];
  CHAR str847[sizeof("VK_OEM_PA3")];
  CHAR str848[sizeof("MF_APPEND")];
  CHAR str849[sizeof("MK_MBUTTON")];
  CHAR str850[sizeof("ANSI_FIXED_FONT")];
  CHAR str851[sizeof("IDB_HIST_SMALL_COLOR")];
  CHAR str852[sizeof("BN_PAINT")];
  CHAR str853[sizeof("VK_Q")];
  CHAR str854[sizeof("VK_NUMPAD0")];
  CHAR str855[sizeof("OBJ_MEMDC")];
  CHAR str856[sizeof("WM_CTLCOLORSCROLLBAR")];
  CHAR str857[sizeof("VK_B")];
  CHAR str858[sizeof("BN_KILLFOCUS")];
  CHAR str859[sizeof("WM_NCXBUTTONDOWN")];
  CHAR str860[sizeof("EM_SETPASSWORDCHAR")];
  CHAR str861[sizeof("CSIDL_FLAG_DONT_VERIFY")];
  CHAR str862[sizeof("TA_BASELINE")];
  CHAR str863[sizeof("CDDS_ITEMPREPAINT")];
  CHAR str864[sizeof("IDC_HELP")];
  CHAR str865[sizeof("DS_NOIDLEMSG")];
  CHAR str866[sizeof("TTM_SETTITLE")];
  CHAR str867[sizeof("WM_NCXBUTTONDBLCLK")];
  CHAR str868[sizeof("IDC_NO")];
  CHAR str869[sizeof("VK_OEM_FINISH")];
  CHAR str870[sizeof("WM_NCMBUTTONDBLCLK")];
  CHAR str871[sizeof("MB_CANCELTRYCONTINUE")];
  CHAR str872[sizeof("CDDS_SUBITEM")];
  CHAR str873[sizeof("WM_CTLCOLOREDIT")];
  CHAR str874[sizeof("TPM_VERNEGANIMATION")];
  CHAR str875[sizeof("BCM_FIRST")];
  CHAR str876[sizeof("ENM_IMECHANGE")];
  CHAR str877[sizeof("BS_DEFPUSHBUTTON")];
  CHAR str878[sizeof("CLR_HILIGHT")];
  CHAR str879[sizeof("SM_RESERVED2")];
  CHAR str880[sizeof("CB_SETDROPPEDWIDTH")];
  CHAR str881[sizeof("SE_ERR_PNF")];
  CHAR str882[sizeof("NM_SETFOCUS")];
  CHAR str883[sizeof("VK_OEM_AUTO")];
  CHAR str884[sizeof("BS_VCENTER")];
  CHAR str885[sizeof("R2_COPYPEN")];
  CHAR str886[sizeof("HDS_FULLDRAG")];
  CHAR str887[sizeof("PBS_VERTICAL")];
  CHAR str888[sizeof("HDS_DRAGDROP")];
  CHAR str889[sizeof("SFF_PERSISTVIEWSCALE")];
  CHAR str890[sizeof("MK_CONTROL")];
  CHAR str891[sizeof("WS_DLGFRAME")];
  CHAR str892[sizeof("ILC_COLOR")];
  CHAR str893[sizeof("SM_CYSMCAPTION")];
  CHAR str894[sizeof("WHITENESS")];
  CHAR str895[sizeof("I_IMAGECALLBACK")];
  CHAR str896[sizeof("LVS_EDITLABELS")];
  CHAR str897[sizeof("BS_CENTER")];
  CHAR str898[sizeof("OIC_NOTE")];
  CHAR str899[sizeof("HTOBJECT")];
  CHAR str900[sizeof("ERROR")];
  CHAR str901[sizeof("VK_F23")];
  CHAR str902[sizeof("LVIS_GLOW")];
  CHAR str903[sizeof("WM_NCLBUTTONDBLCLK")];
  CHAR str904[sizeof("BN_UNHILITE")];
  CHAR str905[sizeof("COLOR_INACTIVEBORDER")];
  CHAR str906[sizeof("IDB_STD_LARGE_COLOR")];
  CHAR str907[sizeof("CBS_UPPERCASE")];
  CHAR str908[sizeof("CSIDL_PROGRAMS")];
  CHAR str909[sizeof("DT_CENTER")];
  CHAR str910[sizeof("CF_BITMAP")];
  CHAR str911[sizeof("HWND_TOP")];
  CHAR str912[sizeof("LBS_WANTKEYBOARDINPUT")];
  CHAR str913[sizeof("VK_MODECHANGE")];
  CHAR str914[sizeof("SMTO_BLOCK")];
  CHAR str915[sizeof("IDHELP")];
  CHAR str916[sizeof("LB_GETCARETINDEX")];
  CHAR str917[sizeof("SIZE_MAXSHOW")];
  CHAR str918[sizeof("GCL_WNDPROC")];
  CHAR str919[sizeof("WM_MENUDRAG")];
  CHAR str920[sizeof("ILD_TRANSPARENT")];
  CHAR str921[sizeof("BM_CLICK")];
  CHAR str922[sizeof("SBS_SIZEBOX")];
  CHAR str923[sizeof("BM_SETSTATE")];
  CHAR str924[sizeof("SW_MAXIMIZE")];
  CHAR str925[sizeof("WS_CHILDWINDOW")];
  CHAR str926[sizeof("WM_HSCROLL")];
  CHAR str927[sizeof("TBSTYLE_AUTOSIZE")];
  CHAR str928[sizeof("PS_JOIN_MASK")];
  CHAR str929[sizeof("BS_BITMAP")];
  CHAR str930[sizeof("EN_VSCROLL")];
  CHAR str931[sizeof("BN_CLICKED")];
  CHAR str932[sizeof("CSIDL_BITBUCKET")];
  CHAR str933[sizeof("WM_HSCROLLCLIPBOARD")];
  CHAR str934[sizeof("BLACKNESS")];
  CHAR str935[sizeof("CB_GETTOPINDEX")];
  CHAR str936[sizeof("WM_INPUTLANGCHANGE")];
  CHAR str937[sizeof("SMTO_ABORTIFHUNG")];
  CHAR str938[sizeof("ODT_MENU")];
  CHAR str939[sizeof("BN_DISABLE")];
  CHAR str940[sizeof("NM_OUTOFMEMORY")];
  CHAR str941[sizeof("EM_SCROLLCARET")];
  CHAR str942[sizeof("DT_WORDBREAK")];
  CHAR str943[sizeof("ILC_MASK")];
  CHAR str944[sizeof("HS_VERTICAL")];
  CHAR str945[sizeof("WS_EX_CLIENTEDGE")];
  CHAR str946[sizeof("CSIDL_MYVIDEO")];
  CHAR str947[sizeof("CSIDL_PROGRAM_FILES_COMMONX86")];
  CHAR str948[sizeof("WM_CHAR")];
  CHAR str949[sizeof("R2_MERGENOTPEN")];
  CHAR str950[sizeof("MB_DEFBUTTON1")];
  CHAR str951[sizeof("MB_MISCMASK")];
  CHAR str952[sizeof("CSIDL_PROGRAM_FILES_COMMON")];
  CHAR str953[sizeof("MCSC_TEXT")];
  CHAR str954[sizeof("IDCONTINUE")];
  CHAR str955[sizeof("CSIDL_FAVORITES")];
  CHAR str956[sizeof("WS_CLIPSIBLINGS")];
  CHAR str957[sizeof("SM_CXMENUCHECK")];
  CHAR str958[sizeof("WS_EX_RIGHTSCROLLBAR")];
  CHAR str959[sizeof("VK_LMENU")];
  CHAR str960[sizeof("ENM_MOUSEEVENTS")];
  CHAR str961[sizeof("OBJ_REGION")];
  CHAR str962[sizeof("CWP_SKIPDISABLED")];
  CHAR str963[sizeof("TPM_TOPALIGN")];
  CHAR str964[sizeof("SWP_NOREDRAW")];
  CHAR str965[sizeof("TBSTATE_ELLIPSES")];
  CHAR str966[sizeof("SFF_PLAINRTF")];
  CHAR str967[sizeof("MCSC_MONTHBK")];
  CHAR str968[sizeof("VK_NONAME")];
  CHAR str969[sizeof("OBJ_FONT")];
  CHAR str970[sizeof("BTNS_AUTOSIZE")];
  CHAR str971[sizeof("HS_BDIAGONAL")];
  CHAR str972[sizeof("TTF_ABSOLUTE")];
  CHAR str973[sizeof("MB_RETRYCANCEL")];
  CHAR str974[sizeof("LBS_HASSTRINGS")];
  CHAR str975[sizeof("DT_MODIFYSTRING")];
  CHAR str976[sizeof("R2_NOP")];
  CHAR str977[sizeof("TBSTYLE_WRAPABLE")];
  CHAR str978[sizeof("VK_LSHIFT")];
  CHAR str979[sizeof("SB_PAGERIGHT")];
  CHAR str980[sizeof("LVS_EX_HIDELABELS")];
  CHAR str981[sizeof("IDI_INFORMATION")];
  CHAR str982[sizeof("BS_NULL")];
  CHAR str983[sizeof("RBBS_NOGRIPPER")];
  CHAR str984[sizeof("SWP_NOMOVE")];
  CHAR str985[sizeof("VK_DOWN")];
  CHAR str986[sizeof("CSIDL_COMMON_VIDEO")];
  CHAR str987[sizeof("COLOR_ACTIVECAPTION")];
  CHAR str988[sizeof("RGN_COPY")];
  CHAR str989[sizeof("VK_NUMLOCK")];
  CHAR str990[sizeof("WM_MDICASCADE")];
  CHAR str991[sizeof("EN_ERRSPACE")];
  CHAR str992[sizeof("COMPLEXREGION")];
  CHAR str993[sizeof("OBM_ZOOM")];
  CHAR str994[sizeof("WM_MDICREATE")];
  CHAR str995[sizeof("TA_LEFT")];
  CHAR str996[sizeof("SM_CYVTHUMB")];
  CHAR str997[sizeof("EN_LOWFIRTF")];
  CHAR str998[sizeof("COLOR_BACKGROUND")];
  CHAR str999[sizeof("VK_FINAL")];
  CHAR str1000[sizeof("TTM_GETTOOLINFO")];
  CHAR str1001[sizeof("SWP_NOSENDCHANGING")];
  CHAR str1002[sizeof("TA_NOUPDATECP")];
  CHAR str1003[sizeof("TBSTYLE_EX_MIXEDBUTTONS")];
  CHAR str1004[sizeof("WM_PRINT")];
  CHAR str1005[sizeof("WS_VISIBLE")];
  CHAR str1006[sizeof("TBTS_RIGHT")];
  CHAR str1007[sizeof("TTM_GETBUBBLESIZE")];
  CHAR str1008[sizeof("DS_CENTER")];
  CHAR str1009[sizeof("PS_JOIN_BEVEL")];
  CHAR str1010[sizeof("HTCAPTION")];
  CHAR str1011[sizeof("ACS_TIMER")];
  CHAR str1012[sizeof("ENM_DROPFILES")];
  CHAR str1013[sizeof("VK_XBUTTON2")];
  CHAR str1014[sizeof("DFCS_MENUARROW")];
  CHAR str1015[sizeof("WM_MENUCOMMAND")];
  CHAR str1016[sizeof("BS_HATCHED")];
  CHAR str1017[sizeof("CSIDL_PROFILE")];
  CHAR str1018[sizeof("ES_AUTOHSCROLL")];
  CHAR str1019[sizeof("CSIDL_SYSTEMX86")];
  CHAR str1020[sizeof("VK_BROWSER_REFRESH")];
  CHAR str1021[sizeof("VK_MULTIPLY")];
  CHAR str1022[sizeof("TVGN_FIRSTVISIBLE")];
  CHAR str1023[sizeof("AW_CENTER")];
  CHAR str1024[sizeof("VK_LCONTROL")];
  CHAR str1025[sizeof("CS_SAVEBITS")];
  CHAR str1026[sizeof("WM_PAINT")];
  CHAR str1027[sizeof("TA_TOP")];
  CHAR str1028[sizeof("VK_RBUTTON")];
  CHAR str1029[sizeof("VK_OEM_FJ_TOUROKU")];
  CHAR str1030[sizeof("TTM_GETDELAYTIME")];
  CHAR str1031[sizeof("DFCS_MENUBULLET")];
  CHAR str1032[sizeof("STN_ENABLE")];
  CHAR str1033[sizeof("SF_NCRFORNONASCII")];
  CHAR str1034[sizeof("MK_XBUTTON2")];
  CHAR str1035[sizeof("TTF_PARSELINKS")];
  CHAR str1036[sizeof("LVS_EX_CHECKBOXES")];
  CHAR str1037[sizeof("BF_MONO")];
  CHAR str1038[sizeof("LVS_NOLABELWRAP")];
  CHAR str1039[sizeof("MA_NOACTIVATE")];
  CHAR str1040[sizeof("LB_FINDSTRINGEXACT")];
  CHAR str1041[sizeof("ES_PASSWORD")];
  CHAR str1042[sizeof("TPM_BOTTOMALIGN")];
  CHAR str1043[sizeof("SYSTEM_FIXED_FONT")];
  CHAR str1044[sizeof("BF_BOTTOMRIGHT")];
  CHAR str1045[sizeof("CBES_EX_NOSIZELIMIT")];
  CHAR str1046[sizeof("LVIS_FOCUSED")];
  CHAR str1047[sizeof("WM_GETTEXT")];
  CHAR str1048[sizeof("WS_MINIMIZE")];
  CHAR str1049[sizeof("MB_OKCANCEL")];
  CHAR str1050[sizeof("LVS_SHAREIMAGELISTS")];
  CHAR str1051[sizeof("ES_READONLY")];
  CHAR str1052[sizeof("VK_SNAPSHOT")];
  CHAR str1053[sizeof("SM_CXSMSIZE")];
  CHAR str1054[sizeof("DFCS_SCROLLLEFT")];
  CHAR str1055[sizeof("ILD_FOCUS")];
  CHAR str1056[sizeof("LBN_SETFOCUS")];
  CHAR str1057[sizeof("SYSTEM_FONT")];
  CHAR str1058[sizeof("COLOR_3DSHADOW")];
  CHAR str1059[sizeof("SWP_ASYNCWINDOWPOS")];
  CHAR str1060[sizeof("SIZE_RESTORED")];
  CHAR str1061[sizeof("WHITEONBLACK")];
  CHAR str1062[sizeof("SM_CXHTHUMB")];
  CHAR str1063[sizeof("SM_CXDLGFRAME")];
  CHAR str1064[sizeof("LB_SETCOLUMNWIDTH")];
  CHAR str1065[sizeof("DFCS_HOT")];
  CHAR str1066[sizeof("WM_UNINITMENUPOPUP")];
  CHAR str1067[sizeof("SM_CXVIRTUALSCREEN")];
  CHAR str1068[sizeof("RGN_MIN")];
  CHAR str1069[sizeof("IDC_UPARROW")];
  CHAR str1070[sizeof("WM_NEXTMENU")];
  CHAR str1071[sizeof("BS_LEFT")];
  CHAR str1072[sizeof("WM_XBUTTONDBLCLK")];
  CHAR str1073[sizeof("VK_DELETE")];
  CHAR str1074[sizeof("SFF_KEEPDOCINFO")];
  CHAR str1075[sizeof("DT_PREFIXONLY")];
  CHAR str1076[sizeof("LB_GETITEMRECT")];
  CHAR str1077[sizeof("CSIDL_COMMON_DOCUMENTS")];
  CHAR str1078[sizeof("TTDT_INITIAL")];
  CHAR str1079[sizeof("SM_CYVSCROLL")];
  CHAR str1080[sizeof("GWL_ID")];
  CHAR str1081[sizeof("OBM_LFARROW")];
  CHAR str1082[sizeof("LVIS_SELECTED")];
  CHAR str1083[sizeof("SRCINVERT")];
  CHAR str1084[sizeof("TA_RIGHT")];
  CHAR str1085[sizeof("CDB2GVF_SHOWALLFILES")];
  CHAR str1086[sizeof("NM_CLICK")];
  CHAR str1087[sizeof("TTDT_AUTOMATIC")];
  CHAR str1088[sizeof("EN_MAXTEXT")];
  CHAR str1089[sizeof("VK_OEM_FJ_LOYA")];
  CHAR str1090[sizeof("CS_OWNDC")];
  CHAR str1091[sizeof("BS_HOLLOW")];
  CHAR str1092[sizeof("IDCLOSE")];
  CHAR str1093[sizeof("MB_ICONINFORMATION")];
  CHAR str1094[sizeof("SM_CYCURSOR")];
  CHAR str1095[sizeof("SM_SWAPBUTTON")];
  CHAR str1096[sizeof("R2_NOTMASKPEN")];
  CHAR str1097[sizeof("GCL_CBWNDEXTRA")];
  CHAR str1098[sizeof("VK_3")];
  CHAR str1099[sizeof("SW_HIDE")];
  CHAR str1100[sizeof("TTN_SHOW")];
  CHAR str1101[sizeof("CB_ERR")];
  CHAR str1102[sizeof("WM_INITMENU")];
  CHAR str1103[sizeof("VK_OEM_CLEAR")];
  CHAR str1104[sizeof("ACM_OPEN")];
  CHAR str1105[sizeof("DTS_RIGHTALIGN")];
  CHAR str1106[sizeof("ODS_HOTLIGHT")];
  CHAR str1107[sizeof("RGN_XOR")];
  CHAR str1108[sizeof("WM_KEYLAST")];
  CHAR str1109[sizeof("VK_ICO_00")];
  CHAR str1110[sizeof("WM_IME_CONTROL")];
  CHAR str1111[sizeof("SB_THUMBTRACK")];
  CHAR str1112[sizeof("RDW_ERASE")];
  CHAR str1113[sizeof("WM_COMPACTING")];
  CHAR str1114[sizeof("COLOR_WINDOWFRAME")];
  CHAR str1115[sizeof("VK_7")];
  CHAR str1116[sizeof("DEFAULT_GUI_FONT")];
  CHAR str1117[sizeof("GWL_USERDATA")];
  CHAR str1118[sizeof("PS_NULL")];
  CHAR str1119[sizeof("CBS_AUTOHSCROLL")];
  CHAR str1120[sizeof("VK_LAUNCH_APP2")];
  CHAR str1121[sizeof("EM_SETRECTNP")];
  CHAR str1122[sizeof("ODT_BUTTON")];
  CHAR str1123[sizeof("TPM_RIGHTBUTTON")];
  CHAR str1124[sizeof("R2_XORPEN")];
  CHAR str1125[sizeof("CSIDL_NETWORK")];
  CHAR str1126[sizeof("LVS_ICON")];
  CHAR str1127[sizeof("WM_MDIMAXIMIZE")];
  CHAR str1128[sizeof("WHITE_PEN")];
  CHAR str1129[sizeof("CBES_EX_CASESENSITIVE")];
  CHAR str1130[sizeof("TVGN_NEXTVISIBLE")];
  CHAR str1131[sizeof("CSIDL_COMMON_STARTUP")];
  CHAR str1132[sizeof("WM_AFXFIRST")];
  CHAR str1133[sizeof("SBM_GETSCROLLBARINFO")];
  CHAR str1134[sizeof("R2_WHITE")];
  CHAR str1135[sizeof("R2_MERGEPEN")];
  CHAR str1136[sizeof("VK_H")];
  CHAR str1137[sizeof("DFCS_SCROLLUP")];
  CHAR str1138[sizeof("LVS_EX_ONECLICKACTIVATE")];
  CHAR str1139[sizeof("AW_BLEND")];
  CHAR str1140[sizeof("VK_OEM_MINUS")];
  CHAR str1141[sizeof("LVS_EX_FULLROWSELECT")];
  CHAR str1142[sizeof("DC_PEN")];
  CHAR str1143[sizeof("VK_PAUSE")];
  CHAR str1144[sizeof("VK_F9")];
  CHAR str1145[sizeof("RGN_OR")];
  CHAR str1146[sizeof("WM_NCHITTEST")];
  CHAR str1147[sizeof("CDDS_ITEMPOSTERASE")];
  CHAR str1148[sizeof("SM_STARTER")];
  CHAR str1149[sizeof("SB_PAGELEFT")];
  CHAR str1150[sizeof("SBS_VERT")];
  CHAR str1151[sizeof("CSIDL_RESOURCES_LOCALIZED")];
  CHAR str1152[sizeof("DT_END_ELLIPSIS")];
  CHAR str1153[sizeof("WM_DROPFILES")];
  CHAR str1154[sizeof("TTM_NEWTOOLRECT")];
  CHAR str1155[sizeof("WM_UNDO")];
  CHAR str1156[sizeof("SC_DEFAULT")];
  CHAR str1157[sizeof("CB_SETITEMHEIGHT")];
  CHAR str1158[sizeof("WM_SIZING")];
  CHAR str1159[sizeof("TPM_HORIZONTAL")];
  CHAR str1160[sizeof("NM_KILLFOCUS")];
  CHAR str1161[sizeof("MF_USECHECKBITMAPS")];
  CHAR str1162[sizeof("SB_BOTH")];
  CHAR str1163[sizeof("EN_HSCROLL")];
  CHAR str1164[sizeof("EM_GETIMESTATUS")];
  CHAR str1165[sizeof("SM_CXVSCROLL")];
  CHAR str1166[sizeof("ILD_NORMAL")];
  CHAR str1167[sizeof("MB_ICONMASK")];
  CHAR str1168[sizeof("VK_LAUNCH_MAIL")];
  CHAR str1169[sizeof("CSIDL_TEMPLATES")];
  CHAR str1170[sizeof("SB_TOP")];
  CHAR str1171[sizeof("BS_PATTERN")];
  CHAR str1172[sizeof("MF_HILITE")];
  CHAR str1173[sizeof("WM_XBUTTONUP")];
  CHAR str1174[sizeof("LVIS_CUT")];
  CHAR str1175[sizeof("DFCS_SCROLLRIGHT")];
  CHAR str1176[sizeof("WM_NCRBUTTONDOWN")];
  CHAR str1177[sizeof("TA_UPDATECP")];
  CHAR str1178[sizeof("SM_CXICON")];
  CHAR str1179[sizeof("MB_YESNO")];
  CHAR str1180[sizeof("SM_CXMINSPACING")];
  CHAR str1181[sizeof("AW_VER_POSITIVE")];
  CHAR str1182[sizeof("VK_NUMPAD3")];
  CHAR str1183[sizeof("OIC_BANG")];
  CHAR str1184[sizeof("WS_CHILD")];
  CHAR str1185[sizeof("LVIS_DROPHILITED")];
  CHAR str1186[sizeof("MB_YESNOCANCEL")];
  CHAR str1187[sizeof("TTM_WINDOWFROMPOINT")];
  CHAR str1188[sizeof("SB_LINELEFT")];
  CHAR str1189[sizeof("RGN_ERROR")];
  CHAR str1190[sizeof("EN_PROTECTED")];
  CHAR str1191[sizeof("LR_DEFAULTSIZE")];
  CHAR str1192[sizeof("SM_CMOUSEBUTTONS")];
  CHAR str1193[sizeof("DT_TOP")];
  CHAR str1194[sizeof("SM_CXEDGE")];
  CHAR str1195[sizeof("DS_LOCALEDIT")];
  CHAR str1196[sizeof("EDGE_BUMP")];
  CHAR str1197[sizeof("LVS_EX_SUBITEMIMAGES")];
  CHAR str1198[sizeof("CSIDL_ADMINTOOLS")];
  CHAR str1199[sizeof("TTM_GETMAXTIPWIDTH")];
  CHAR str1200[sizeof("DS_CENTERMOUSE")];
  CHAR str1201[sizeof("WS_EX_STATICEDGE")];
  CHAR str1202[sizeof("AW_VER_NEGATIVE")];
  CHAR str1203[sizeof("HTSYSMENU")];
  CHAR str1204[sizeof("MF_UNCHECKED")];
  CHAR str1205[sizeof("ILC_COLOR16")];
  CHAR str1206[sizeof("VK_PRINT")];
  CHAR str1207[sizeof("CF_DIBV5")];
  CHAR str1208[sizeof("MB_SYSTEMMODAL")];
  CHAR str1209[sizeof("SM_REMOTESESSION")];
  CHAR str1210[sizeof("CB_GETCURSEL")];
  CHAR str1211[sizeof("WM_INPUT")];
  CHAR str1212[sizeof("VK_KANJI")];
  CHAR str1213[sizeof("CSIDL_NETHOOD")];
  CHAR str1214[sizeof("OBM_SIZE")];
  CHAR str1215[sizeof("EN_PARAGRAPHEXPANDED")];
  CHAR str1216[sizeof("SM_CYMAXTRACK")];
  CHAR str1217[sizeof("SMTO_NORMAL")];
  CHAR str1218[sizeof("LB_GETSEL")];
  CHAR str1219[sizeof("CSIDL_ALTSTARTUP")];
  CHAR str1220[sizeof("WM_SETCURSOR")];
  CHAR str1221[sizeof("CB_GETEDITSEL")];
  CHAR str1222[sizeof("DS_FIXEDSYS")];
  CHAR str1223[sizeof("ENM_CORRECTTEXT")];
  CHAR str1224[sizeof("GCL_HICON")];
  CHAR str1225[sizeof("TTM_POP")];
  CHAR str1226[sizeof("TVHT_NOWHERE")];
  CHAR str1227[sizeof("ILC_COLOR4")];
  CHAR str1228[sizeof("EM_LINESCROLL")];
  CHAR str1229[sizeof("TME_LEAVE")];
  CHAR str1230[sizeof("WM_USERCHANGED")];
  CHAR str1231[sizeof("COLOR_BTNFACE")];
  CHAR str1232[sizeof("SC_HOTKEY")];
  CHAR str1233[sizeof("OBJ_PEN")];
  CHAR str1234[sizeof("CF_PRIVATEFIRST")];
  CHAR str1235[sizeof("LR_CREATEDIBSECTION")];
  CHAR str1236[sizeof("SFF_SELECTION")];
  CHAR str1237[sizeof("ILC_COLOR8")];
  CHAR str1238[sizeof("SM_CYVIRTUALSCREEN")];
  CHAR str1239[sizeof("BF_BOTTOM")];
  CHAR str1240[sizeof("RBBS_USECHEVRON")];
  CHAR str1241[sizeof("ILC_COLOR24")];
  CHAR str1242[sizeof("PATINVERT")];
  CHAR str1243[sizeof("VK_RWIN")];
  CHAR str1244[sizeof("DFCS_CAPTIONMIN")];
  CHAR str1245[sizeof("GA_PARENT")];
  CHAR str1246[sizeof("OBM_DNARROWD")];
  CHAR str1247[sizeof("CW_USEDEFAULT")];
  CHAR str1248[sizeof("LVS_EX_SINGLEROW")];
  CHAR str1249[sizeof("OIC_WARNING")];
  CHAR str1250[sizeof("LBS_OWNERDRAWFIXED")];
  CHAR str1251[sizeof("VTA_LEFT")];
  CHAR str1252[sizeof("SM_CXDOUBLECLK")];
  CHAR str1253[sizeof("VK_OEM_5")];
  CHAR str1254[sizeof("CBS_SORT")];
  CHAR str1255[sizeof("WM_QUERYNEWPALETTE")];
  CHAR str1256[sizeof("BS_USERBUTTON")];
  CHAR str1257[sizeof("PS_JOIN_MITER")];
  CHAR str1258[sizeof("WM_IME_STARTCOMPOSITION")];
  CHAR str1259[sizeof("SC_MOVE")];
  CHAR str1260[sizeof("VK_RETURN")];
  CHAR str1261[sizeof("EM_LINEFROMCHAR")];
  CHAR str1262[sizeof("DT_HIDEPREFIX")];
  CHAR str1263[sizeof("HOLLOW_BRUSH")];
  CHAR str1264[sizeof("VK_NONCONVERT")];
  CHAR str1265[sizeof("WA_INACTIVE")];
  CHAR str1266[sizeof("WM_MDIICONARRANGE")];
  CHAR str1267[sizeof("LB_ADDSTRING")];
  CHAR str1268[sizeof("GCLP_HICONSM")];
  CHAR str1269[sizeof("DFC_BUTTON")];
  CHAR str1270[sizeof("VK_F8")];
  CHAR str1271[sizeof("LB_SELITEMRANGEEX")];
  CHAR str1272[sizeof("HTBORDER")];
  CHAR str1273[sizeof("LB_SETLOCALE")];
  CHAR str1274[sizeof("WS_EX_RTLREADING")];
  CHAR str1275[sizeof("BF_RIGHT")];
  CHAR str1276[sizeof("CB_ADDSTRING")];
  CHAR str1277[sizeof("VK_O")];
  CHAR str1278[sizeof("TTM_SETMARGIN")];
  CHAR str1279[sizeof("SW_SHOWMINNOACTIVE")];
  CHAR str1280[sizeof("TVHT_ONITEMICON")];
  CHAR str1281[sizeof("DTS_SHORTDATECENTURYFORMAT")];
  CHAR str1282[sizeof("BN_DBLCLK")];
  CHAR str1283[sizeof("WM_PARENTNOTIFY")];
  CHAR str1284[sizeof("ENM_CHANGE")];
  CHAR str1285[sizeof("SM_CYDOUBLECLK")];
  CHAR str1286[sizeof("SM_CYSMICON")];
  CHAR str1287[sizeof("EM_FMTLINES")];
  CHAR str1288[sizeof("LVSIL_STATE")];
  CHAR str1289[sizeof("SC_VSCROLL")];
  CHAR str1290[sizeof("GW_ENABLEDPOPUP")];
  CHAR str1291[sizeof("CSIDL_STARTMENU")];
  CHAR str1292[sizeof("SE_ERR_DDETIMEOUT")];
  CHAR str1293[sizeof("R2_MASKNOTPEN")];
  CHAR str1294[sizeof("ENM_LANGCHANGE")];
  CHAR str1295[sizeof("LVS_EX_HEADERDRAGDROP")];
  CHAR str1296[sizeof("LBN_KILLFOCUS")];
  CHAR str1297[sizeof("NM_RELEASEDCAPTURE")];
  CHAR str1298[sizeof("MF_STRING")];
  CHAR str1299[sizeof("SB_HORZ")];
  CHAR str1300[sizeof("WM_MOVING")];
  CHAR str1301[sizeof("BCM_GETTEXTMARGIN")];
  CHAR str1302[sizeof("ILS_ALPHA")];
  CHAR str1303[sizeof("SM_SHUTTINGDOWN")];
  CHAR str1304[sizeof("SW_SHOW")];
  CHAR str1305[sizeof("SB_LINEDOWN")];
  CHAR str1306[sizeof("TTF_SUBCLASS")];
  CHAR str1307[sizeof("LR_COPYFROMRESOURCE")];
  CHAR str1308[sizeof("R2_MERGEPENNOT")];
  CHAR str1309[sizeof("IDC_APPSTARTING")];
  CHAR str1310[sizeof("TME_NONCLIENT")];
  CHAR str1311[sizeof("HS_HORIZONTAL")];
  CHAR str1312[sizeof("BM_SETIMAGE")];
  CHAR str1313[sizeof("TTM_TRACKACTIVATE")];
  CHAR str1314[sizeof("MB_ICONEXCLAMATION")];
  CHAR str1315[sizeof("CB_INSERTSTRING")];
  CHAR str1316[sizeof("STM_SETICON")];
  CHAR str1317[sizeof("SBM_GETPOS")];
  CHAR str1318[sizeof("ODS_DISABLED")];
  CHAR str1319[sizeof("LB_ADDFILE")];
  CHAR str1320[sizeof("EM_GETPASSWORDCHAR")];
  CHAR str1321[sizeof("DT_NOPREFIX")];
  CHAR str1322[sizeof("DS_SETFOREGROUND")];
  CHAR str1323[sizeof("PS_STYLE_MASK")];
  CHAR str1324[sizeof("SB_CTL")];
  CHAR str1325[sizeof("CP_UTF8")];
  CHAR str1326[sizeof("SBS_LEFTALIGN")];
  CHAR str1327[sizeof("SFF_PWD")];
  CHAR str1328[sizeof("SM_CXHSCROLL")];
  CHAR str1329[sizeof("WM_NOTIFY")];
  CHAR str1330[sizeof("GWL_STYLE")];
  CHAR str1331[sizeof("VK_W")];
  CHAR str1332[sizeof("ILC_PALETTE")];
  CHAR str1333[sizeof("EM_SCROLL")];
  CHAR str1334[sizeof("MB_ABORTRETRYIGNORE")];
  CHAR str1335[sizeof("TPM_NONOTIFY")];
  CHAR str1336[sizeof("WS_EX_MDICHILD")];
  CHAR str1337[sizeof("COLOR_BTNHILIGHT")];
  CHAR str1338[sizeof("LVS_EX_TRACKSELECT")];
  CHAR str1339[sizeof("DTS_TIMEFORMAT")];
  CHAR str1340[sizeof("SRCCOPY")];
  CHAR str1341[sizeof("WM_PENWINFIRST")];
  CHAR str1342[sizeof("HTBOTTOMRIGHT")];
  CHAR str1343[sizeof("CBN_SELCHANGE")];
  CHAR str1344[sizeof("SBM_SETRANGEREDRAW")];
  CHAR str1345[sizeof("VK_HANJA")];
  CHAR str1346[sizeof("SF_USECODEPAGE")];
  CHAR str1347[sizeof("DFCS_BUTTONCHECK")];
  CHAR str1348[sizeof("VK_NUMPAD1")];
  CHAR str1349[sizeof("TTF_CENTERTIP")];
  CHAR str1350[sizeof("BF_MIDDLE")];
  CHAR str1351[sizeof("LB_OKAY")];
  CHAR str1352[sizeof("VK_OEM_RESET")];
  CHAR str1353[sizeof("WM_ASKCBFORMATNAME")];
  CHAR str1354[sizeof("WM_RENDERFORMAT")];
  CHAR str1355[sizeof("OBJ_ENHMETADC")];
  CHAR str1356[sizeof("IDI_ERROR")];
  CHAR str1357[sizeof("VK_F3")];
  CHAR str1358[sizeof("CB_SETCURSEL")];
  CHAR str1359[sizeof("WM_PAINTCLIPBOARD")];
  CHAR str1360[sizeof("WM_DEVMODECHANGE")];
  CHAR str1361[sizeof("VK_8")];
  CHAR str1362[sizeof("VK_U")];
  CHAR str1363[sizeof("DFCS_SCROLLSIZEGRIP")];
  CHAR str1364[sizeof("TBTS_BOTTOM")];
  CHAR str1365[sizeof("VK_OEM_AX")];
  CHAR str1366[sizeof("VK_PA1")];
  CHAR str1367[sizeof("MB_ICONQUESTION")];
  CHAR str1368[sizeof("CSIDL_COMMON_ADMINTOOLS")];
  CHAR str1369[sizeof("BF_DIAGONAL_ENDTOPRIGHT")];
  CHAR str1370[sizeof("HTMAXBUTTON")];
  CHAR str1371[sizeof("SC_RESTORE")];
  CHAR str1372[sizeof("SF_TEXTIZED")];
  CHAR str1373[sizeof("VK_EXECUTE")];
  CHAR str1374[sizeof("VK_LEFT")];
  CHAR str1375[sizeof("IDC_SIZENWSE")];
  CHAR str1376[sizeof("WM_LBUTTONDOWN")];
  CHAR str1377[sizeof("SF_RTFVAL")];
  CHAR str1378[sizeof("VK_P")];
  CHAR str1379[sizeof("TPM_NOANIMATION")];
  CHAR str1380[sizeof("WS_EX_COMPOSITED")];
  CHAR str1381[sizeof("SM_IMMENABLED")];
  CHAR str1382[sizeof("TTDT_RESHOW")];
  CHAR str1383[sizeof("WS_CLIPCHILDREN")];
  CHAR str1384[sizeof("CSIDL_COMMON_APPDATA")];
  CHAR str1385[sizeof("BM_GETCHECK")];
  CHAR str1386[sizeof("CF_UNICODETEXT")];
  CHAR str1387[sizeof("SW_SHOWMINIMIZED")];
  CHAR str1388[sizeof("WM_IME_KEYUP")];
  CHAR str1389[sizeof("CSIDL_INTERNET")];
  CHAR str1390[sizeof("SM_XVIRTUALSCREEN")];
  CHAR str1391[sizeof("IDI_DEFAULTICON")];
  CHAR str1392[sizeof("OCR_IBEAM")];
  CHAR str1393[sizeof("VK_OEM_PERIOD")];
  CHAR str1394[sizeof("VK_XBUTTON1")];
  CHAR str1395[sizeof("ILD_DPISCALE")];
  CHAR str1396[sizeof("CBS_DROPDOWNLIST")];
  CHAR str1397[sizeof("BS_SOLID")];
  CHAR str1398[sizeof("FLOODFILLSURFACE")];
  CHAR str1399[sizeof("SIZE_MINIMIZED")];
  CHAR str1400[sizeof("OBM_DNARROWI")];
  CHAR str1401[sizeof("WM_NCMOUSEMOVE")];
  CHAR str1402[sizeof("HWND_NOTOPMOST")];
  CHAR str1403[sizeof("BS_ICON")];
  CHAR str1404[sizeof("CB_MULTIPLEADDSTRING")];
  CHAR str1405[sizeof("BDR_RAISEDINNER")];
  CHAR str1406[sizeof("WM_SYSCOLORCHANGE")];
  CHAR str1407[sizeof("WM_GETDLGCODE")];
  CHAR str1408[sizeof("STM_GETICON")];
  CHAR str1409[sizeof("PBM_SETSTEP")];
  CHAR str1410[sizeof("CF_METAFILEPICT")];
  CHAR str1411[sizeof("TPM_CENTERALIGN")];
  CHAR str1412[sizeof("PS_ENDCAP_SQUARE")];
  CHAR str1413[sizeof("COLOR_3DHILIGHT")];
  CHAR str1414[sizeof("EM_SETRECT")];
  CHAR str1415[sizeof("WM_INITMENUPOPUP")];
  CHAR str1416[sizeof("EM_SETIMESTATUS")];
  CHAR str1417[sizeof("OBM_RGARROWD")];
  CHAR str1418[sizeof("BS_AUTO3STATE")];
  CHAR str1419[sizeof("RDW_ALLCHILDREN")];
  CHAR str1420[sizeof("IDRETRY")];
  CHAR str1421[sizeof("WM_GETICON")];
  CHAR str1422[sizeof("STM_GETIMAGE")];
  CHAR str1423[sizeof("DSTINVERT")];
  CHAR str1424[sizeof("SM_CXMENUSIZE")];
  CHAR str1425[sizeof("VK_ESCAPE")];
  CHAR str1426[sizeof("SM_YVIRTUALSCREEN")];
  CHAR str1427[sizeof("SM_SECURE")];
  CHAR str1428[sizeof("CDDS_PREPAINT")];
  CHAR str1429[sizeof("ILS_SHADOW")];
  CHAR str1430[sizeof("NM_SETCURSOR")];
  CHAR str1431[sizeof("OBM_RGARROW")];
  CHAR str1432[sizeof("TVHT_ONITEMLABEL")];
  CHAR str1433[sizeof("LB_SETCOUNT")];
  CHAR str1434[sizeof("RBBS_HIDDEN")];
  CHAR str1435[sizeof("MF_BITMAP")];
  CHAR str1436[sizeof("IDC_IBEAM")];
  CHAR str1437[sizeof("SC_CONTEXTHELP")];
  CHAR str1438[sizeof("MB_RTLREADING")];
  CHAR str1439[sizeof("BS_DIBPATTERN8X8")];
  CHAR str1440[sizeof("SM_CMONITORS")];
  CHAR str1441[sizeof("MB_TOPMOST")];
  CHAR str1442[sizeof("LVS_LIST")];
  CHAR str1443[sizeof("OBM_UPARROW")];
  CHAR str1444[sizeof("TBSTYLE_REGISTERDROP")];
  CHAR str1445[sizeof("BF_DIAGONAL")];
  CHAR str1446[sizeof("SM_CYMINTRACK")];
  CHAR str1447[sizeof("WM_INPUTLANGCHANGEREQUEST")];
  CHAR str1448[sizeof("MF_BYPOSITION")];
  CHAR str1449[sizeof("ACS_AUTOPLAY")];
  CHAR str1450[sizeof("HWND_DESKTOP")];
  CHAR str1451[sizeof("CS_HREDRAW")];
  CHAR str1452[sizeof("TME_HOVER")];
  CHAR str1453[sizeof("PS_JOIN_ROUND")];
  CHAR str1454[sizeof("OBM_REDUCE")];
  CHAR str1455[sizeof("TTM_GETTIPTEXTCOLOR")];
  CHAR str1456[sizeof("WM_SYSCOMMAND")];
  CHAR str1457[sizeof("MB_HELP")];
  CHAR str1458[sizeof("VK_NUMPAD2")];
  CHAR str1459[sizeof("OCR_UP")];
  CHAR str1460[sizeof("LVS_EX_TWOCLICKACTIVATE")];
  CHAR str1461[sizeof("ILD_BLEND50")];
  CHAR str1462[sizeof("ENM_SCROLLEVENTS")];
  CHAR str1463[sizeof("TBSTATE_WRAP")];
  CHAR str1464[sizeof("GCL_HCURSOR")];
  CHAR str1465[sizeof("VK_F2")];
  CHAR str1466[sizeof("WM_SETFOCUS")];
  CHAR str1467[sizeof("VTA_BASELINE")];
  CHAR str1468[sizeof("CF_DSPTEXT")];
  CHAR str1469[sizeof("STM_SETIMAGE")];
  CHAR str1470[sizeof("WM_CHANGECBCHAIN")];
  CHAR str1471[sizeof("IDNO")];
  CHAR str1472[sizeof("BS_LEFTTEXT")];
  CHAR str1473[sizeof("GCL_HMODULE")];
  CHAR str1474[sizeof("SM_CYFRAME")];
  CHAR str1475[sizeof("CSIDL_PRINTERS")];
  CHAR str1476[sizeof("WM_KILLFOCUS")];
  CHAR str1477[sizeof("DFC_POPUPMENU")];
  CHAR str1478[sizeof("VK_OEM_PA1")];
  CHAR str1479[sizeof("COLOR_GRADIENTINACTIVECAPTION")];
  CHAR str1480[sizeof("SW_SHOWNA")];
  CHAR str1481[sizeof("VK_EXSEL")];
  CHAR str1482[sizeof("CSIDL_DRIVES")];
  CHAR str1483[sizeof("OBM_RESTORE")];
  CHAR str1484[sizeof("WM_LBUTTONUP")];
  CHAR str1485[sizeof("EM_GETRECT")];
  CHAR str1486[sizeof("CSIDL_COMMON_FAVORITES")];
  CHAR str1487[sizeof("BS_AUTORADIOBUTTON")];
  CHAR str1488[sizeof("CS_DROPSHADOW")];
  CHAR str1489[sizeof("WM_RENDERALLFORMATS")];
  CHAR str1490[sizeof("BS_PATTERN8X8")];
  CHAR str1491[sizeof("VK_F6")];
  CHAR str1492[sizeof("SBS_RIGHTALIGN")];
  CHAR str1493[sizeof("TPM_RETURNCMD")];
  CHAR str1494[sizeof("SM_MIDEASTENABLED")];
  CHAR str1495[sizeof("LB_SETANCHORINDEX")];
  CHAR str1496[sizeof("HTTOPRIGHT")];
  CHAR str1497[sizeof("BDR_RAISEDOUTER")];
  CHAR str1498[sizeof("DTS_SHOWNONE")];
  CHAR str1499[sizeof("BCM_SETTEXTMARGIN")];
  CHAR str1500[sizeof("BTNS_CHECKGROUP")];
  CHAR str1501[sizeof("SM_CLEANBOOT")];
  CHAR str1502[sizeof("LR_DEFAULTCOLOR")];
  CHAR str1503[sizeof("AW_HOR_POSITIVE")];
  CHAR str1504[sizeof("MF_UNHILITE")];
  CHAR str1505[sizeof("RBBS_CHILDEDGE")];
  CHAR str1506[sizeof("PS_DASHDOTDOT")];
  CHAR str1507[sizeof("WM_NEXTDLGCTL")];
  CHAR str1508[sizeof("SBM_ENABLE_ARROWS")];
  CHAR str1509[sizeof("COLORONCOLOR")];
  CHAR str1510[sizeof("WM_QUEUESYNC")];
  CHAR str1511[sizeof("WS_EX_RIGHT")];
  CHAR str1512[sizeof("WS_SIZEBOX")];
  CHAR str1513[sizeof("SM_CXMIN")];
  CHAR str1514[sizeof("TPM_RIGHTALIGN")];
  CHAR str1515[sizeof("WM_DRAWCLIPBOARD")];
  CHAR str1516[sizeof("SBS_SIZEBOXTOPLEFTALIGN")];
  CHAR str1517[sizeof("WM_IME_CHAR")];
  CHAR str1518[sizeof("CS_GLOBALCLASS")];
  CHAR str1519[sizeof("LBN_SELCANCEL")];
  CHAR str1520[sizeof("DT_RTLREADING")];
  CHAR str1521[sizeof("DT_TABSTOP")];
  CHAR str1522[sizeof("LVS_SINGLESEL")];
  CHAR str1523[sizeof("PS_ALTERNATE")];
  CHAR str1524[sizeof("HTGROWBOX")];
  CHAR str1525[sizeof("BS_PUSHBOX")];
  CHAR str1526[sizeof("MF_REMOVE")];
  CHAR str1527[sizeof("DFCS_CHECKED")];
  CHAR str1528[sizeof("IDI_APPLICATION")];
  CHAR str1529[sizeof("COLOR_DESKTOP")];
  CHAR str1530[sizeof("COLOR_BTNTEXT")];
  CHAR str1531[sizeof("LB_GETTOPINDEX")];
  CHAR str1532[sizeof("WS_TILED")];
  CHAR str1533[sizeof("VK_HANGUL")];
  CHAR str1534[sizeof("TTN_GETDISPINFO")];
  CHAR str1535[sizeof("ACN_STOP")];
  CHAR str1536[sizeof("NOTSRCCOPY")];
  CHAR str1537[sizeof("EN_ALIGNLTR")];
  CHAR str1538[sizeof("OIC_HAND")];
  CHAR str1539[sizeof("EN_LINK")];
  CHAR str1540[sizeof("BS_RIGHTBUTTON")];
  CHAR str1541[sizeof("R2_NOTMERGEPEN")];
  CHAR str1542[sizeof("PS_TYPE_MASK")];
  CHAR str1543[sizeof("WM_VSCROLL")];
  CHAR str1544[sizeof("RDW_NOFRAME")];
  CHAR str1545[sizeof("GW_HWNDLAST")];
  CHAR str1546[sizeof("CF_PALETTE")];
  CHAR str1547[sizeof("SM_CYMENU")];
  CHAR str1548[sizeof("TBSTYLE_LIST")];
  CHAR str1549[sizeof("BLACK_BRUSH")];
  CHAR str1550[sizeof("VK_F11")];
  CHAR str1551[sizeof("LVS_ALIGNMASK")];
  CHAR str1552[sizeof("CBN_EDITCHANGE")];
  CHAR str1553[sizeof("MB_MODEMASK")];
  CHAR str1554[sizeof("LBS_MULTIPLESEL")];
  CHAR str1555[sizeof("CF_WAVE")];
  CHAR str1556[sizeof("VK_RSHIFT")];
  CHAR str1557[sizeof("SC_ZOOM")];
  CHAR str1558[sizeof("LVS_TYPESTYLEMASK")];
  CHAR str1559[sizeof("BS_OWNERDRAW")];
  CHAR str1560[sizeof("IDB_STD_SMALL_COLOR")];
  CHAR str1561[sizeof("CLR_DEFAULT")];
  CHAR str1562[sizeof("SM_CYICON")];
  CHAR str1563[sizeof("HS_CROSS")];
  CHAR str1564[sizeof("STRETCH_DELETESCANS")];
  CHAR str1565[sizeof("TTN_NEEDTEXT")];
  CHAR str1566[sizeof("TPM_LEFTALIGN")];
  CHAR str1567[sizeof("WM_MEASUREITEM")];
  CHAR str1568[sizeof("SBS_TOPALIGN")];
  CHAR str1569[sizeof("WM_NOTIFYFORMAT")];
  CHAR str1570[sizeof("WS_SYSMENU")];
  CHAR str1571[sizeof("TPM_VCENTERALIGN")];
  CHAR str1572[sizeof("BTNS_GROUP")];
  CHAR str1573[sizeof("WM_SIZE")];
  CHAR str1574[sizeof("TBSTYLE_EX_DOUBLEBUFFER")];
  CHAR str1575[sizeof("DLGC_WANTALLKEYS")];
  CHAR str1576[sizeof("VK_X")];
  CHAR str1577[sizeof("WS_OVERLAPPEDWINDOW")];
  CHAR str1578[sizeof("OBJ_ENHMETAFILE")];
  CHAR str1579[sizeof("WM_CAPTURECHANGED")];
  CHAR str1580[sizeof("VK_BROWSER_BACK")];
  CHAR str1581[sizeof("CB_GETCOUNT")];
  CHAR str1582[sizeof("VK_OEM_4")];
  CHAR str1583[sizeof("SE_ERR_OOM")];
  CHAR str1584[sizeof("OBJ_EXTPEN")];
  CHAR str1585[sizeof("WM_ICONERASEBKGND")];
  CHAR str1586[sizeof("CBS_OWNERDRAWVARIABLE")];
  CHAR str1587[sizeof("LVIR_BOUNDS")];
  CHAR str1588[sizeof("OIC_INFORMATION")];
  CHAR str1589[sizeof("SRCERASE")];
  CHAR str1590[sizeof("MK_RBUTTON")];
  CHAR str1591[sizeof("VK_BROWSER_SEARCH")];
  CHAR str1592[sizeof("IDC_SIZEWE")];
  CHAR str1593[sizeof("WS_EX_TOOLWINDOW")];
  CHAR str1594[sizeof("CSIDL_COMMON_PICTURES")];
  CHAR str1595[sizeof("WM_RBUTTONDOWN")];
  CHAR str1596[sizeof("BN_PUSHED")];
  CHAR str1597[sizeof("CB_GETCOMBOBOXINFO")];
  CHAR str1598[sizeof("ILD_SELECTED")];
  CHAR str1599[sizeof("CB_GETLBTEXTLEN")];
  CHAR str1600[sizeof("DFCS_PUSHED")];
  CHAR str1601[sizeof("WM_IME_KEYDOWN")];
  CHAR str1602[sizeof("ENM_KEYEVENTS")];
  CHAR str1603[sizeof("CB_SETLOCALE")];
  CHAR str1604[sizeof("COLOR_MENUTEXT")];
  CHAR str1605[sizeof("COLOR_ACTIVEBORDER")];
  CHAR str1606[sizeof("LBS_EXTENDEDSEL")];
  CHAR str1607[sizeof("VK_OEM_ENLW")];
  CHAR str1608[sizeof("DT_EXPANDTABS")];
  CHAR str1609[sizeof("DLGC_WANTTAB")];
  CHAR str1610[sizeof("TTM_ACTIVATE")];
  CHAR str1611[sizeof("VK_C")];
  CHAR str1612[sizeof("BS_FLAT")];
  CHAR str1613[sizeof("MA_ACTIVATEANDEAT")];
  CHAR str1614[sizeof("CBS_DROPDOWN")];
  CHAR str1615[sizeof("ENM_LINK")];
  CHAR str1616[sizeof("HOVER_DEFAULT")];
  CHAR str1617[sizeof("CSIDL_CONNECTIONS")];
  CHAR str1618[sizeof("NM_RETURN")];
  CHAR str1619[sizeof("SW_SHOWMAXIMIZED")];
  CHAR str1620[sizeof("CF_DIF")];
  CHAR str1621[sizeof("ILS_NORMAL")];
  CHAR str1622[sizeof("SF_RTFNOOBJS")];
  CHAR str1623[sizeof("VK_PROCESSKEY")];
  CHAR str1624[sizeof("WM_COMMNOTIFY")];
  CHAR str1625[sizeof("BDR_SUNKEN")];
  CHAR str1626[sizeof("WM_PASTE")];
  CHAR str1627[sizeof("WHITE_BRUSH")];
  CHAR str1628[sizeof("BF_SOFT")];
  CHAR str1629[sizeof("CDDS_POSTPAINT")];
  CHAR str1630[sizeof("VK_S")];
  CHAR str1631[sizeof("WM_EXITMENULOOP")];
  CHAR str1632[sizeof("PS_ENDCAP_FLAT")];
  CHAR str1633[sizeof("WM_QUIT")];
  CHAR str1634[sizeof("ENM_LOWFIRTF")];
  CHAR str1635[sizeof("COLOR_HOTLIGHT")];
  CHAR str1636[sizeof("ES_NOHIDESEL")];
  CHAR str1637[sizeof("LB_SETCARETINDEX")];
  CHAR str1638[sizeof("LVS_EX_GRIDLINES")];
  CHAR str1639[sizeof("SM_CYSMSIZE")];
  CHAR str1640[sizeof("NULLREGION")];
  CHAR str1641[sizeof("MB_RIGHT")];
  CHAR str1642[sizeof("WM_ENTERSIZEMOVE")];
  CHAR str1643[sizeof("VK_R")];
  CHAR str1644[sizeof("NM_RDBLCLK")];
  CHAR str1645[sizeof("VK_F14")];
  CHAR str1646[sizeof("WM_NCRBUTTONUP")];
  CHAR str1647[sizeof("MK_LBUTTON")];
  CHAR str1648[sizeof("TPM_HORPOSANIMATION")];
  CHAR str1649[sizeof("TTM_SETDELAYTIME")];
  CHAR str1650[sizeof("LVS_SORTDESCENDING")];
  CHAR str1651[sizeof("WM_GETFONT")];
  CHAR str1652[sizeof("OBM_DNARROW")];
  CHAR str1653[sizeof("LB_GETTEXT")];
  CHAR str1654[sizeof("TBSTATE_PRESSED")];
  CHAR str1655[sizeof("CF_PRIVATELAST")];
  CHAR str1656[sizeof("IDI_EXCLAMATION")];
  CHAR str1657[sizeof("OIC_SAMPLE")];
  CHAR str1658[sizeof("LBS_COMBOBOX")];
  CHAR str1659[sizeof("SBS_HORZ")];
  CHAR str1660[sizeof("SM_CYFIXEDFRAME")];
  CHAR str1661[sizeof("SWP_DRAWFRAME")];
  CHAR str1662[sizeof("VK_NUMPAD7")];
  CHAR str1663[sizeof("EM_GETSEL")];
  CHAR str1664[sizeof("TPM_RECURSE")];
  CHAR str1665[sizeof("VK_SLEEP")];
  CHAR str1666[sizeof("SM_CXSCREEN")];
  CHAR str1667[sizeof("SE_ERR_SHARE")];
  CHAR str1668[sizeof("DT_SINGLELINE")];
  CHAR str1669[sizeof("SM_CARETBLINKINGENABLED")];
  CHAR str1670[sizeof("EM_GETFIRSTVISIBLELINE")];
  CHAR str1671[sizeof("GT_NOHIDDENTEXT")];
  CHAR str1672[sizeof("MB_SERVICE_NOTIFICATION_NT3X")];
  CHAR str1673[sizeof("WM_ENDSESSION")];
  CHAR str1674[sizeof("OCR_SIZENESW")];
  CHAR str1675[sizeof("IDC_WAIT")];
  CHAR str1676[sizeof("LB_GETTEXTLEN")];
  CHAR str1677[sizeof("PS_DASHDOT")];
  CHAR str1678[sizeof("TVHT_ABOVE")];
  CHAR str1679[sizeof("ILC_PERITEMMIRROR")];
  CHAR str1680[sizeof("LVS_SHOWSELALWAYS")];
  CHAR str1681[sizeof("VK_OEM_3")];
  CHAR str1682[sizeof("WM_MDIDESTROY")];
  CHAR str1683[sizeof("SM_CYMINIMIZED")];
  CHAR str1684[sizeof("SM_CXSIZE")];
  CHAR str1685[sizeof("BS_RIGHT")];
  CHAR str1686[sizeof("CP_OEMCP")];
  CHAR str1687[sizeof("WM_ENTERMENULOOP")];
  CHAR str1688[sizeof("SBT_POPOUT")];
  CHAR str1689[sizeof("OCR_NO")];
  CHAR str1690[sizeof("WM_DEADCHAR")];
  CHAR str1691[sizeof("TBSTYLE_ALTDRAG")];
  CHAR str1692[sizeof("TTF_TRACK")];
  CHAR str1693[sizeof("VK_ICO_CLEAR")];
  CHAR str1694[sizeof("NM_RDOWN")];
  CHAR str1695[sizeof("DT_EXTERNALLEADING")];
  CHAR str1696[sizeof("OBM_LFARROWD")];
  CHAR str1697[sizeof("TTF_IDISHWND")];
  CHAR str1698[sizeof("VK_D")];
  CHAR str1699[sizeof("GW_CHILD")];
  CHAR str1700[sizeof("DFCS_TRANSPARENT")];
  CHAR str1701[sizeof("VK_G")];
  CHAR str1702[sizeof("EM_SETREADONLY")];
  CHAR str1703[sizeof("CSIDL_MYDOCUMENTS")];
  CHAR str1704[sizeof("DT_RIGHT")];
  CHAR str1705[sizeof("WM_NCLBUTTONDOWN")];
  CHAR str1706[sizeof("WM_CLEAR")];
  CHAR str1707[sizeof("LBS_STANDARD")];
  CHAR str1708[sizeof("SBT_NOTABPARSING")];
  CHAR str1709[sizeof("EM_SETMODIFY")];
  CHAR str1710[sizeof("LB_SETSEL")];
  CHAR str1711[sizeof("VK_NUMPAD6")];
  CHAR str1712[sizeof("WM_SYSDEADCHAR")];
  CHAR str1713[sizeof("NM_HOVER")];
  CHAR str1714[sizeof("IDOK")];
  CHAR str1715[sizeof("CB_FINDSTRINGEXACT")];
  CHAR str1716[sizeof("BS_TEXT")];
  CHAR str1717[sizeof("WM_NCDESTROY")];
  CHAR str1718[sizeof("SC_MINIMIZE")];
  CHAR str1719[sizeof("MK_XBUTTON1")];
  CHAR str1720[sizeof("DFCS_SCROLLSIZEGRIPRIGHT")];
  CHAR str1721[sizeof("CBS_HASSTRINGS")];
  CHAR str1722[sizeof("OCR_SIZENS")];
  CHAR str1723[sizeof("WM_GETTEXTLENGTH")];
  CHAR str1724[sizeof("SM_TABLETPC")];
  CHAR str1725[sizeof("GT_USECRLF")];
  CHAR str1726[sizeof("ES_NUMBER")];
  CHAR str1727[sizeof("CBES_EX_PATHWORDBREAKPROC")];
  CHAR str1728[sizeof("CB_SETTOPINDEX")];
  CHAR str1729[sizeof("CB_SHOWDROPDOWN")];
  CHAR str1730[sizeof("WS_EX_DLGMODALFRAME")];
  CHAR str1731[sizeof("EM_LINELENGTH")];
  CHAR str1732[sizeof("LB_GETSELCOUNT")];
  CHAR str1733[sizeof("LVSIL_SMALL")];
  CHAR str1734[sizeof("BS_DIBPATTERNPT")];
  CHAR str1735[sizeof("RDW_UPDATENOW")];
  CHAR str1736[sizeof("VK_A")];
  CHAR str1737[sizeof("DTS_UPDOWN")];
  CHAR str1738[sizeof("WM_SETREDRAW")];
  CHAR str1739[sizeof("BS_TOP")];
  CHAR str1740[sizeof("WM_CUT")];
  CHAR str1741[sizeof("WM_DEVICECHANGE")];
  CHAR str1742[sizeof("ENM_PAGECHANGE")];
  CHAR str1743[sizeof("SM_CYEDGE")];
  CHAR str1744[sizeof("HTMINBUTTON")];
  CHAR str1745[sizeof("EM_REPLACESEL")];
  CHAR str1746[sizeof("COLOR_GRADIENTACTIVECAPTION")];
  CHAR str1747[sizeof("DS_SETFONT")];
  CHAR str1748[sizeof("GW_HWNDFIRST")];
  CHAR str1749[sizeof("IDTIMEOUT")];
  CHAR str1750[sizeof("IDC_SIZENS")];
  CHAR str1751[sizeof("SWP_NOREPOSITION")];
  CHAR str1752[sizeof("EM_SETMARGINS")];
  CHAR str1753[sizeof("WM_XBUTTONDOWN")];
  CHAR str1754[sizeof("BF_DIAGONAL_ENDTOPLEFT")];
  CHAR str1755[sizeof("WM_MOUSEHOVER")];
  CHAR str1756[sizeof("IDABORT")];
  CHAR str1757[sizeof("WM_IME_REQUEST")];
  CHAR str1758[sizeof("SW_RESTORE")];
  CHAR str1759[sizeof("BTNS_SHOWTEXT")];
  CHAR str1760[sizeof("RBBS_HIDETITLE")];
  CHAR str1761[sizeof("VK_VOLUME_UP")];
  CHAR str1762[sizeof("WM_MENUGETOBJECT")];
  CHAR str1763[sizeof("RGN_MAX")];
  CHAR str1764[sizeof("VK_CONVERT")];
  CHAR str1765[sizeof("WM_NCMBUTTONDOWN")];
  CHAR str1766[sizeof("SW_SHOWNORMAL")];
  CHAR str1767[sizeof("PBM_STEPIT")];
  CHAR str1768[sizeof("TTDT_AUTOPOP")];
  CHAR str1769[sizeof("TPM_LEFTBUTTON")];
  CHAR str1770[sizeof("OBM_BTNCORNERS")];
  CHAR str1771[sizeof("IDC_HSPLIT")];
  CHAR str1772[sizeof("SC_KEYMENU")];
  CHAR str1773[sizeof("WM_WTSSESSION_CHANGE")];
  CHAR str1774[sizeof("TBSTYLE_BUTTON")];
  CHAR str1775[sizeof("GW_HWNDNEXT")];
  CHAR str1776[sizeof("OBM_REDUCED")];
  CHAR str1777[sizeof("DFCS_BUTTONRADIOMASK")];
  CHAR str1778[sizeof("CSIDL_COMMON_OEM_LINKS")];
  CHAR str1779[sizeof("NM_KEYDOWN")];
  CHAR str1780[sizeof("EN_ALIGN_RTL_EC")];
  CHAR str1781[sizeof("WS_DISABLED")];
  CHAR str1782[sizeof("DFCS_INACTIVE")];
  CHAR str1783[sizeof("MB_ICONWARNING")];
  CHAR str1784[sizeof("VK_F")];
  CHAR str1785[sizeof("WS_MAXIMIZEBOX")];
  CHAR str1786[sizeof("EN_OBJECTPOSITIONS")];
  CHAR str1787[sizeof("VK_0")];
  CHAR str1788[sizeof("VK_BROWSER_FAVORITES")];
  CHAR str1789[sizeof("WM_EXITSIZEMOVE")];
  CHAR str1790[sizeof("WM_DESTROY")];
  CHAR str1791[sizeof("NULL_BRUSH")];
  CHAR str1792[sizeof("HDS_HOTTRACK")];
  CHAR str1793[sizeof("DFCS_CAPTIONHELP")];
  CHAR str1794[sizeof("WM_KEYDOWN")];
  CHAR str1795[sizeof("LBS_NOREDRAW")];
  CHAR str1796[sizeof("WM_HELP")];
  CHAR str1797[sizeof("SM_REMOTECONTROL")];
  CHAR str1798[sizeof("CSIDL_MYMUSIC")];
  CHAR str1799[sizeof("LR_COPYRETURNORG")];
  CHAR str1800[sizeof("MB_ICONSTOP")];
  CHAR str1801[sizeof("DLGC_WANTCHARS")];
  CHAR str1802[sizeof("TTN_POP")];
  CHAR str1803[sizeof("MA_NOACTIVATEANDEAT")];
  CHAR str1804[sizeof("TBSTYLE_EX_DRAWDDARROWS")];
  CHAR str1805[sizeof("ES_AUTOVSCROLL")];
  CHAR str1806[sizeof("WM_KEYFIRST")];
  CHAR str1807[sizeof("NOTSRCERASE")];
  CHAR str1808[sizeof("WS_POPUPWINDOW")];
  CHAR str1809[sizeof("VK_F7")];
  CHAR str1810[sizeof("SRCAND")];
  CHAR str1811[sizeof("ES_LEFT")];
  CHAR str1812[sizeof("VK_F13")];
  CHAR str1813[sizeof("WS_TABSTOP")];
  CHAR str1814[sizeof("CBN_EDITUPDATE")];
  CHAR str1815[sizeof("PATPAINT")];
  CHAR str1816[sizeof("WM_WINDOWPOSCHANGING")];
  CHAR str1817[sizeof("LVS_EX_INFOTIP")];
  CHAR str1818[sizeof("SC_MOUSEMENU")];
  CHAR str1819[sizeof("BN_UNPUSHED")];
  CHAR str1820[sizeof("NM_DBLCLK")];
  CHAR str1821[sizeof("WM_QUERYOPEN")];
  CHAR str1822[sizeof("IMAGE_ENHMETAFILE")];
  CHAR str1823[sizeof("MF_SEPARATOR")];
  CHAR str1824[sizeof("CDDS_ITEMPOSTPAINT")];
  CHAR str1825[sizeof("SM_SHOWSOUNDS")];
  CHAR str1826[sizeof("IDYES")];
  CHAR str1827[sizeof("VK_OEM_2")];
  CHAR str1828[sizeof("LBN_ERRSPACE")];
  CHAR str1829[sizeof("HDS_FILTERBAR")];
  CHAR str1830[sizeof("RGN_DIFF")];
  CHAR str1831[sizeof("OBM_UPARROWD")];
  CHAR str1832[sizeof("CBN_SELENDOK")];
  CHAR str1833[sizeof("ILD_BLEND")];
  CHAR str1834[sizeof("LVS_NOCOLUMNHEADER")];
  CHAR str1835[sizeof("COLOR_INACTIVECAPTION")];
  CHAR str1836[sizeof("CB_SELECTSTRING")];
  CHAR str1837[sizeof("WM_MDIGETACTIVE")];
  CHAR str1838[sizeof("VK_BACK")];
  CHAR str1839[sizeof("LB_DELETESTRING")];
  CHAR str1840[sizeof("SC_CLOSE")];
  CHAR str1841[sizeof("VK_VOLUME_MUTE")];
  CHAR str1842[sizeof("SM_CYMENUCHECK")];
  CHAR str1843[sizeof("VK_UP")];
  CHAR str1844[sizeof("TVGN_CHILD")];
  CHAR str1845[sizeof("CSIDL_PRINTHOOD")];
  CHAR str1846[sizeof("TTM_SETTOOLINFO")];
  CHAR str1847[sizeof("VK_OEM_102")];
  CHAR str1848[sizeof("CS_IME")];
  CHAR str1849[sizeof("CB_FINDSTRING")];
  CHAR str1850[sizeof("TBSTYLE_GROUP")];
  CHAR str1851[sizeof("SE_ERR_DDEBUSY")];
  CHAR str1852[sizeof("VK_SUBTRACT")];
  CHAR str1853[sizeof("CSIDL_SYSTEM")];
  CHAR str1854[sizeof("PS_INSIDEFRAME")];
  CHAR str1855[sizeof("VK_OEM_JUMP")];
  CHAR str1856[sizeof("CDDS_POSTERASE")];
  CHAR str1857[sizeof("LB_RESETCONTENT")];
  CHAR str1858[sizeof("SM_CYHSCROLL")];
  CHAR str1859[sizeof("WM_COMMAND")];
  CHAR str1860[sizeof("GWL_HINSTANCE")];
  CHAR str1861[sizeof("SE_ERR_DLLNOTFOUND")];
  CHAR str1862[sizeof("CDDS_ITEM")];
  CHAR str1863[sizeof("OBM_CHECK")];
  CHAR str1864[sizeof("DFCS_FLAT")];
  CHAR str1865[sizeof("PS_GEOMETRIC")];
  CHAR str1866[sizeof("VK_RIGHT")];
  CHAR str1867[sizeof("BTNS_DROPDOWN")];
  CHAR str1868[sizeof("LVSIL_NORMAL")];
  CHAR str1869[sizeof("MF_MENUBARBREAK")];
  CHAR str1870[sizeof("LBS_NODATA")];
  CHAR str1871[sizeof("WM_MBUTTONDOWN")];
  CHAR str1872[sizeof("SM_CXICONSPACING")];
  CHAR str1873[sizeof("OBJ_METADC")];
  CHAR str1874[sizeof("GCL_CBCLSEXTRA")];
  CHAR str1875[sizeof("SIZE_MAXIMIZED")];
  CHAR str1876[sizeof("ILD_OVERLAYMASK")];
  CHAR str1877[sizeof("MB_DEFBUTTON3")];
  CHAR str1878[sizeof("WM_UNICHAR")];
  CHAR str1879[sizeof("BS_MULTILINE")];
  CHAR str1880[sizeof("CSIDL_RESOURCES")];
  CHAR str1881[sizeof("VK_OEM_PA2")];
  CHAR str1882[sizeof("WM_TABLET_FIRST")];
  CHAR str1883[sizeof("DS_SYSMODAL")];
  CHAR str1884[sizeof("MF_DELETE")];
  CHAR str1885[sizeof("WS_EX_WINDOWEDGE")];
  CHAR str1886[sizeof("BM_GETIMAGE")];
  CHAR str1887[sizeof("COLOR_3DHIGHLIGHT")];
  CHAR str1888[sizeof("TBTS_LEFT")];
  CHAR str1889[sizeof("WM_MDINEXT")];
  CHAR str1890[sizeof("LR_LOADFROMFILE")];
  CHAR str1891[sizeof("EDGE_ETCHED")];
  CHAR str1892[sizeof("BF_DIAGONAL_ENDBOTTOMLEFT")];
  CHAR str1893[sizeof("ENM_PROTECTED")];
  CHAR str1894[sizeof("BS_TYPEMASK")];
  CHAR str1895[sizeof("TA_RTLREADING")];
  CHAR str1896[sizeof("HTZOOM")];
  CHAR str1897[sizeof("TBSTATE_MARKED")];
  CHAR str1898[sizeof("VK_HOME")];
  CHAR str1899[sizeof("CSIDL_FLAG_PER_USER_INIT")];
  CHAR str1900[sizeof("ES_MULTILINE")];
  CHAR str1901[sizeof("ODT_TAB")];
  CHAR str1902[sizeof("LB_SETITEMDATA")];
  CHAR str1903[sizeof("CBN_CLOSEUP")];
  CHAR str1904[sizeof("VK_MEDIA_NEXT_TRACK")];
  CHAR str1905[sizeof("EM_SETLIMITTEXT")];
  CHAR str1906[sizeof("SC_ICON")];
  CHAR str1907[sizeof("BS_BOTTOM")];
  CHAR str1908[sizeof("TTM_TRACKPOSITION")];
  CHAR str1909[sizeof("CBN_KILLFOCUS")];
  CHAR str1910[sizeof("CBN_ERRSPACE")];
  CHAR str1911[sizeof("MF_HELP")];
  CHAR str1912[sizeof("WA_CLICKACTIVE")];
  CHAR str1913[sizeof("PS_DASH")];
  CHAR str1914[sizeof("EN_DROPFILES")];
  CHAR str1915[sizeof("WM_ACTIVATEAPP")];
  CHAR str1916[sizeof("ODS_DEFAULT")];
  CHAR str1917[sizeof("VK_OEM_6")];
  CHAR str1918[sizeof("SBM_SETPOS")];
  CHAR str1919[sizeof("SM_CXDRAG")];
  CHAR str1920[sizeof("EN_ALIGNRTL")];
  CHAR str1921[sizeof("WM_MOUSEACTIVATE")];
  CHAR str1922[sizeof("LBN_DBLCLK")];
  CHAR str1923[sizeof("VK_V")];
  CHAR str1924[sizeof("BF_RECT")];
  CHAR str1925[sizeof("WM_TABLET_LAST")];
  CHAR str1926[sizeof("SM_CXSIZEFRAME")];
  CHAR str1927[sizeof("VK_L")];
  CHAR str1928[sizeof("BTNS_WHOLEDROPDOWN")];
  CHAR str1929[sizeof("SM_CXFULLSCREEN")];
  CHAR str1930[sizeof("VK_OEM_1")];
  CHAR str1931[sizeof("GCL_HBRBACKGROUND")];
  CHAR str1932[sizeof("LB_GETANCHORINDEX")];
  CHAR str1933[sizeof("WM_NCRBUTTONDBLCLK")];
  CHAR str1934[sizeof("CF_RIFF")];
  CHAR str1935[sizeof("COLOR_MENUBAR")];
  CHAR str1936[sizeof("TTM_DELTOOL")];
  CHAR str1937[sizeof("CBN_SELENDCANCEL")];
  CHAR str1938[sizeof("CSIDL_SENDTO")];
  CHAR str1939[sizeof("LVS_EX_SNAPTOGRID")];
  CHAR str1940[sizeof("VK_HELP")];
  CHAR str1941[sizeof("VK_5")];
  CHAR str1942[sizeof("OBM_CLOSE")];
  CHAR str1943[sizeof("VTA_TOP")];
  CHAR str1944[sizeof("HTHSCROLL")];
  CHAR str1945[sizeof("DS_NOFAILCREATE")];
  CHAR str1946[sizeof("IDB_HIST_LARGE_COLOR")];
  CHAR str1947[sizeof("CLR_NONE")];
  CHAR str1948[sizeof("LB_GETCURSEL")];
  CHAR str1949[sizeof("LR_LOADTRANSPARENT")];
  CHAR str1950[sizeof("TVGN_DROPHILITE")];
  CHAR str1951[sizeof("SM_CXFIXEDFRAME")];
  CHAR str1952[sizeof("CS_PARENTDC")];
  CHAR str1953[sizeof("WM_QUERYDRAGICON")];
  CHAR str1954[sizeof("HTVSCROLL")];
  CHAR str1955[sizeof("EN_DRAGDROPDONE")];
  CHAR str1956[sizeof("SE_ERR_ACCESSDENIED")];
  CHAR str1957[sizeof("TME_CANCEL")];
  CHAR str1958[sizeof("WM_CLOSE")];
  CHAR str1959[sizeof("MCSC_TRAILINGTEXT")];
  CHAR str1960[sizeof("CP_ACP")];
  CHAR str1961[sizeof("MCS_NOTODAYCIRCLE")];
  CHAR str1962[sizeof("BLACKONWHITE")];
  CHAR str1963[sizeof("SBS_SIZEGRIP")];
  CHAR str1964[sizeof("SC_MAXIMIZE")];
  CHAR str1965[sizeof("LBS_MULTICOLUMN")];
  CHAR str1966[sizeof("TTM_GETTOOLCOUNT")];
  CHAR str1967[sizeof("CF_HDROP")];
  CHAR str1968[sizeof("PBM_DELTAPOS")];
  CHAR str1969[sizeof("WM_IME_NOTIFY")];
  CHAR str1970[sizeof("SW_SHOWDEFAULT")];
  CHAR str1971[sizeof("CBS_NOINTEGRALHEIGHT")];
  CHAR str1972[sizeof("WM_MOUSEWHEEL")];
  CHAR str1973[sizeof("WM_MBUTTONDBLCLK")];
  CHAR str1974[sizeof("COLOR_BTNHIGHLIGHT")];
  CHAR str1975[sizeof("SE_ERR_FNF")];
  CHAR str1976[sizeof("TBSTYLE_CUSTOMERASE")];
  CHAR str1977[sizeof("DS_3DLOOK")];
  CHAR str1978[sizeof("TTM_UPDATETIPTEXT")];
  CHAR str1979[sizeof("TTM_RELAYEVENT")];
  CHAR str1980[sizeof("OBJ_COLORSPACE")];
  CHAR str1981[sizeof("LB_SETTABSTOPS")];
  CHAR str1982[sizeof("WM_DISPLAYCHANGE")];
  CHAR str1983[sizeof("CB_SETHORIZONTALEXTENT")];
  CHAR str1984[sizeof("EM_SETHANDLE")];
  CHAR str1985[sizeof("COLOR_MENUHILIGHT")];
  CHAR str1986[sizeof("MF_MENUBREAK")];
  CHAR str1987[sizeof("CB_GETEXTENDEDUI")];
  CHAR str1988[sizeof("VK_NUMPAD5")];
  CHAR str1989[sizeof("HTBOTTOMLEFT")];
  CHAR str1990[sizeof("ACN_START")];
  CHAR str1991[sizeof("VK_LBUTTON")];
  CHAR str1992[sizeof("SWP_FRAMECHANGED")];
  CHAR str1993[sizeof("MF_BYCOMMAND")];
  CHAR str1994[sizeof("ODT_HEADER")];
  CHAR str1995[sizeof("GWL_HWNDPARENT")];
  CHAR str1996[sizeof("OCR_SIZEALL")];
  CHAR str1997[sizeof("SB_LINERIGHT")];
  CHAR str1998[sizeof("CF_OWNERDISPLAY")];
  CHAR str1999[sizeof("COLOR_WINDOWTEXT")];
  CHAR str2000[sizeof("IDI_QUESTION")];
  CHAR str2001[sizeof("VK_MBUTTON")];
  CHAR str2002[sizeof("VK_SPACE")];
  CHAR str2003[sizeof("COLOR_HIGHLIGHT")];
  CHAR str2004[sizeof("CBN_DROPDOWN")];
  CHAR str2005[sizeof("WM_PALETTECHANGED")];
  CHAR str2006[sizeof("WS_EX_APPWINDOW")];
  CHAR str2007[sizeof("DLGC_WANTARROWS")];
  CHAR str2008[sizeof("OCR_SIZENWSE")];
  CHAR str2009[sizeof("LTGRAY_BRUSH")];
  CHAR str2010[sizeof("EN_OLEOPFAILED")];
  CHAR str2011[sizeof("BS_DIBPATTERN")];
  CHAR str2012[sizeof("ODS_GRAYED")];
  CHAR str2013[sizeof("CBES_EX_NOEDITIMAGEINDENT")];
  CHAR str2014[sizeof("BS_NOTIFY")];
  CHAR str2015[sizeof("CBS_SIMPLE")];
  CHAR str2016[sizeof("ODS_SELECTED")];
  CHAR str2017[sizeof("BM_SETCHECK")];
  CHAR str2018[sizeof("CS_DBLCLKS")];
  CHAR str2019[sizeof("DS_CONTEXTHELP")];
  CHAR str2020[sizeof("HTTRANSPARENT")];
  CHAR str2021[sizeof("SB_LEFT")];
  CHAR str2022[sizeof("SC_PREVWINDOW")];
  CHAR str2023[sizeof("MCSC_BACKGROUND")];
  CHAR str2024[sizeof("LB_GETLOCALE")];
  CHAR str2025[sizeof("VK_CONTROL")];
  CHAR str2026[sizeof("LB_SETITEMHEIGHT")];
  CHAR str2027[sizeof("WS_EX_TOPMOST")];
  CHAR str2028[sizeof("CB_GETDROPPEDCONTROLRECT")];
  CHAR str2029[sizeof("OBM_UPARROWI")];
  CHAR str2030[sizeof("VK_EREOF")];
};

/* initialise string table */
static const struct stringpool_t stringpool_contents = {
  "CDRF_NEWFONT",
  "WM_IME_COMPOSITION",
  "WM_NCXBUTTONUP",
  "LR_COPYDELETEORG",
  "WS_VSCROLL",
  "BDR_OUTER",
  "VK_T",
  "ILD_MASK",
  "OPAQUE",
  "TBSTYLE_TRANSPARENT",
  "GA_ROOT",
  "HWND_TOPMOST",
  "VK_OEM_COMMA",
  "WM_MOUSELAST",
  "DTS_LONGDATEFORMAT",
  "ENM_OBJECTPOSITIONS",
  "DT_CALCRECT",
  "PATCOPY",
  "ILD_PRESERVEALPHA",
  "RDW_VALIDATE",
  "LVS_EX_REGIONAL",
  "COLOR_BTNSHADOW",
  "TBSTATE_CHECKED",
  "VK_F18",
  "ICON_SMALL",
  "TBSTYLE_FLAT",
  "CBS_DISABLENOSCROLL",
  "TTM_GETCURRENTTOOL",
  "IDI_WINLOGO",
  "LB_GETITEMDATA",
  "IDC_HAND",
  "RDW_ERASENOW",
  "FLOODFILLBORDER",
  "MB_OK",
  "TVHT_ONITEMBUTTON",
  "BS_PUSHLIKE",
  "HTMENU",
  "PS_SOLID",
  "WS_POPUP",
  "DFCS_ADJUSTRECT",
  "IDC_SIZENESW",
  "GA_ROOTOWNER",
  "NULL_PEN",
  "WM_USER",
  "MB_ICONERROR",
  "OBJ_DC",
  "VK_HANGEUL",
  "WM_NCACTIVATE",
  "WM_MDIREFRESHMENU",
  "WM_NULL",
  "TBSTYLE_SEP",
  "SM_CYSIZE",
  "WM_WININICHANGE",
  "SM_NETWORK",
  "CDRF_NOTIFYPOSTERASE",
  "BF_LEFT",
  "TRANSPARENT",
  "VK_ATTN",
  "OBM_MNARROW",
  "HTLEFT",
  "EM_GETWORDBREAKPROC",
  "TPM_VERPOSANIMATION",
  "CF_TEXT",
  "WM_THEMECHANGED",
  "LB_SETTOPINDEX",
  "PBM_SETRANGE32",
  "LB_INSERTSTRING",
  "MF_GRAYED",
  "MB_DEFBUTTON2",
  "TVGN_PARENT",
  "HTBOTTOM",
  "VK_SELECT",
  "STN_DISABLE",
  "PS_ENDCAP_MASK",
  "WA_ACTIVE",
  "ILS_GLOW",
  "WS_EX_CONTROLPARENT",
  "IDB_VIEW_LARGE_COLOR",
  "LB_MULTIPLEADDSTRING",
  "WS_TILEDWINDOW",
  "ODA_SELECT",
  "SM_MEDIACENTER",
  "COLOR_APPWORKSPACE",
  "MB_DEFAULT_DESKTOP_ONLY",
  "LR_MONOCHROME",
  "MF_SYSMENU",
  "SC_MONITORPOWER",
  "CS_VREDRAW",
  "EM_CHARFROMPOS",
  "MERGECOPY",
  "TTF_RTLREADING",
  "SWP_SHOWWINDOW",
  "WM_NCMOUSEHOVER",
  "WS_EX_TRANSPARENT",
  "WS_EX_CONTEXTHELP",
  "LVS_EX_BORDERSELECT",
  "CSIDL_DESKTOPDIRECTORY",
  "LR_LOADMAP3DCOLORS",
  "HTREDUCE",
  "LVIS_ACTIVATING",
  "OIC_QUES",
  "TVHT_TOLEFT",
  "VK_CLEAR",
  "ENM_SCROLL",
  "IDCANCEL",
  "HS_DIAGCROSS",
  "CF_LOCALE",
  "LBN_SELCHANGE",
  "GWL_EXSTYLE",
  "GW_HWNDPREV",
  "ES_UPPERCASE",
  "COLOR_INFOBK",
  "CDRF_NOTIFYSUBITEMDRAW",
  "LB_GETLISTBOXINFO",
  "WM_DESTROYCLIPBOARD",
  "R2_MASKPEN",
  "TA_MASK",
  "NOMIRRORBITMAP",
  "PBM_SETBARCOLOR",
  "SM_SERVERR2",
  "GCW_ATOM",
  "CSIDL_FLAG_NO_ALIAS",
  "WS_MINIMIZEBOX",
  "LB_DIR",
  "LVIR_LABEL",
  "EM_GETHANDLE",
  "WS_BORDER",
  "GT_RAWTEXT",
  "PS_USERSTYLE",
  "WM_MOUSEFIRST",
  "LVS_OWNERDRAWFIXED",
  "SM_DEBUG",
  "VK_BROWSER_STOP",
  "CB_GETLBTEXT",
  "DFCS_CAPTIONRESTORE",
  "CSIDL_FONTS",
  "TTF_TRANSPARENT",
  "TBSTYLE_TOOLTIPS",
  "SC_NEXTWINDOW",
  "SF_TEXT",
  "CWP_ALL",
  "SWP_NOZORDER",
  "LR_SHARED",
  "EM_UNDO",
  "OBM_COMBO",
  "MCS_NOTODAY",
  "STN_CLICKED",
  "SM_MOUSEPRESENT",
  "SM_CXFRAME",
  "SC_SCREENSAVE",
  "SC_TASKLIST",
  "CBS_OEMCONVERT",
  "SC_HSCROLL",
  "LVS_NOSORTHEADER",
  "BDR_SUNKENINNER",
  "TVGN_NEXT",
  "WM_COPY",
  "LVS_EX_SIMPLESELECT",
  "LVS_EX_UNDERLINECOLD",
  "WM_APPCOMMAND",
  "TVGN_ROOT",
  "EN_KILLFOCUS",
  "OBJ_BITMAP",
  "BTNS_SEP",
  "TTF_DI_SETITEM",
  "CSIDL_MYPICTURES",
  "EDGE_SUNKEN",
  "CP_MACCP",
  "LBS_OWNERDRAWVARIABLE",
  "WS_HSCROLL",
  "WM_SETICON",
  "SM_CYFULLSCREEN",
  "CF_DSPENHMETAFILE",
  "WS_EX_NOPARENTNOTIFY",
  "SC_ARRANGE",
  "SM_CYCAPTION",
  "VK_MEDIA_PLAY_PAUSE",
  "BS_AUTOCHECKBOX",
  "NM_CUSTOMDRAW",
  "SBS_SIZEBOXBOTTOMRIGHTALIGN",
  "CSIDL_COMMON_TEMPLATES",
  "OBM_RESTORED",
  "TTM_SETTIPBKCOLOR",
  "SBT_OWNERDRAW",
  "CSIDL_HISTORY",
  "VK_F12",
  "WM_MBUTTONUP",
  "BTNS_NOPREFIX",
  "TTM_SETTIPTEXTCOLOR",
  "WM_MDIRESTORE",
  "EM_SETWORDBREAKPROC",
  "DFCS_BUTTONRADIOIMAGE",
  "OBJ_METAFILE",
  "MB_USERICON",
  "BM_SETSTYLE",
  "OEM_FIXED_FONT",
  "CB_DIR",
  "HINST_COMMCTRL",
  "TTM_GETTEXT",
  "CB_GETLOCALE",
  "TVGN_PREVIOUS",
  "LB_INITSTORAGE",
  "SBM_SETRANGE",
  "TTM_ADDTOOL",
  "SB_PAGEUP",
  "LB_SELITEMRANGE",
  "MB_SETFOREGROUND",
  "PBM_GETRANGE",
  "CF_ENHMETAFILE",
  "SB_BOTTOM",
  "EM_LINEINDEX",
  "CB_RESETCONTENT",
  "VK_F24",
  "ES_WANTRETURN",
  "VK_OEM_FJ_MASSHOU",
  "SM_CXCURSOR",
  "WS_EX_LAYOUTRTL",
  "WM_KEYUP",
  "SB_THUMBPOSITION",
  "NM_RCLICK",
  "TVHT_ONITEMSTATEICON",
  "BCM_GETIMAGELIST",
  "CSIDL_COMMON_STARTMENU",
  "ICON_BIG",
  "WS_ICONIC",
  "DFCS_MENUARROWRIGHT",
  "VK_OEM_CUSEL",
  "ODT_STATIC",
  "ENM_REQUESTRESIZE",
  "EN_PAGECHANGE",
  "DFCS_SCROLLDOWN",
  "WM_SIZECLIPBOARD",
  "ODT_LISTVIEW",
  "VK_K",
  "TTM_ADJUSTRECT",
  "EN_STOPNOUNDO",
  "RBBS_FIXEDBMP",
  "MB_DEFBUTTON4",
  "SM_PENWINDOWS",
  "WS_GROUP",
  "VK_2",
  "BS_3STATE",
  "WM_LBUTTONDBLCLK",
  "DLGC_WANTMESSAGE",
  "EM_CANUNDO",
  "COLOR_HIGHLIGHTTEXT",
  "PBM_SETMARQUEE",
  "OCR_CROSS",
  "STRETCH_HALFTONE",
  "SF_UNICODE",
  "SBT_RTLREADING",
  "COLOR_INACTIVECAPTIONTEXT",
  "VK_CANCEL",
  "SIZE_MAXHIDE",
  "WM_POWER",
  "RDW_INTERNALPAINT",
  "GT_SELECTION",
  "VK_TAB",
  "WM_SYSCHAR",
  "SM_DBCSENABLED",
  "IDIGNORE",
  "EDGE_RAISED",
  "EN_MSGFILTER",
  "VK_LWIN",
  "VK_KANA",
  "ODS_NOFOCUSRECT",
  "DS_ABSALIGN",
  "DC_BRUSH",
  "SM_CXBORDER",
  "WM_NCLBUTTONUP",
  "OBJ_PAL",
  "WM_TIMER",
  "HTERROR",
  "OCR_HAND",
  "TA_CENTER",
  "HTRIGHT",
  "VK_OEM_7",
  "OCR_NORMAL",
  "BF_DIAGONAL_ENDBOTTOMRIGHT",
  "IDC_SIZEALL",
  "ICON_SMALL2",
  "LBS_DISABLENOSCROLL",
  "CB_SETEDITSEL",
  "SE_ERR_ASSOCINCOMPLETE",
  "WM_SPOOLERSTATUS",
  "LVS_REPORT",
  "VK_APPS",
  "VK_CAPITAL",
  "CP_UTF7",
  "AW_HOR_NEGATIVE",
  "TBSTYLE_DROPDOWN",
  "LVIR_ICON",
  "WM_PRINTCLIENT",
  "MCS_DAYSTATE",
  "HDS_BUTTONS",
  "VK_SHIFT",
  "SWP_HIDEWINDOW",
  "EM_POSFROMCHAR",
  "HALFTONE",
  "CB_GETHORIZONTALEXTENT",
  "TTM_HITTEST",
  "WM_PALETTEISCHANGING",
  "CBN_SETFOCUS",
  "DT_PATH_ELLIPSIS",
  "SM_ARRANGE",
  "BLACK_PEN",
  "DS_SHELLFONT",
  "HTCLIENT",
  "IDC_VSPLIT",
  "VK_F19",
  "SB_LINEUP",
  "WS_EX_LAYERED",
  "EM_LIMITTEXT",
  "CWP_SKIPTRANSPARENT",
  "WS_THICKFRAME",
  "SM_SAMEDISPLAYFORMAT",
  "WM_CHARTOITEM",
  "VK_BROWSER_HOME",
  "VK_NUMPAD8",
  "SM_CXSMICON",
  "VK_NUMPAD4",
  "EM_GETMARGINS",
  "TVHT_TORIGHT",
  "VK_E",
  "WM_UPDATEUISTATE",
  "BF_ADJUST",
  "WM_ENTERIDLE",
  "WM_MDIACTIVATE",
  "WM_MOUSELEAVE",
  "CP_THREAD_ACP",
  "COLOR_3DFACE",
  "VK_OEM_8",
  "SB_PAGEDOWN",
  "CSIDL_APPDATA",
  "R2_NOT",
  "CB_GETITEMHEIGHT",
  "LB_ERR",
  "DT_BOTTOM",
  "SFF_WRITEXTRAPAR",
  "DLGC_BUTTON",
  "RBBS_GRIPPERALWAYS",
  "WS_EX_LEFTSCROLLBAR",
  "BM_GETSTATE",
  "WM_CANCELJOURNAL",
  "WM_NCCREATE",
  "SBM_SETSCROLLINFO",
  "ES_RIGHT",
  "SM_CXMAXTRACK",
  "DLGC_DEFPUSHBUTTON",
  "SW_MINIMIZE",
  "MF_OWNERDRAW",
  "VK_F4",
  "VK_SCROLL",
  "EN_IMECHANGE",
  "SF_RTF",
  "WM_INITDIALOG",
  "SE_ERR_DDEFAIL",
  "VK_ADD",
  "RBBS_TOPALIGN",
  "LBS_NOINTEGRALHEIGHT",
  "CSIDL_RECENT",
  "WM_SETTINGCHANGE",
  "IDI_HAND",
  "TVGN_LASTVISIBLE",
  "CF_DSPMETAFILEPICT",
  "RDW_NOINTERNALPAINT",
  "HWND_BOTTOM",
  "PS_ENDCAP_ROUND",
  "WS_EX_LTRREADING",
  "WM_NCMOUSELEAVE",
  "LBS_NOTIFY",
  "TTM_UPDATE",
  "WM_IME_KEYLAST",
  "DFC_MENU",
  "WM_MENUSELECT",
  "ES_LOWERCASE",
  "TBSTATE_HIDDEN",
  "WM_SYNCPAINT",
  "ACM_PLAY",
  "AW_HIDE",
  "DKGRAY_BRUSH",
  "WM_MENUCHAR",
  "VK_9",
  "SB_ENDSCROLL",
  "WM_IME_ENDCOMPOSITION",
  "IMAGE_CURSOR",
  "DTS_SHORTDATEFORMAT",
  "TTM_ENUMTOOLS",
  "MB_TASKMODAL",
  "MCS_MULTISELECT",
  "BS_PUSHBUTTON",
  "BTNS_BUTTON",
  "WM_HANDHELDLAST",
  "COLOR_3DDKSHADOW",
  "R2_MASKPENNOT",
  "LR_VGACOLOR",
  "WM_TCARD",
  "TPM_VERTICAL",
  "WM_CANCELMODE",
  "LB_GETCOUNT",
  "VK_MENU",
  "SM_SLOWMACHINE",
  "SWP_NOSIZE",
  "OBM_ZOOMD",
  "BS_CHECKBOX",
  "VK_OEM_WSCTRL",
  "MF_DISABLED",
  "ACM_STOP",
  "EM_GETLIMITTEXT",
  "WM_GETOBJECT",
  "LB_SELECTSTRING",
  "VK_MEDIA_STOP",
  "SM_CYSIZEFRAME",
  "CSIDL_COMPUTERSNEARME",
  "VK_Z",
  "MB_NOFOCUS",
  "OCR_WAIT",
  "LB_ERRSPACE",
  "SM_CYMINSPACING",
  "BDR_INNER",
  "BN_HILITE",
  "ENM_DRAGDROPDONE",
  "VK_OEM_BACKTAB",
  "CSIDL_INTERNET_CACHE",
  "WM_ACTIVATE",
  "TVHT_BELOW",
  "AW_SLIDE",
  "WM_TIMECHANGE",
  "VK_LAUNCH_MEDIA_SELECT",
  "WM_GETHOTKEY",
  "HTTOP",
  "CDRF_SKIPDEFAULT",
  "DFCS_SCROLLCOMBOBOX",
  "DFCS_BUTTONPUSH",
  "VK_F10",
  "BF_TOPLEFT",
  "WM_SYSKEYUP",
  "VK_PRIOR",
  "RDW_NOCHILDREN",
  "CSIDL_STARTUP",
  "WM_ENABLE",
  "LB_SETCURSEL",
  "WM_QUERYENDSESSION",
  "VK_OEM_NEC_EQUAL",
  "ILS_SATURATE",
  "WS_OVERLAPPED",
  "LVS_OWNERDATA",
  "TBSTYLE_CHECK",
  "IDC_ARROW",
  "STN_DBLCLK",
  "CSIDL_FLAG_CREATE",
  "BDR_RAISED",
  "CSIDL_LOCAL_APPDATA",
  "PBM_SETBKCOLOR",
  "VK_F17",
  "HTTOPLEFT",
  "OIC_WINLOGO",
  "WM_IME_SELECT",
  "TBSTATE_INDETERMINATE",
  "HTHELP",
  "SC_SEPARATOR",
  "LB_GETHORIZONTALEXTENT",
  "CBES_EX_NOEDITIMAGE",
  "VK_OEM_FJ_ROYA",
  "WS_EX_LEFT",
  "BCM_SETIMAGELIST",
  "COLOR_INFOTEXT",
  "LB_GETITEMHEIGHT",
  "WM_MDISETMENU",
  "TVHT_ONITEMINDENT",
  "CF_TIFF",
  "VK_RCONTROL",
  "NM_LDOWN",
  "SB_RIGHT",
  "EM_GETMODIFY",
  "SW_NORMAL",
  "SM_RESERVED4",
  "LVIR_SELECTBOUNDS",
  "IMAGE_ICON",
  "WM_WINDOWPOSCHANGED",
  "HDS_FLAT",
  "WM_VSCROLLCLIPBOARD",
  "BS_GROUPBOX",
  "LBS_NOSEL",
  "ODT_LISTBOX",
  "R2_BLACK",
  "CB_SETITEMDATA",
  "CP_SYMBOL",
  "LVS_NOSCROLL",
  "BDR_SUNKENOUTER",
  "CSIDL_CDBURN_AREA",
  "ES_OEMCONVERT",
  "EN_UPDATE",
  "CF_DIB",
  "VK_BROWSER_FORWARD",
  "PBS_SMOOTH",
  "PBM_GETPOS",
  "RBBS_FIXEDSIZE",
  "WM_CREATE",
  "WM_HOTKEY",
  "EN_REQUESTRESIZE",
  "LB_ITEMFROMPOINT",
  "VK_F21",
  "SM_CXMINIMIZED",
  "ODS_INACTIVE",
  "WM_SETTEXT",
  "WM_CONTEXTMENU",
  "NM_THEMECHANGED",
  "ENM_UPDATE",
  "MF_MOUSESELECT",
  "WM_SETFONT",
  "VK_ACCEPT",
  "COLOR_SCROLLBAR",
  "MB_ICONHAND",
  "VK_6",
  "WM_RBUTTONDBLCLK",
  "VK_VOLUME_DOWN",
  "SW_FORCEMINIMIZE",
  "CDRF_NOTIFYITEMDRAW",
  "CF_PENDATA",
  "DS_MODALFRAME",
  "SRCPAINT",
  "VK_Y",
  "SBT_NOBORDERS",
  "STRETCH_ORSCANS",
  "CLR_INVALID",
  "SM_RESERVED1",
  "DFCS_MONO",
  "WM_CTLCOLORMSGBOX",
  "VK_PLAY",
  "TPM_HORNEGANIMATION",
  "LBS_USETABSTOPS",
  "CF_OEMTEXT",
  "MB_APPLMODAL",
  "SB_VERT",
  "VK_F20",
  "WM_DELETEITEM",
  "WM_IME_COMPOSITIONFULL",
  "SC_SIZE",
  "LVIS_STATEIMAGEMASK",
  "MCSC_TITLEBK",
  "VK_OEM_ATTN",
  "VK_ICO_HELP",
  "WM_COMPAREITEM",
  "ACS_CENTER",
  "TTM_GETMARGIN",
  "CDRF_DODEFAULT",
  "CB_ERRSPACE",
  "WM_MOUSEMOVE",
  "SM_CXMINTRACK",
  "EN_SELCHANGE",
  "SM_CYMENUSIZE",
  "DTS_APPCANPARSE",
  "EN_SETFOCUS",
  "SE_ERR_NOASSOC",
  "STRETCH_ANDSCANS",
  "TVHT_ONITEMRIGHT",
  "DEVICE_DEFAULT_FONT",
  "MF_ENABLED",
  "WM_SHOWWINDOW",
  "VK_J",
  "TME_QUERY",
  "CB_DELETESTRING",
  "HTSIZEFIRST",
  "COLOR_CAPTIONTEXT",
  "LB_GETSELITEMS",
  "VK_4",
  "TTM_GETTIPBKCOLOR",
  "DFC_CAPTION",
  "EM_GETLINECOUNT",
  "CF_SYLK",
  "HTNOWHERE",
  "TVHT_ONITEM",
  "BTNS_CHECK",
  "TBTS_TOP",
  "WM_SYSKEYDOWN",
  "RBBS_BREAK",
  "SWP_NOACTIVATE",
  "CS_BYTEALIGNWINDOW",
  "EM_EMPTYUNDOBUFFER",
  "DLGC_STATIC",
  "VK_PACKET",
  "MF_RIGHTJUSTIFY",
  "STM_MSGMAX",
  "TA_BOTTOM",
  "DFCS_CAPTIONCLOSE",
  "DFCS_BUTTON3STATE",
  "SBS_BOTTOMALIGN",
  "DLGC_UNDEFPUSHBUTTON",
  "LB_FINDSTRING",
  "SW_SHOWNOACTIVATE",
  "ENM_PARAGRAPHEXPANDED",
  "ENM_SELCHANGE",
  "ODT_COMBOBOX",
  "VK_END",
  "I_IMAGENONE",
  "LVS_SMALLICON",
  "WM_CTLCOLORBTN",
  "ILD_ROP",
  "LVIS_OVERLAYMASK",
  "DS_CONTROL",
  "CSIDL_COMMON_DESKTOPDIRECTORY",
  "DLGC_RADIOBUTTON",
  "RDW_INVALIDATE",
  "SM_CMETRICS",
  "DFCS_MENUCHECK",
  "EM_GETTHUMB",
  "WM_COPYDATA",
  "DFCS_CAPTIONMAX",
  "SM_CXMAXIMIZED",
  "DT_WORD_ELLIPSIS",
  "HTCLOSE",
  "VK_OEM_PLUS",
  "OIC_ERROR",
  "MCSC_TITLETEXT",
  "LVS_EX_MULTIWORKAREAS",
  "WM_RBUTTONUP",
  "WM_PENWINLAST",
  "COLOR_WINDOW",
  "OBJ_BRUSH",
  "MB_ICONASTERISK",
  "AW_ACTIVATE",
  "EN_CHANGE",
  "CSIDL_COMMON_ALTSTARTUP",
  "VK_DIVIDE",
  "ES_CENTER",
  "VK_RMENU",
  "BS_RADIOBUTTON",
  "NM_NCHITTEST",
  "DT_EDITCONTROL",
  "VTA_RIGHT",
  "MB_TYPEMASK",
  "GCL_STYLE",
  "BF_FLAT",
  "SBM_GETRANGE",
  "OCR_APPSTARTING",
  "PS_COSMETIC",
  "CBS_OWNERDRAWFIXED",
  "CBS_LOWERCASE",
  "WM_CHANGEUISTATE",
  "WM_AFXLAST",
  "EM_SETTABSTOPS",
  "EM_GETLINE",
  "WM_CTLCOLORSTATIC",
  "WM_NCPAINT",
  "WS_EX_NOINHERITLAYOUT",
  "WM_STYLECHANGING",
  "VK_NEXT",
  "SM_RESERVED3",
  "MF_DEFAULT",
  "TPM_LAYOUTRTL",
  "WM_CTLCOLORDLG",
  "EN_SAVECLIPBOARD",
  "WM_SETHOTKEY",
  "COLOR_3DLIGHT",
  "VK_N",
  "ODS_NOACCEL",
  "CB_OKAY",
  "SM_CYKANJIWINDOW",
  "OCR_SIZEWE",
  "ODA_DRAWENTIRE",
  "HDS_HORZ",
  "SBM_GETSCROLLINFO",
  "LVS_ALIGNTOP",
  "MF_CHANGE",
  "PS_DOT",
  "WM_HANDHELDFIRST",
  "LVS_AUTOARRANGE",
  "CS_CLASSDC",
  "TBSTATE_ENABLED",
  "WS_EX_ACCEPTFILES",
  "WM_POWERBROADCAST",
  "CWP_SKIPINVISIBLE",
  "TBSTYLE_CHECKGROUP",
  "GT_DEFAULT",
  "MA_ACTIVATE",
  "WS_EX_OVERLAPPEDWINDOW",
  "DEFAULT_PALETTE",
  "CDDS_ITEMPREERASE",
  "WS_CAPTION",
  "OBM_BTSIZE",
  "SM_MOUSEWHEELPRESENT",
  "WM_DRAWITEM",
  "DT_INTERNAL",
  "CB_LIMITTEXT",
  "ODA_FOCUS",
  "VK_LAUNCH_APP1",
  "BS_INDEXED",
  "ILC_COLOR32",
  "COLOR_MENU",
  "CDDS_PREERASE",
  "VK_JUNJA",
  "VK_DECIMAL",
  "COLOR_GRAYTEXT",
  "ILD_IMAGE",
  "VK_F5",
  "ILC_COLORDDB",
  "CB_GETDROPPEDWIDTH",
  "VK_OEM_FJ_JISHO",
  "WM_PAINTICON",
  "ACS_TRANSPARENT",
  "RDW_FRAME",
  "LVS_EX_UNDERLINEHOT",
  "EM_SETSEL",
  "WM_STYLECHANGED",
  "RGN_AND",
  "CSIDL_DESKTOP",
  "CAPTUREBLT",
  "VK_ZOOM",
  "TVGN_CARET",
  "CSIDL_COMMON_MUSIC",
  "DT_VCENTER",
  "OBM_LFARROWI",
  "VK_F15",
  "BCM_GETIDEALSIZE",
  "IDTRYAGAIN",
  "BN_DOUBLECLICKED",
  "RDW_NOERASE",
  "BS_MONOPATTERN",
  "SM_CYDRAG",
  "LVS_ALIGNLEFT",
  "CF_MAX",
  "VTA_BOTTOM",
  "HTSIZELAST",
  "SM_CXFOCUSBORDER",
  "WS_EX_NOACTIVATE",
  "SMTO_NOTIMEOUTIFNOTHUNG",
  "CS_NOCLOSE",
  "ENM_NONE",
  "CSIDL_PROGRAM_FILES",
  "HTSIZE",
  "CDRF_NOTIFYPOSTPAINT",
  "TTM_SETMAXTIPWIDTH",
  "VK_NUMPAD9",
  "SM_CYMAXIMIZED",
  "WM_CHILDACTIVATE",
  "DT_LEFT",
  "CB_GETDROPPEDSTATE",
  "BF_TOP",
  "MK_SHIFT",
  "VK_M",
  "IDC_CROSS",
  "RBBS_VARIABLEHEIGHT",
  "GWL_WNDPROC",
  "PBM_SETPOS",
  "ILD_SCALE",
  "SM_MENUDROPALIGNMENT",
  "SWP_NOCOPYBITS",
  "OBM_RGARROWI",
  "R2_NOTCOPYPEN",
  "ILD_BLEND25",
  "WM_IME_SETCONTEXT",
  "WM_CTLCOLORLISTBOX",
  "IDI_WARNING",
  "VK_F1",
  "SM_CYFOCUSBORDER",
  "OBM_CHECKBOXES",
  "WM_APP",
  "CSIDL_CONTROLS",
  "LVS_TYPEMASK",
  "ODS_CHECKED",
  "ODS_FOCUS",
  "SM_CYMIN",
  "PBM_SETRANGE",
  "SWP_NOOWNERZORDER",
  "LVS_EX_FLATSB",
  "GRAY_BRUSH",
  "CB_GETITEMDATA",
  "GW_OWNER",
  "SM_CYBORDER",
  "LVS_SORTASCENDING",
  "LBS_SORT",
  "DFCS_BUTTONRADIO",
  "RBBS_NOVERT",
  "LVS_EX_LABELTIP",
  "EN_CORRECTTEXT",
  "VK_F16",
  "BF_TOPRIGHT",
  "VTA_CENTER",
  "VK_INSERT",
  "IDB_VIEW_SMALL_COLOR",
  "SM_CYICONSPACING",
  "DT_NOCLIP",
  "MCS_WEEKNUMBERS",
  "R2_NOTXORPEN",
  "WM_GETMINMAXINFO",
  "CBN_DBLCLK",
  "ODS_COMBOBOXEDIT",
  "TVGN_PREVIOUSVISIBLE",
  "NM_TOOLTIPSCREATED",
  "VK_I",
  "WM_MENURBUTTONUP",
  "VK_1",
  "VK_F22",
  "EN_ALIGN_LTR_EC",
  "MERGEPAINT",
  "MB_SERVICE_NOTIFICATION",
  "MF_CHECKED",
  "VK_OEM_COPY",
  "CSIDL_FLAG_MASK",
  "CB_SETEXTENDEDUI",
  "SIMPLEREGION",
  "BF_BOTTOMLEFT",
  "DLGC_HASSETSEL",
  "SM_CYDLGFRAME",
  "WS_MAXIMIZE",
  "TBSTYLE_EX_HIDECLIPPEDBUTTONS",
  "LB_SETHORIZONTALEXTENT",
  "LR_COLOR",
  "WM_VKEYTOITEM",
  "CB_INITSTORAGE",
  "BN_SETFOCUS",
  "WS_EX_PALETTEWINDOW",
  "CSIDL_COMMON_PROGRAMS",
  "CS_BYTEALIGNCLIENT",
  "DFC_SCROLL",
  "WM_ERASEBKGND",
  "PBS_MARQUEE",
  "WM_NCMBUTTONUP",
  "SWP_DEFERERASE",
  "IMAGE_BITMAP",
  "TBSTYLE_NOPREFIX",
  "CSIDL_COOKIES",
  "WM_MOVE",
  "WM_FONTCHANGE",
  "VK_SEPARATOR",
  "WM_NCCALCSIZE",
  "WM_MDITILE",
  "HS_FDIAGONAL",
  "CSIDL_WINDOWS",
  "VK_MEDIA_PREV_TRACK",
  "ANSI_VAR_FONT",
  "DT_NOFULLWIDTHCHARBREAK",
  "ILC_MIRROR",
  "MF_POPUP",
  "WM_QUERYUISTATE",
  "CSIDL_PERSONAL",
  "HDS_HIDDEN",
  "NM_CHAR",
  "GCL_MENUNAME",
  "LVS_EX_DOUBLEBUFFER",
  "VK_CRSEL",
  "IDI_ASTERISK",
  "MB_DEFMASK",
  "CF_DSPBITMAP",
  "SM_CYSCREEN",
  "CSIDL_PROGRAM_FILESX86",
  "VK_OEM_PA3",
  "MF_APPEND",
  "MK_MBUTTON",
  "ANSI_FIXED_FONT",
  "IDB_HIST_SMALL_COLOR",
  "BN_PAINT",
  "VK_Q",
  "VK_NUMPAD0",
  "OBJ_MEMDC",
  "WM_CTLCOLORSCROLLBAR",
  "VK_B",
  "BN_KILLFOCUS",
  "WM_NCXBUTTONDOWN",
  "EM_SETPASSWORDCHAR",
  "CSIDL_FLAG_DONT_VERIFY",
  "TA_BASELINE",
  "CDDS_ITEMPREPAINT",
  "IDC_HELP",
  "DS_NOIDLEMSG",
  "TTM_SETTITLE",
  "WM_NCXBUTTONDBLCLK",
  "IDC_NO",
  "VK_OEM_FINISH",
  "WM_NCMBUTTONDBLCLK",
  "MB_CANCELTRYCONTINUE",
  "CDDS_SUBITEM",
  "WM_CTLCOLOREDIT",
  "TPM_VERNEGANIMATION",
  "BCM_FIRST",
  "ENM_IMECHANGE",
  "BS_DEFPUSHBUTTON",
  "CLR_HILIGHT",
  "SM_RESERVED2",
  "CB_SETDROPPEDWIDTH",
  "SE_ERR_PNF",
  "NM_SETFOCUS",
  "VK_OEM_AUTO",
  "BS_VCENTER",
  "R2_COPYPEN",
  "HDS_FULLDRAG",
  "PBS_VERTICAL",
  "HDS_DRAGDROP",
  "SFF_PERSISTVIEWSCALE",
  "MK_CONTROL",
  "WS_DLGFRAME",
  "ILC_COLOR",
  "SM_CYSMCAPTION",
  "WHITENESS",
  "I_IMAGECALLBACK",
  "LVS_EDITLABELS",
  "BS_CENTER",
  "OIC_NOTE",
  "HTOBJECT",
  "ERROR",
  "VK_F23",
  "LVIS_GLOW",
  "WM_NCLBUTTONDBLCLK",
  "BN_UNHILITE",
  "COLOR_INACTIVEBORDER",
  "IDB_STD_LARGE_COLOR",
  "CBS_UPPERCASE",
  "CSIDL_PROGRAMS",
  "DT_CENTER",
  "CF_BITMAP",
  "HWND_TOP",
  "LBS_WANTKEYBOARDINPUT",
  "VK_MODECHANGE",
  "SMTO_BLOCK",
  "IDHELP",
  "LB_GETCARETINDEX",
  "SIZE_MAXSHOW",
  "GCL_WNDPROC",
  "WM_MENUDRAG",
  "ILD_TRANSPARENT",
  "BM_CLICK",
  "SBS_SIZEBOX",
  "BM_SETSTATE",
  "SW_MAXIMIZE",
  "WS_CHILDWINDOW",
  "WM_HSCROLL",
  "TBSTYLE_AUTOSIZE",
  "PS_JOIN_MASK",
  "BS_BITMAP",
  "EN_VSCROLL",
  "BN_CLICKED",
  "CSIDL_BITBUCKET",
  "WM_HSCROLLCLIPBOARD",
  "BLACKNESS",
  "CB_GETTOPINDEX",
  "WM_INPUTLANGCHANGE",
  "SMTO_ABORTIFHUNG",
  "ODT_MENU",
  "BN_DISABLE",
  "NM_OUTOFMEMORY",
  "EM_SCROLLCARET",
  "DT_WORDBREAK",
  "ILC_MASK",
  "HS_VERTICAL",
  "WS_EX_CLIENTEDGE",
  "CSIDL_MYVIDEO",
  "CSIDL_PROGRAM_FILES_COMMONX86",
  "WM_CHAR",
  "R2_MERGENOTPEN",
  "MB_DEFBUTTON1",
  "MB_MISCMASK",
  "CSIDL_PROGRAM_FILES_COMMON",
  "MCSC_TEXT",
  "IDCONTINUE",
  "CSIDL_FAVORITES",
  "WS_CLIPSIBLINGS",
  "SM_CXMENUCHECK",
  "WS_EX_RIGHTSCROLLBAR",
  "VK_LMENU",
  "ENM_MOUSEEVENTS",
  "OBJ_REGION",
  "CWP_SKIPDISABLED",
  "TPM_TOPALIGN",
  "SWP_NOREDRAW",
  "TBSTATE_ELLIPSES",
  "SFF_PLAINRTF",
  "MCSC_MONTHBK",
  "VK_NONAME",
  "OBJ_FONT",
  "BTNS_AUTOSIZE",
  "HS_BDIAGONAL",
  "TTF_ABSOLUTE",
  "MB_RETRYCANCEL",
  "LBS_HASSTRINGS",
  "DT_MODIFYSTRING",
  "R2_NOP",
  "TBSTYLE_WRAPABLE",
  "VK_LSHIFT",
  "SB_PAGERIGHT",
  "LVS_EX_HIDELABELS",
  "IDI_INFORMATION",
  "BS_NULL",
  "RBBS_NOGRIPPER",
  "SWP_NOMOVE",
  "VK_DOWN",
  "CSIDL_COMMON_VIDEO",
  "COLOR_ACTIVECAPTION",
  "RGN_COPY",
  "VK_NUMLOCK",
  "WM_MDICASCADE",
  "EN_ERRSPACE",
  "COMPLEXREGION",
  "OBM_ZOOM",
  "WM_MDICREATE",
  "TA_LEFT",
  "SM_CYVTHUMB",
  "EN_LOWFIRTF",
  "COLOR_BACKGROUND",
  "VK_FINAL",
  "TTM_GETTOOLINFO",
  "SWP_NOSENDCHANGING",
  "TA_NOUPDATECP",
  "TBSTYLE_EX_MIXEDBUTTONS",
  "WM_PRINT",
  "WS_VISIBLE",
  "TBTS_RIGHT",
  "TTM_GETBUBBLESIZE",
  "DS_CENTER",
  "PS_JOIN_BEVEL",
  "HTCAPTION",
  "ACS_TIMER",
  "ENM_DROPFILES",
  "VK_XBUTTON2",
  "DFCS_MENUARROW",
  "WM_MENUCOMMAND",
  "BS_HATCHED",
  "CSIDL_PROFILE",
  "ES_AUTOHSCROLL",
  "CSIDL_SYSTEMX86",
  "VK_BROWSER_REFRESH",
  "VK_MULTIPLY",
  "TVGN_FIRSTVISIBLE",
  "AW_CENTER",
  "VK_LCONTROL",
  "CS_SAVEBITS",
  "WM_PAINT",
  "TA_TOP",
  "VK_RBUTTON",
  "VK_OEM_FJ_TOUROKU",
  "TTM_GETDELAYTIME",
  "DFCS_MENUBULLET",
  "STN_ENABLE",
  "SF_NCRFORNONASCII",
  "MK_XBUTTON2",
  "TTF_PARSELINKS",
  "LVS_EX_CHECKBOXES",
  "BF_MONO",
  "LVS_NOLABELWRAP",
  "MA_NOACTIVATE",
  "LB_FINDSTRINGEXACT",
  "ES_PASSWORD",
  "TPM_BOTTOMALIGN",
  "SYSTEM_FIXED_FONT",
  "BF_BOTTOMRIGHT",
  "CBES_EX_NOSIZELIMIT",
  "LVIS_FOCUSED",
  "WM_GETTEXT",
  "WS_MINIMIZE",
  "MB_OKCANCEL",
  "LVS_SHAREIMAGELISTS",
  "ES_READONLY",
  "VK_SNAPSHOT",
  "SM_CXSMSIZE",
  "DFCS_SCROLLLEFT",
  "ILD_FOCUS",
  "LBN_SETFOCUS",
  "SYSTEM_FONT",
  "COLOR_3DSHADOW",
  "SWP_ASYNCWINDOWPOS",
  "SIZE_RESTORED",
  "WHITEONBLACK",
  "SM_CXHTHUMB",
  "SM_CXDLGFRAME",
  "LB_SETCOLUMNWIDTH",
  "DFCS_HOT",
  "WM_UNINITMENUPOPUP",
  "SM_CXVIRTUALSCREEN",
  "RGN_MIN",
  "IDC_UPARROW",
  "WM_NEXTMENU",
  "BS_LEFT",
  "WM_XBUTTONDBLCLK",
  "VK_DELETE",
  "SFF_KEEPDOCINFO",
  "DT_PREFIXONLY",
  "LB_GETITEMRECT",
  "CSIDL_COMMON_DOCUMENTS",
  "TTDT_INITIAL",
  "SM_CYVSCROLL",
  "GWL_ID",
  "OBM_LFARROW",
  "LVIS_SELECTED",
  "SRCINVERT",
  "TA_RIGHT",
  "CDB2GVF_SHOWALLFILES",
  "NM_CLICK",
  "TTDT_AUTOMATIC",
  "EN_MAXTEXT",
  "VK_OEM_FJ_LOYA",
  "CS_OWNDC",
  "BS_HOLLOW",
  "IDCLOSE",
  "MB_ICONINFORMATION",
  "SM_CYCURSOR",
  "SM_SWAPBUTTON",
  "R2_NOTMASKPEN",
  "GCL_CBWNDEXTRA",
  "VK_3",
  "SW_HIDE",
  "TTN_SHOW",
  "CB_ERR",
  "WM_INITMENU",
  "VK_OEM_CLEAR",
  "ACM_OPEN",
  "DTS_RIGHTALIGN",
  "ODS_HOTLIGHT",
  "RGN_XOR",
  "WM_KEYLAST",
  "VK_ICO_00",
  "WM_IME_CONTROL",
  "SB_THUMBTRACK",
  "RDW_ERASE",
  "WM_COMPACTING",
  "COLOR_WINDOWFRAME",
  "VK_7",
  "DEFAULT_GUI_FONT",
  "GWL_USERDATA",
  "PS_NULL",
  "CBS_AUTOHSCROLL",
  "VK_LAUNCH_APP2",
  "EM_SETRECTNP",
  "ODT_BUTTON",
  "TPM_RIGHTBUTTON",
  "R2_XORPEN",
  "CSIDL_NETWORK",
  "LVS_ICON",
  "WM_MDIMAXIMIZE",
  "WHITE_PEN",
  "CBES_EX_CASESENSITIVE",
  "TVGN_NEXTVISIBLE",
  "CSIDL_COMMON_STARTUP",
  "WM_AFXFIRST",
  "SBM_GETSCROLLBARINFO",
  "R2_WHITE",
  "R2_MERGEPEN",
  "VK_H",
  "DFCS_SCROLLUP",
  "LVS_EX_ONECLICKACTIVATE",
  "AW_BLEND",
  "VK_OEM_MINUS",
  "LVS_EX_FULLROWSELECT",
  "DC_PEN",
  "VK_PAUSE",
  "VK_F9",
  "RGN_OR",
  "WM_NCHITTEST",
  "CDDS_ITEMPOSTERASE",
  "SM_STARTER",
  "SB_PAGELEFT",
  "SBS_VERT",
  "CSIDL_RESOURCES_LOCALIZED",
  "DT_END_ELLIPSIS",
  "WM_DROPFILES",
  "TTM_NEWTOOLRECT",
  "WM_UNDO",
  "SC_DEFAULT",
  "CB_SETITEMHEIGHT",
  "WM_SIZING",
  "TPM_HORIZONTAL",
  "NM_KILLFOCUS",
  "MF_USECHECKBITMAPS",
  "SB_BOTH",
  "EN_HSCROLL",
  "EM_GETIMESTATUS",
  "SM_CXVSCROLL",
  "ILD_NORMAL",
  "MB_ICONMASK",
  "VK_LAUNCH_MAIL",
  "CSIDL_TEMPLATES",
  "SB_TOP",
  "BS_PATTERN",
  "MF_HILITE",
  "WM_XBUTTONUP",
  "LVIS_CUT",
  "DFCS_SCROLLRIGHT",
  "WM_NCRBUTTONDOWN",
  "TA_UPDATECP",
  "SM_CXICON",
  "MB_YESNO",
  "SM_CXMINSPACING",
  "AW_VER_POSITIVE",
  "VK_NUMPAD3",
  "OIC_BANG",
  "WS_CHILD",
  "LVIS_DROPHILITED",
  "MB_YESNOCANCEL",
  "TTM_WINDOWFROMPOINT",
  "SB_LINELEFT",
  "RGN_ERROR",
  "EN_PROTECTED",
  "LR_DEFAULTSIZE",
  "SM_CMOUSEBUTTONS",
  "DT_TOP",
  "SM_CXEDGE",
  "DS_LOCALEDIT",
  "EDGE_BUMP",
  "LVS_EX_SUBITEMIMAGES",
  "CSIDL_ADMINTOOLS",
  "TTM_GETMAXTIPWIDTH",
  "DS_CENTERMOUSE",
  "WS_EX_STATICEDGE",
  "AW_VER_NEGATIVE",
  "HTSYSMENU",
  "MF_UNCHECKED",
  "ILC_COLOR16",
  "VK_PRINT",
  "CF_DIBV5",
  "MB_SYSTEMMODAL",
  "SM_REMOTESESSION",
  "CB_GETCURSEL",
  "WM_INPUT",
  "VK_KANJI",
  "CSIDL_NETHOOD",
  "OBM_SIZE",
  "EN_PARAGRAPHEXPANDED",
  "SM_CYMAXTRACK",
  "SMTO_NORMAL",
  "LB_GETSEL",
  "CSIDL_ALTSTARTUP",
  "WM_SETCURSOR",
  "CB_GETEDITSEL",
  "DS_FIXEDSYS",
  "ENM_CORRECTTEXT",
  "GCL_HICON",
  "TTM_POP",
  "TVHT_NOWHERE",
  "ILC_COLOR4",
  "EM_LINESCROLL",
  "TME_LEAVE",
  "WM_USERCHANGED",
  "COLOR_BTNFACE",
  "SC_HOTKEY",
  "OBJ_PEN",
  "CF_PRIVATEFIRST",
  "LR_CREATEDIBSECTION",
  "SFF_SELECTION",
  "ILC_COLOR8",
  "SM_CYVIRTUALSCREEN",
  "BF_BOTTOM",
  "RBBS_USECHEVRON",
  "ILC_COLOR24",
  "PATINVERT",
  "VK_RWIN",
  "DFCS_CAPTIONMIN",
  "GA_PARENT",
  "OBM_DNARROWD",
  "CW_USEDEFAULT",
  "LVS_EX_SINGLEROW",
  "OIC_WARNING",
  "LBS_OWNERDRAWFIXED",
  "VTA_LEFT",
  "SM_CXDOUBLECLK",
  "VK_OEM_5",
  "CBS_SORT",
  "WM_QUERYNEWPALETTE",
  "BS_USERBUTTON",
  "PS_JOIN_MITER",
  "WM_IME_STARTCOMPOSITION",
  "SC_MOVE",
  "VK_RETURN",
  "EM_LINEFROMCHAR",
  "DT_HIDEPREFIX",
  "HOLLOW_BRUSH",
  "VK_NONCONVERT",
  "WA_INACTIVE",
  "WM_MDIICONARRANGE",
  "LB_ADDSTRING",
  "GCLP_HICONSM",
  "DFC_BUTTON",
  "VK_F8",
  "LB_SELITEMRANGEEX",
  "HTBORDER",
  "LB_SETLOCALE",
  "WS_EX_RTLREADING",
  "BF_RIGHT",
  "CB_ADDSTRING",
  "VK_O",
  "TTM_SETMARGIN",
  "SW_SHOWMINNOACTIVE",
  "TVHT_ONITEMICON",
  "DTS_SHORTDATECENTURYFORMAT",
  "BN_DBLCLK",
  "WM_PARENTNOTIFY",
  "ENM_CHANGE",
  "SM_CYDOUBLECLK",
  "SM_CYSMICON",
  "EM_FMTLINES",
  "LVSIL_STATE",
  "SC_VSCROLL",
  "GW_ENABLEDPOPUP",
  "CSIDL_STARTMENU",
  "SE_ERR_DDETIMEOUT",
  "R2_MASKNOTPEN",
  "ENM_LANGCHANGE",
  "LVS_EX_HEADERDRAGDROP",
  "LBN_KILLFOCUS",
  "NM_RELEASEDCAPTURE",
  "MF_STRING",
  "SB_HORZ",
  "WM_MOVING",
  "BCM_GETTEXTMARGIN",
  "ILS_ALPHA",
  "SM_SHUTTINGDOWN",
  "SW_SHOW",
  "SB_LINEDOWN",
  "TTF_SUBCLASS",
  "LR_COPYFROMRESOURCE",
  "R2_MERGEPENNOT",
  "IDC_APPSTARTING",
  "TME_NONCLIENT",
  "HS_HORIZONTAL",
  "BM_SETIMAGE",
  "TTM_TRACKACTIVATE",
  "MB_ICONEXCLAMATION",
  "CB_INSERTSTRING",
  "STM_SETICON",
  "SBM_GETPOS",
  "ODS_DISABLED",
  "LB_ADDFILE",
  "EM_GETPASSWORDCHAR",
  "DT_NOPREFIX",
  "DS_SETFOREGROUND",
  "PS_STYLE_MASK",
  "SB_CTL",
  "CP_UTF8",
  "SBS_LEFTALIGN",
  "SFF_PWD",
  "SM_CXHSCROLL",
  "WM_NOTIFY",
  "GWL_STYLE",
  "VK_W",
  "ILC_PALETTE",
  "EM_SCROLL",
  "MB_ABORTRETRYIGNORE",
  "TPM_NONOTIFY",
  "WS_EX_MDICHILD",
  "COLOR_BTNHILIGHT",
  "LVS_EX_TRACKSELECT",
  "DTS_TIMEFORMAT",
  "SRCCOPY",
  "WM_PENWINFIRST",
  "HTBOTTOMRIGHT",
  "CBN_SELCHANGE",
  "SBM_SETRANGEREDRAW",
  "VK_HANJA",
  "SF_USECODEPAGE",
  "DFCS_BUTTONCHECK",
  "VK_NUMPAD1",
  "TTF_CENTERTIP",
  "BF_MIDDLE",
  "LB_OKAY",
  "VK_OEM_RESET",
  "WM_ASKCBFORMATNAME",
  "WM_RENDERFORMAT",
  "OBJ_ENHMETADC",
  "IDI_ERROR",
  "VK_F3",
  "CB_SETCURSEL",
  "WM_PAINTCLIPBOARD",
  "WM_DEVMODECHANGE",
  "VK_8",
  "VK_U",
  "DFCS_SCROLLSIZEGRIP",
  "TBTS_BOTTOM",
  "VK_OEM_AX",
  "VK_PA1",
  "MB_ICONQUESTION",
  "CSIDL_COMMON_ADMINTOOLS",
  "BF_DIAGONAL_ENDTOPRIGHT",
  "HTMAXBUTTON",
  "SC_RESTORE",
  "SF_TEXTIZED",
  "VK_EXECUTE",
  "VK_LEFT",
  "IDC_SIZENWSE",
  "WM_LBUTTONDOWN",
  "SF_RTFVAL",
  "VK_P",
  "TPM_NOANIMATION",
  "WS_EX_COMPOSITED",
  "SM_IMMENABLED",
  "TTDT_RESHOW",
  "WS_CLIPCHILDREN",
  "CSIDL_COMMON_APPDATA",
  "BM_GETCHECK",
  "CF_UNICODETEXT",
  "SW_SHOWMINIMIZED",
  "WM_IME_KEYUP",
  "CSIDL_INTERNET",
  "SM_XVIRTUALSCREEN",
  "IDI_DEFAULTICON",
  "OCR_IBEAM",
  "VK_OEM_PERIOD",
  "VK_XBUTTON1",
  "ILD_DPISCALE",
  "CBS_DROPDOWNLIST",
  "BS_SOLID",
  "FLOODFILLSURFACE",
  "SIZE_MINIMIZED",
  "OBM_DNARROWI",
  "WM_NCMOUSEMOVE",
  "HWND_NOTOPMOST",
  "BS_ICON",
  "CB_MULTIPLEADDSTRING",
  "BDR_RAISEDINNER",
  "WM_SYSCOLORCHANGE",
  "WM_GETDLGCODE",
  "STM_GETICON",
  "PBM_SETSTEP",
  "CF_METAFILEPICT",
  "TPM_CENTERALIGN",
  "PS_ENDCAP_SQUARE",
  "COLOR_3DHILIGHT",
  "EM_SETRECT",
  "WM_INITMENUPOPUP",
  "EM_SETIMESTATUS",
  "OBM_RGARROWD",
  "BS_AUTO3STATE",
  "RDW_ALLCHILDREN",
  "IDRETRY",
  "WM_GETICON",
  "STM_GETIMAGE",
  "DSTINVERT",
  "SM_CXMENUSIZE",
  "VK_ESCAPE",
  "SM_YVIRTUALSCREEN",
  "SM_SECURE",
  "CDDS_PREPAINT",
  "ILS_SHADOW",
  "NM_SETCURSOR",
  "OBM_RGARROW",
  "TVHT_ONITEMLABEL",
  "LB_SETCOUNT",
  "RBBS_HIDDEN",
  "MF_BITMAP",
  "IDC_IBEAM",
  "SC_CONTEXTHELP",
  "MB_RTLREADING",
  "BS_DIBPATTERN8X8",
  "SM_CMONITORS",
  "MB_TOPMOST",
  "LVS_LIST",
  "OBM_UPARROW",
  "TBSTYLE_REGISTERDROP",
  "BF_DIAGONAL",
  "SM_CYMINTRACK",
  "WM_INPUTLANGCHANGEREQUEST",
  "MF_BYPOSITION",
  "ACS_AUTOPLAY",
  "HWND_DESKTOP",
  "CS_HREDRAW",
  "TME_HOVER",
  "PS_JOIN_ROUND",
  "OBM_REDUCE",
  "TTM_GETTIPTEXTCOLOR",
  "WM_SYSCOMMAND",
  "MB_HELP",
  "VK_NUMPAD2",
  "OCR_UP",
  "LVS_EX_TWOCLICKACTIVATE",
  "ILD_BLEND50",
  "ENM_SCROLLEVENTS",
  "TBSTATE_WRAP",
  "GCL_HCURSOR",
  "VK_F2",
  "WM_SETFOCUS",
  "VTA_BASELINE",
  "CF_DSPTEXT",
  "STM_SETIMAGE",
  "WM_CHANGECBCHAIN",
  "IDNO",
  "BS_LEFTTEXT",
  "GCL_HMODULE",
  "SM_CYFRAME",
  "CSIDL_PRINTERS",
  "WM_KILLFOCUS",
  "DFC_POPUPMENU",
  "VK_OEM_PA1",
  "COLOR_GRADIENTINACTIVECAPTION",
  "SW_SHOWNA",
  "VK_EXSEL",
  "CSIDL_DRIVES",
  "OBM_RESTORE",
  "WM_LBUTTONUP",
  "EM_GETRECT",
  "CSIDL_COMMON_FAVORITES",
  "BS_AUTORADIOBUTTON",
  "CS_DROPSHADOW",
  "WM_RENDERALLFORMATS",
  "BS_PATTERN8X8",
  "VK_F6",
  "SBS_RIGHTALIGN",
  "TPM_RETURNCMD",
  "SM_MIDEASTENABLED",
  "LB_SETANCHORINDEX",
  "HTTOPRIGHT",
  "BDR_RAISEDOUTER",
  "DTS_SHOWNONE",
  "BCM_SETTEXTMARGIN",
  "BTNS_CHECKGROUP",
  "SM_CLEANBOOT",
  "LR_DEFAULTCOLOR",
  "AW_HOR_POSITIVE",
  "MF_UNHILITE",
  "RBBS_CHILDEDGE",
  "PS_DASHDOTDOT",
  "WM_NEXTDLGCTL",
  "SBM_ENABLE_ARROWS",
  "COLORONCOLOR",
  "WM_QUEUESYNC",
  "WS_EX_RIGHT",
  "WS_SIZEBOX",
  "SM_CXMIN",
  "TPM_RIGHTALIGN",
  "WM_DRAWCLIPBOARD",
  "SBS_SIZEBOXTOPLEFTALIGN",
  "WM_IME_CHAR",
  "CS_GLOBALCLASS",
  "LBN_SELCANCEL",
  "DT_RTLREADING",
  "DT_TABSTOP",
  "LVS_SINGLESEL",
  "PS_ALTERNATE",
  "HTGROWBOX",
  "BS_PUSHBOX",
  "MF_REMOVE",
  "DFCS_CHECKED",
  "IDI_APPLICATION",
  "COLOR_DESKTOP",
  "COLOR_BTNTEXT",
  "LB_GETTOPINDEX",
  "WS_TILED",
  "VK_HANGUL",
  "TTN_GETDISPINFO",
  "ACN_STOP",
  "NOTSRCCOPY",
  "EN_ALIGNLTR",
  "OIC_HAND",
  "EN_LINK",
  "BS_RIGHTBUTTON",
  "R2_NOTMERGEPEN",
  "PS_TYPE_MASK",
  "WM_VSCROLL",
  "RDW_NOFRAME",
  "GW_HWNDLAST",
  "CF_PALETTE",
  "SM_CYMENU",
  "TBSTYLE_LIST",
  "BLACK_BRUSH",
  "VK_F11",
  "LVS_ALIGNMASK",
  "CBN_EDITCHANGE",
  "MB_MODEMASK",
  "LBS_MULTIPLESEL",
  "CF_WAVE",
  "VK_RSHIFT",
  "SC_ZOOM",
  "LVS_TYPESTYLEMASK",
  "BS_OWNERDRAW",
  "IDB_STD_SMALL_COLOR",
  "CLR_DEFAULT",
  "SM_CYICON",
  "HS_CROSS",
  "STRETCH_DELETESCANS",
  "TTN_NEEDTEXT",
  "TPM_LEFTALIGN",
  "WM_MEASUREITEM",
  "SBS_TOPALIGN",
  "WM_NOTIFYFORMAT",
  "WS_SYSMENU",
  "TPM_VCENTERALIGN",
  "BTNS_GROUP",
  "WM_SIZE",
  "TBSTYLE_EX_DOUBLEBUFFER",
  "DLGC_WANTALLKEYS",
  "VK_X",
  "WS_OVERLAPPEDWINDOW",
  "OBJ_ENHMETAFILE",
  "WM_CAPTURECHANGED",
  "VK_BROWSER_BACK",
  "CB_GETCOUNT",
  "VK_OEM_4",
  "SE_ERR_OOM",
  "OBJ_EXTPEN",
  "WM_ICONERASEBKGND",
  "CBS_OWNERDRAWVARIABLE",
  "LVIR_BOUNDS",
  "OIC_INFORMATION",
  "SRCERASE",
  "MK_RBUTTON",
  "VK_BROWSER_SEARCH",
  "IDC_SIZEWE",
  "WS_EX_TOOLWINDOW",
  "CSIDL_COMMON_PICTURES",
  "WM_RBUTTONDOWN",
  "BN_PUSHED",
  "CB_GETCOMBOBOXINFO",
  "ILD_SELECTED",
  "CB_GETLBTEXTLEN",
  "DFCS_PUSHED",
  "WM_IME_KEYDOWN",
  "ENM_KEYEVENTS",
  "CB_SETLOCALE",
  "COLOR_MENUTEXT",
  "COLOR_ACTIVEBORDER",
  "LBS_EXTENDEDSEL",
  "VK_OEM_ENLW",
  "DT_EXPANDTABS",
  "DLGC_WANTTAB",
  "TTM_ACTIVATE",
  "VK_C",
  "BS_FLAT",
  "MA_ACTIVATEANDEAT",
  "CBS_DROPDOWN",
  "ENM_LINK",
  "HOVER_DEFAULT",
  "CSIDL_CONNECTIONS",
  "NM_RETURN",
  "SW_SHOWMAXIMIZED",
  "CF_DIF",
  "ILS_NORMAL",
  "SF_RTFNOOBJS",
  "VK_PROCESSKEY",
  "WM_COMMNOTIFY",
  "BDR_SUNKEN",
  "WM_PASTE",
  "WHITE_BRUSH",
  "BF_SOFT",
  "CDDS_POSTPAINT",
  "VK_S",
  "WM_EXITMENULOOP",
  "PS_ENDCAP_FLAT",
  "WM_QUIT",
  "ENM_LOWFIRTF",
  "COLOR_HOTLIGHT",
  "ES_NOHIDESEL",
  "LB_SETCARETINDEX",
  "LVS_EX_GRIDLINES",
  "SM_CYSMSIZE",
  "NULLREGION",
  "MB_RIGHT",
  "WM_ENTERSIZEMOVE",
  "VK_R",
  "NM_RDBLCLK",
  "VK_F14",
  "WM_NCRBUTTONUP",
  "MK_LBUTTON",
  "TPM_HORPOSANIMATION",
  "TTM_SETDELAYTIME",
  "LVS_SORTDESCENDING",
  "WM_GETFONT",
  "OBM_DNARROW",
  "LB_GETTEXT",
  "TBSTATE_PRESSED",
  "CF_PRIVATELAST",
  "IDI_EXCLAMATION",
  "OIC_SAMPLE",
  "LBS_COMBOBOX",
  "SBS_HORZ",
  "SM_CYFIXEDFRAME",
  "SWP_DRAWFRAME",
  "VK_NUMPAD7",
  "EM_GETSEL",
  "TPM_RECURSE",
  "VK_SLEEP",
  "SM_CXSCREEN",
  "SE_ERR_SHARE",
  "DT_SINGLELINE",
  "SM_CARETBLINKINGENABLED",
  "EM_GETFIRSTVISIBLELINE",
  "GT_NOHIDDENTEXT",
  "MB_SERVICE_NOTIFICATION_NT3X",
  "WM_ENDSESSION",
  "OCR_SIZENESW",
  "IDC_WAIT",
  "LB_GETTEXTLEN",
  "PS_DASHDOT",
  "TVHT_ABOVE",
  "ILC_PERITEMMIRROR",
  "LVS_SHOWSELALWAYS",
  "VK_OEM_3",
  "WM_MDIDESTROY",
  "SM_CYMINIMIZED",
  "SM_CXSIZE",
  "BS_RIGHT",
  "CP_OEMCP",
  "WM_ENTERMENULOOP",
  "SBT_POPOUT",
  "OCR_NO",
  "WM_DEADCHAR",
  "TBSTYLE_ALTDRAG",
  "TTF_TRACK",
  "VK_ICO_CLEAR",
  "NM_RDOWN",
  "DT_EXTERNALLEADING",
  "OBM_LFARROWD",
  "TTF_IDISHWND",
  "VK_D",
  "GW_CHILD",
  "DFCS_TRANSPARENT",
  "VK_G",
  "EM_SETREADONLY",
  "CSIDL_MYDOCUMENTS",
  "DT_RIGHT",
  "WM_NCLBUTTONDOWN",
  "WM_CLEAR",
  "LBS_STANDARD",
  "SBT_NOTABPARSING",
  "EM_SETMODIFY",
  "LB_SETSEL",
  "VK_NUMPAD6",
  "WM_SYSDEADCHAR",
  "NM_HOVER",
  "IDOK",
  "CB_FINDSTRINGEXACT",
  "BS_TEXT",
  "WM_NCDESTROY",
  "SC_MINIMIZE",
  "MK_XBUTTON1",
  "DFCS_SCROLLSIZEGRIPRIGHT",
  "CBS_HASSTRINGS",
  "OCR_SIZENS",
  "WM_GETTEXTLENGTH",
  "SM_TABLETPC",
  "GT_USECRLF",
  "ES_NUMBER",
  "CBES_EX_PATHWORDBREAKPROC",
  "CB_SETTOPINDEX",
  "CB_SHOWDROPDOWN",
  "WS_EX_DLGMODALFRAME",
  "EM_LINELENGTH",
  "LB_GETSELCOUNT",
  "LVSIL_SMALL",
  "BS_DIBPATTERNPT",
  "RDW_UPDATENOW",
  "VK_A",
  "DTS_UPDOWN",
  "WM_SETREDRAW",
  "BS_TOP",
  "WM_CUT",
  "WM_DEVICECHANGE",
  "ENM_PAGECHANGE",
  "SM_CYEDGE",
  "HTMINBUTTON",
  "EM_REPLACESEL",
  "COLOR_GRADIENTACTIVECAPTION",
  "DS_SETFONT",
  "GW_HWNDFIRST",
  "IDTIMEOUT",
  "IDC_SIZENS",
  "SWP_NOREPOSITION",
  "EM_SETMARGINS",
  "WM_XBUTTONDOWN",
  "BF_DIAGONAL_ENDTOPLEFT",
  "WM_MOUSEHOVER",
  "IDABORT",
  "WM_IME_REQUEST",
  "SW_RESTORE",
  "BTNS_SHOWTEXT",
  "RBBS_HIDETITLE",
  "VK_VOLUME_UP",
  "WM_MENUGETOBJECT",
  "RGN_MAX",
  "VK_CONVERT",
  "WM_NCMBUTTONDOWN",
  "SW_SHOWNORMAL",
  "PBM_STEPIT",
  "TTDT_AUTOPOP",
  "TPM_LEFTBUTTON",
  "OBM_BTNCORNERS",
  "IDC_HSPLIT",
  "SC_KEYMENU",
  "WM_WTSSESSION_CHANGE",
  "TBSTYLE_BUTTON",
  "GW_HWNDNEXT",
  "OBM_REDUCED",
  "DFCS_BUTTONRADIOMASK",
  "CSIDL_COMMON_OEM_LINKS",
  "NM_KEYDOWN",
  "EN_ALIGN_RTL_EC",
  "WS_DISABLED",
  "DFCS_INACTIVE",
  "MB_ICONWARNING",
  "VK_F",
  "WS_MAXIMIZEBOX",
  "EN_OBJECTPOSITIONS",
  "VK_0",
  "VK_BROWSER_FAVORITES",
  "WM_EXITSIZEMOVE",
  "WM_DESTROY",
  "NULL_BRUSH",
  "HDS_HOTTRACK",
  "DFCS_CAPTIONHELP",
  "WM_KEYDOWN",
  "LBS_NOREDRAW",
  "WM_HELP",
  "SM_REMOTECONTROL",
  "CSIDL_MYMUSIC",
  "LR_COPYRETURNORG",
  "MB_ICONSTOP",
  "DLGC_WANTCHARS",
  "TTN_POP",
  "MA_NOACTIVATEANDEAT",
  "TBSTYLE_EX_DRAWDDARROWS",
  "ES_AUTOVSCROLL",
  "WM_KEYFIRST",
  "NOTSRCERASE",
  "WS_POPUPWINDOW",
  "VK_F7",
  "SRCAND",
  "ES_LEFT",
  "VK_F13",
  "WS_TABSTOP",
  "CBN_EDITUPDATE",
  "PATPAINT",
  "WM_WINDOWPOSCHANGING",
  "LVS_EX_INFOTIP",
  "SC_MOUSEMENU",
  "BN_UNPUSHED",
  "NM_DBLCLK",
  "WM_QUERYOPEN",
  "IMAGE_ENHMETAFILE",
  "MF_SEPARATOR",
  "CDDS_ITEMPOSTPAINT",
  "SM_SHOWSOUNDS",
  "IDYES",
  "VK_OEM_2",
  "LBN_ERRSPACE",
  "HDS_FILTERBAR",
  "RGN_DIFF",
  "OBM_UPARROWD",
  "CBN_SELENDOK",
  "ILD_BLEND",
  "LVS_NOCOLUMNHEADER",
  "COLOR_INACTIVECAPTION",
  "CB_SELECTSTRING",
  "WM_MDIGETACTIVE",
  "VK_BACK",
  "LB_DELETESTRING",
  "SC_CLOSE",
  "VK_VOLUME_MUTE",
  "SM_CYMENUCHECK",
  "VK_UP",
  "TVGN_CHILD",
  "CSIDL_PRINTHOOD",
  "TTM_SETTOOLINFO",
  "VK_OEM_102",
  "CS_IME",
  "CB_FINDSTRING",
  "TBSTYLE_GROUP",
  "SE_ERR_DDEBUSY",
  "VK_SUBTRACT",
  "CSIDL_SYSTEM",
  "PS_INSIDEFRAME",
  "VK_OEM_JUMP",
  "CDDS_POSTERASE",
  "LB_RESETCONTENT",
  "SM_CYHSCROLL",
  "WM_COMMAND",
  "GWL_HINSTANCE",
  "SE_ERR_DLLNOTFOUND",
  "CDDS_ITEM",
  "OBM_CHECK",
  "DFCS_FLAT",
  "PS_GEOMETRIC",
  "VK_RIGHT",
  "BTNS_DROPDOWN",
  "LVSIL_NORMAL",
  "MF_MENUBARBREAK",
  "LBS_NODATA",
  "WM_MBUTTONDOWN",
  "SM_CXICONSPACING",
  "OBJ_METADC",
  "GCL_CBCLSEXTRA",
  "SIZE_MAXIMIZED",
  "ILD_OVERLAYMASK",
  "MB_DEFBUTTON3",
  "WM_UNICHAR",
  "BS_MULTILINE",
  "CSIDL_RESOURCES",
  "VK_OEM_PA2",
  "WM_TABLET_FIRST",
  "DS_SYSMODAL",
  "MF_DELETE",
  "WS_EX_WINDOWEDGE",
  "BM_GETIMAGE",
  "COLOR_3DHIGHLIGHT",
  "TBTS_LEFT",
  "WM_MDINEXT",
  "LR_LOADFROMFILE",
  "EDGE_ETCHED",
  "BF_DIAGONAL_ENDBOTTOMLEFT",
  "ENM_PROTECTED",
  "BS_TYPEMASK",
  "TA_RTLREADING",
  "HTZOOM",
  "TBSTATE_MARKED",
  "VK_HOME",
  "CSIDL_FLAG_PER_USER_INIT",
  "ES_MULTILINE",
  "ODT_TAB",
  "LB_SETITEMDATA",
  "CBN_CLOSEUP",
  "VK_MEDIA_NEXT_TRACK",
  "EM_SETLIMITTEXT",
  "SC_ICON",
  "BS_BOTTOM",
  "TTM_TRACKPOSITION",
  "CBN_KILLFOCUS",
  "CBN_ERRSPACE",
  "MF_HELP",
  "WA_CLICKACTIVE",
  "PS_DASH",
  "EN_DROPFILES",
  "WM_ACTIVATEAPP",
  "ODS_DEFAULT",
  "VK_OEM_6",
  "SBM_SETPOS",
  "SM_CXDRAG",
  "EN_ALIGNRTL",
  "WM_MOUSEACTIVATE",
  "LBN_DBLCLK",
  "VK_V",
  "BF_RECT",
  "WM_TABLET_LAST",
  "SM_CXSIZEFRAME",
  "VK_L",
  "BTNS_WHOLEDROPDOWN",
  "SM_CXFULLSCREEN",
  "VK_OEM_1",
  "GCL_HBRBACKGROUND",
  "LB_GETANCHORINDEX",
  "WM_NCRBUTTONDBLCLK",
  "CF_RIFF",
  "COLOR_MENUBAR",
  "TTM_DELTOOL",
  "CBN_SELENDCANCEL",
  "CSIDL_SENDTO",
  "LVS_EX_SNAPTOGRID",
  "VK_HELP",
  "VK_5",
  "OBM_CLOSE",
  "VTA_TOP",
  "HTHSCROLL",
  "DS_NOFAILCREATE",
  "IDB_HIST_LARGE_COLOR",
  "CLR_NONE",
  "LB_GETCURSEL",
  "LR_LOADTRANSPARENT",
  "TVGN_DROPHILITE",
  "SM_CXFIXEDFRAME",
  "CS_PARENTDC",
  "WM_QUERYDRAGICON",
  "HTVSCROLL",
  "EN_DRAGDROPDONE",
  "SE_ERR_ACCESSDENIED",
  "TME_CANCEL",
  "WM_CLOSE",
  "MCSC_TRAILINGTEXT",
  "CP_ACP",
  "MCS_NOTODAYCIRCLE",
  "BLACKONWHITE",
  "SBS_SIZEGRIP",
  "SC_MAXIMIZE",
  "LBS_MULTICOLUMN",
  "TTM_GETTOOLCOUNT",
  "CF_HDROP",
  "PBM_DELTAPOS",
  "WM_IME_NOTIFY",
  "SW_SHOWDEFAULT",
  "CBS_NOINTEGRALHEIGHT",
  "WM_MOUSEWHEEL",
  "WM_MBUTTONDBLCLK",
  "COLOR_BTNHIGHLIGHT",
  "SE_ERR_FNF",
  "TBSTYLE_CUSTOMERASE",
  "DS_3DLOOK",
  "TTM_UPDATETIPTEXT",
  "TTM_RELAYEVENT",
  "OBJ_COLORSPACE",
  "LB_SETTABSTOPS",
  "WM_DISPLAYCHANGE",
  "CB_SETHORIZONTALEXTENT",
  "EM_SETHANDLE",
  "COLOR_MENUHILIGHT",
  "MF_MENUBREAK",
  "CB_GETEXTENDEDUI",
  "VK_NUMPAD5",
  "HTBOTTOMLEFT",
  "ACN_START",
  "VK_LBUTTON",
  "SWP_FRAMECHANGED",
  "MF_BYCOMMAND",
  "ODT_HEADER",
  "GWL_HWNDPARENT",
  "OCR_SIZEALL",
  "SB_LINERIGHT",
  "CF_OWNERDISPLAY",
  "COLOR_WINDOWTEXT",
  "IDI_QUESTION",
  "VK_MBUTTON",
  "VK_SPACE",
  "COLOR_HIGHLIGHT",
  "CBN_DROPDOWN",
  "WM_PALETTECHANGED",
  "WS_EX_APPWINDOW",
  "DLGC_WANTARROWS",
  "OCR_SIZENWSE",
  "LTGRAY_BRUSH",
  "EN_OLEOPFAILED",
  "BS_DIBPATTERN",
  "ODS_GRAYED",
  "CBES_EX_NOEDITIMAGEINDENT",
  "BS_NOTIFY",
  "CBS_SIMPLE",
  "ODS_SELECTED",
  "BM_SETCHECK",
  "CS_DBLCLKS",
  "DS_CONTEXTHELP",
  "HTTRANSPARENT",
  "SB_LEFT",
  "SC_PREVWINDOW",
  "MCSC_BACKGROUND",
  "LB_GETLOCALE",
  "VK_CONTROL",
  "LB_SETITEMHEIGHT",
  "WS_EX_TOPMOST",
  "CB_GETDROPPEDCONTROLRECT",
  "OBM_UPARROWI",
  "VK_EREOF",
};
#define stringpool ((const LPSTR) &stringpool_contents)

/* constants lookup table structures */
struct const_entry {
    USHORT offset;  /* offset into the string table */
    USHORT flags;   /* flags: F_IV or F_UV */
    LONG   value;   /* constants value */
};
typedef struct const_entry const_entry;

/* falags values */
#define F_IV 0     /* treat value as signed */
#define F_UV 1     /* treat value as unsigned */

/* constants lookup table */
static const const_entry const_table[] = {
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str0, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1, F_IV, (LONG)271L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2, F_IV, (LONG)172L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str3, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str4, F_IV, (LONG)2097152L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str5, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str6, F_IV, (LONG)84L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str7, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str8, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str9, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str10, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str11, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str12, F_IV, (LONG)188L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str13, F_IV, (LONG)525L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str14, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str15, F_IV, (LONG)33554432L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str16, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str17, F_IV, (LONG)15728673L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str18, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str19, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str20, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str21, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str22, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str23, F_IV, (LONG)129L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str24, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str25, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str26, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str27, F_IV, (LONG)1039L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str28, F_IV, (LONG)32517L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str29, F_IV, (LONG)409L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str30, F_IV, (LONG)32649L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str31, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str32, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str33, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str34, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str35, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str36, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str37, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str38, F_UV, (LONG)2147483648UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str39, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str40, F_IV, (LONG)32643L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str41, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str42, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str43, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str44, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str45, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str46, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str47, F_IV, (LONG)134L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str48, F_IV, (LONG)564L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str49, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str50, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str51, F_IV, (LONG)31L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str52, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str53, F_IV, (LONG)63L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str54, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str55, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str56, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str57, F_IV, (LONG)246L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str58, F_IV, (LONG)32739L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str59, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str60, F_IV, (LONG)209L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str61, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str62, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str63, F_IV, (LONG)794L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str64, F_IV, (LONG)407L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str65, F_IV, (LONG)1030L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str66, F_IV, (LONG)385L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str67, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str68, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str69, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str70, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str71, F_IV, (LONG)41L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str72, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str73, F_IV, (LONG)3840L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str74, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str75, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str76, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str77, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str78, F_IV, (LONG)433L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str79, F_IV, (LONG)13565952L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str80, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str81, F_IV, (LONG)87L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str82, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str83, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str84, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str85, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str86, F_IV, (LONG)61808L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str87, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str88, F_IV, (LONG)215L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str89, F_IV, (LONG)12583114L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str90, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str91, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str92, F_IV, (LONG)672L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str93, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str94, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str95, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str96, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str97, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str98, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str99, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str100, F_IV, (LONG)32514L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str101, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str102, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str103, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str104, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str105, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str106, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str107, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str108, F_IV, (LONG)-20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str109, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str110, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str111, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str112, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str113, F_IV, (LONG)434L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str114, F_IV, (LONG)775L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str115, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str116, F_IV, (LONG)287L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str117, F_UV, (LONG)2147483648UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str118, F_IV, (LONG)1033L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str119, F_IV, (LONG)89L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str120, F_IV, (LONG)-32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str121, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str122, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str123, F_IV, (LONG)397L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str124, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str125, F_IV, (LONG)189L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str126, F_IV, (LONG)8388608L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str127, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str128, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str129, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str130, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str131, F_IV, (LONG)22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str132, F_IV, (LONG)169L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str133, F_IV, (LONG)328L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str134, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str135, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str136, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str137, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str138, F_IV, (LONG)61504L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str139, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str140, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str141, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str142, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str143, F_IV, (LONG)199L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str144, F_IV, (LONG)32738L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str145, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str146, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str147, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str148, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str149, F_IV, (LONG)61760L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str150, F_IV, (LONG)61744L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str151, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str152, F_IV, (LONG)61568L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str153, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str154, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str155, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str156, F_IV, (LONG)769L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str157, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str158, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str159, F_IV, (LONG)793L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str160, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str161, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str162, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str163, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str164, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str165, F_IV, (LONG)39L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str166, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str167, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str168, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str169, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str170, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str171, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str172, F_IV, (LONG)142L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str173, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str174, F_IV, (LONG)61712L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str175, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str176, F_IV, (LONG)179L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str177, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str178, F_IV, (LONG)-12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str179, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str180, F_IV, (LONG)45L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str181, F_IV, (LONG)32744L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str182, F_IV, (LONG)1043L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str183, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str184, F_IV, (LONG)34L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str185, F_IV, (LONG)123L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str186, F_IV, (LONG)520L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str187, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str188, F_IV, (LONG)1044L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str189, F_IV, (LONG)547L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str190, F_IV, (LONG)208L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str191, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str192, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str193, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str194, F_IV, (LONG)244L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str195, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str196, F_IV, (LONG)325L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str197, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str198, F_IV, (LONG)1035L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str199, F_IV, (LONG)346L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str200, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str201, F_IV, (LONG)424L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str202, F_IV, (LONG)226L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str203, F_IV, (LONG)1028L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str204, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str205, F_IV, (LONG)411L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str206, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str207, F_IV, (LONG)1031L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str208, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str209, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str210, F_IV, (LONG)187L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str211, F_IV, (LONG)331L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str212, F_IV, (LONG)135L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str213, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str214, F_IV, (LONG)147L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str215, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str216, F_IV, (LONG)4194304L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str217, F_IV, (LONG)257L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str218, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str219, F_IV, (LONG)-5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str220, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str221, F_IV, (LONG)5635L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str222, F_IV, (LONG)22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str223, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str224, F_IV, (LONG)536870912L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str225, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str226, F_IV, (LONG)239L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str227, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str228, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str229, F_IV, (LONG)1806L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str230, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str231, F_IV, (LONG)779L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str232, F_IV, (LONG)102L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str233, F_IV, (LONG)75L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str234, F_IV, (LONG)1055L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str235, F_IV, (LONG)1798L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str236, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str237, F_IV, (LONG)768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str238, F_IV, (LONG)41L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str239, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str240, F_IV, (LONG)50L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str241, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str242, F_IV, (LONG)515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str243, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str244, F_IV, (LONG)198L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str245, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str246, F_IV, (LONG)1035L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str247, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str248, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str249, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str250, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str251, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str252, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str253, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str254, F_IV, (LONG)72L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str255, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str256, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str257, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str258, F_IV, (LONG)262L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str259, F_IV, (LONG)42L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str260, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str261, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str262, F_IV, (LONG)1792L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str263, F_IV, (LONG)91L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str264, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str265, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str266, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str267, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str268, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str269, F_IV, (LONG)162L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str270, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str271, F_IV, (LONG)275L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str272, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str273, F_IV, (LONG)32649L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str274, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str275, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str276, F_IV, (LONG)222L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str277, F_IV, (LONG)32512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str278, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str279, F_IV, (LONG)32646L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str280, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str281, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str282, F_IV, (LONG)322L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str283, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str284, F_IV, (LONG)42L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str285, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str286, F_IV, (LONG)93L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str287, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str288, F_IV, (LONG)65000L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str289, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str290, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str291, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str292, F_IV, (LONG)792L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str293, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str294, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str295, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str296, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str297, F_IV, (LONG)214L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str298, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str299, F_IV, (LONG)349L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str300, F_IV, (LONG)1034L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str301, F_IV, (LONG)784L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str302, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str303, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str304, F_IV, (LONG)56L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str305, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str306, F_IV, (LONG)72L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str307, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str308, F_IV, (LONG)104L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str309, F_IV, (LONG)130L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str310, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str311, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str312, F_IV, (LONG)197L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str313, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str314, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str315, F_IV, (LONG)81L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str316, F_IV, (LONG)47L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str317, F_IV, (LONG)172L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str318, F_IV, (LONG)104L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str319, F_IV, (LONG)49L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str320, F_IV, (LONG)100L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str321, F_IV, (LONG)212L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str322, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str323, F_IV, (LONG)69L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str324, F_IV, (LONG)296L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str325, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str326, F_IV, (LONG)289L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str327, F_IV, (LONG)546L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str328, F_IV, (LONG)675L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str329, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str330, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str331, F_IV, (LONG)223L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str332, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str333, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str334, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str335, F_IV, (LONG)340L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str336, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str337, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str338, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str339, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str340, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str341, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str342, F_IV, (LONG)242L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str343, F_IV, (LONG)75L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str344, F_IV, (LONG)129L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str345, F_IV, (LONG)233L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str346, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str347, F_IV, (LONG)59L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str348, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str349, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str350, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str351, F_IV, (LONG)115L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str352, F_IV, (LONG)145L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str353, F_IV, (LONG)1799L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str354, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str355, F_IV, (LONG)272L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str356, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str357, F_IV, (LONG)107L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str358, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str359, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str360, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str361, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str362, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str363, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str364, F_IV, (LONG)131L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str365, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str366, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str367, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str368, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str369, F_IV, (LONG)674L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str370, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str371, F_IV, (LONG)1053L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str372, F_IV, (LONG)271L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str373, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str374, F_IV, (LONG)287L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str375, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str376, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str377, F_IV, (LONG)136L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str378, F_IV, (LONG)1125L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str379, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str380, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str381, F_IV, (LONG)288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str382, F_IV, (LONG)57L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str383, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str384, F_IV, (LONG)270L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str385, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str386, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str387, F_IV, (LONG)1038L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str388, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str389, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str390, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str391, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str392, F_IV, (LONG)863L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str393, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str394, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str395, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str396, F_IV, (LONG)82L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str397, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str398, F_IV, (LONG)31L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str399, F_IV, (LONG)395L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str400, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str401, F_IV, (LONG)73L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str402, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str403, F_IV, (LONG)32745L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str404, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str405, F_IV, (LONG)238L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str406, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str407, F_IV, (LONG)1126L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str408, F_IV, (LONG)213L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str409, F_IV, (LONG)61L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str410, F_IV, (LONG)396L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str411, F_IV, (LONG)178L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str412, F_IV, (LONG)33L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str413, F_IV, (LONG)61L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str414, F_IV, (LONG)90L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str415, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str416, F_IV, (LONG)32514L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str417, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str418, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str419, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str420, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str421, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str422, F_IV, (LONG)245L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str423, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str424, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str425, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str426, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str427, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str428, F_IV, (LONG)181L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str429, F_IV, (LONG)51L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str430, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str431, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str432, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str433, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str434, F_IV, (LONG)121L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str435, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str436, F_IV, (LONG)261L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str437, F_IV, (LONG)33L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str438, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str439, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str440, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str441, F_IV, (LONG)390L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str442, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str443, F_IV, (LONG)146L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str444, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str445, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str446, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str447, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str448, F_IV, (LONG)32512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str449, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str450, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str451, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str452, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str453, F_IV, (LONG)8193L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str454, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str455, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str456, F_IV, (LONG)32517L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str457, F_IV, (LONG)645L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str458, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str459, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str460, F_IV, (LONG)61455L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str461, F_IV, (LONG)403L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str462, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str463, F_IV, (LONG)150L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str464, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str465, F_IV, (LONG)5634L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str466, F_IV, (LONG)23L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str467, F_IV, (LONG)417L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str468, F_IV, (LONG)560L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str469, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str470, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str471, F_IV, (LONG)163L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str472, F_IV, (LONG)-20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str473, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str474, F_IV, (LONG)184L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str475, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str476, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str477, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str478, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str479, F_IV, (LONG)71L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str480, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str481, F_IV, (LONG)778L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str482, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str483, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str484, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str485, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str486, F_IV, (LONG)337L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str487, F_IV, (LONG)42L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str488, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str489, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str490, F_IV, (LONG)59L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str491, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str492, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str493, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str494, F_IV, (LONG)167L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str495, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str496, F_IV, (LONG)1032L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str497, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str498, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str499, F_IV, (LONG)786L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str500, F_IV, (LONG)1793L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str501, F_IV, (LONG)425L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str502, F_IV, (LONG)132L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str503, F_IV, (LONG)57L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str504, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str505, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str506, F_IV, (LONG)123L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str507, F_IV, (LONG)-22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str508, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str509, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str510, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str511, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str512, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str513, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str514, F_IV, (LONG)54L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str515, F_IV, (LONG)518L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str516, F_IV, (LONG)174L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str517, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str518, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str519, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str520, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str521, F_IV, (LONG)15597702L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str522, F_IV, (LONG)89L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str523, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str524, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str525, F_UV, (LONG)4294967295UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str526, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str527, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str528, F_IV, (LONG)306L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str529, F_IV, (LONG)250L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str530, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str531, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str532, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str533, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str534, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str535, F_IV, (LONG)131L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str536, F_IV, (LONG)45L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str537, F_IV, (LONG)644L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str538, F_IV, (LONG)61440L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str539, F_IV, (LONG)61440L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str540, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str541, F_IV, (LONG)240L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str542, F_IV, (LONG)227L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str543, F_IV, (LONG)57L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str544, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str545, F_IV, (LONG)1051L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str546, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str547, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str548, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str549, F_IV, (LONG)34L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str550, F_IV, (LONG)1794L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str551, F_IV, (LONG)55L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str552, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str553, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str554, F_IV, (LONG)31L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str555, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str556, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str557, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str558, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str559, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str560, F_IV, (LONG)74L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str561, F_IV, (LONG)1073741824L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str562, F_IV, (LONG)324L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str563, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str564, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str565, F_IV, (LONG)401L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str566, F_IV, (LONG)52L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str567, F_IV, (LONG)1046L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str568, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str569, F_IV, (LONG)186L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str570, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str571, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str572, F_IV, (LONG)70L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str573, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str574, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str575, F_IV, (LONG)260L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str576, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str577, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str578, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str579, F_IV, (LONG)205L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str580, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str581, F_IV, (LONG)231L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str582, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str583, F_IV, (LONG)372L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str584, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str585, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str586, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str587, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str588, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str589, F_IV, (LONG)399L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str590, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str591, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str592, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str593, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str594, F_IV, (LONG)35L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str595, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str596, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str597, F_IV, (LONG)309L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str598, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str599, F_IV, (LONG)3840L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str600, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str601, F_IV, (LONG)25L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str602, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str603, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str604, F_IV, (LONG)90L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str605, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str606, F_IV, (LONG)190L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str607, F_IV, (LONG)74L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str608, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str609, F_IV, (LONG)61L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str610, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str611, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str612, F_IV, (LONG)187L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str613, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str614, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str615, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str616, F_IV, (LONG)517L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str617, F_IV, (LONG)911L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str618, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str619, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str620, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str621, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str622, F_IV, (LONG)768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str623, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str624, F_IV, (LONG)111L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str625, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str626, F_IV, (LONG)165L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str627, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str628, F_IV, (LONG)-14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str629, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str630, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str631, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str632, F_IV, (LONG)-26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str633, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str634, F_IV, (LONG)227L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str635, F_IV, (LONG)32650L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str636, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str637, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str638, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str639, F_IV, (LONG)295L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str640, F_IV, (LONG)895L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str641, F_IV, (LONG)203L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str642, F_IV, (LONG)196L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str643, F_IV, (LONG)312L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str644, F_IV, (LONG)133L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str645, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str646, F_IV, (LONG)124L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str647, F_IV, (LONG)34L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str648, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str649, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str650, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str651, F_IV, (LONG)310L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str652, F_IV, (LONG)1800L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str653, F_IV, (LONG)50L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str654, F_IV, (LONG)22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str655, F_IV, (LONG)78L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str656, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str657, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str658, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str659, F_IV, (LONG)32644L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str660, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str661, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str662, F_IV, (LONG)234L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str663, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str664, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str665, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str666, F_IV, (LONG)856L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str667, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str668, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str669, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str670, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str671, F_IV, (LONG)536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str672, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str673, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str674, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str675, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str676, F_IV, (LONG)768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str677, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str678, F_IV, (LONG)65539L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str679, F_IV, (LONG)12582912L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str680, F_IV, (LONG)32761L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str681, F_IV, (LONG)75L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str682, F_IV, (LONG)43L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str683, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str684, F_IV, (LONG)321L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str685, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str686, F_IV, (LONG)182L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str687, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str688, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str689, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str690, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str691, F_IV, (LONG)23L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str692, F_IV, (LONG)110L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str693, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str694, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str695, F_IV, (LONG)116L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str696, F_IV, (LONG)254L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str697, F_IV, (LONG)351L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str698, F_IV, (LONG)146L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str699, F_IV, (LONG)38L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str700, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str701, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str702, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str703, F_IV, (LONG)177L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str704, F_IV, (LONG)125L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str705, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str706, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str707, F_IV, (LONG)1073741824L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str708, F_IV, (LONG)251L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str709, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str710, F_IV, (LONG)53L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str711, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str712, F_IV, (LONG)32734L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str713, F_IV, (LONG)126L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str714, F_IV, (LONG)5633L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str715, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str716, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str717, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str718, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str719, F_IV, (LONG)69L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str720, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str721, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str722, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str723, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str724, F_IV, (LONG)83L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str725, F_IV, (LONG)134217728L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str726, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str727, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str728, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str729, F_IV, (LONG)38L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str730, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str731, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str732, F_IV, (LONG)1048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str733, F_IV, (LONG)105L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str734, F_IV, (LONG)62L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str735, F_IV, (LONG)34L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str736, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str737, F_IV, (LONG)343L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str738, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str739, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str740, F_IV, (LONG)77L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str741, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str742, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str743, F_IV, (LONG)-4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str744, F_IV, (LONG)1026L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str745, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str746, F_IV, (LONG)40L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str747, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str748, F_IV, (LONG)32735L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str749, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str750, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str751, F_IV, (LONG)641L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str752, F_IV, (LONG)308L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str753, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str754, F_IV, (LONG)112L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str755, F_IV, (LONG)84L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str756, F_IV, (LONG)32759L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str757, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str758, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str759, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str760, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str761, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str762, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str763, F_IV, (LONG)1025L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str764, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str765, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str766, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str767, F_IV, (LONG)336L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str768, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str769, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str770, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str771, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str772, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str773, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str774, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str775, F_IV, (LONG)1797L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str776, F_IV, (LONG)127L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str777, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str778, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str779, F_IV, (LONG)45L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str780, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str781, F_IV, (LONG)39L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str782, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str783, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str784, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str785, F_IV, (LONG)36L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str786, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str787, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str788, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str789, F_IV, (LONG)-19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str790, F_IV, (LONG)73L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str791, F_IV, (LONG)290L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str792, F_IV, (LONG)49L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str793, F_IV, (LONG)133L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str794, F_IV, (LONG)1792L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str795, F_IV, (LONG)12255782L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str796, F_IV, (LONG)2097152L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str797, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str798, F_IV, (LONG)242L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str799, F_IV, (LONG)65280L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str800, F_IV, (LONG)341L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str801, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str802, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str803, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str804, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str805, F_IV, (LONG)16777216L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str806, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str807, F_IV, (LONG)404L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str808, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str809, F_IV, (LONG)46L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str810, F_IV, (LONG)353L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str811, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str812, F_IV, (LONG)392L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str813, F_IV, (LONG)23L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str814, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str815, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str816, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str817, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str818, F_IV, (LONG)168L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str819, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str820, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str821, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str822, F_IV, (LONG)33L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str823, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str824, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str825, F_IV, (LONG)108L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str826, F_IV, (LONG)131L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str827, F_IV, (LONG)550L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str828, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str829, F_IV, (LONG)36L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str830, F_IV, (LONG)177L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str831, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str832, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str833, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str834, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str835, F_IV, (LONG)297L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str836, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str837, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str838, F_IV, (LONG)-18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str839, F_IV, (LONG)-8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str840, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str841, F_IV, (LONG)247L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str842, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str843, F_IV, (LONG)3840L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str844, F_IV, (LONG)130L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str845, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str846, F_IV, (LONG)42L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str847, F_IV, (LONG)237L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str848, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str849, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str850, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str851, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str852, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str853, F_IV, (LONG)81L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str854, F_IV, (LONG)96L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str855, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str856, F_IV, (LONG)311L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str857, F_IV, (LONG)66L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str858, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str859, F_IV, (LONG)171L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str860, F_IV, (LONG)204L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str861, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str862, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str863, F_IV, (LONG)65537L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str864, F_IV, (LONG)32651L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str865, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str866, F_IV, (LONG)1056L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str867, F_IV, (LONG)173L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str868, F_IV, (LONG)32648L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str869, F_IV, (LONG)241L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str870, F_IV, (LONG)169L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str871, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str872, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str873, F_IV, (LONG)307L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str874, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str875, F_IV, (LONG)5632L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str876, F_IV, (LONG)8388608L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str877, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str878, F_UV, (LONG)4278190080UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str879, F_IV, (LONG)25L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str880, F_IV, (LONG)352L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str881, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str882, F_IV, (LONG)-7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str883, F_IV, (LONG)243L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str884, F_IV, (LONG)3072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str885, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str886, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str887, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str888, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str889, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str890, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str891, F_IV, (LONG)4194304L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str892, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str893, F_IV, (LONG)51L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str894, F_IV, (LONG)16711778L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str895, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str896, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str897, F_IV, (LONG)768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str898, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str899, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str900, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str901, F_IV, (LONG)134L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str902, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str903, F_IV, (LONG)163L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str904, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str905, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str906, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str907, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str908, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str909, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str910, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str911, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str912, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str913, F_IV, (LONG)31L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str914, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str915, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str916, F_IV, (LONG)415L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str917, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str918, F_IV, (LONG)-24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str919, F_IV, (LONG)291L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str920, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str921, F_IV, (LONG)245L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str922, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str923, F_IV, (LONG)243L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str924, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str925, F_IV, (LONG)1073741824L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str926, F_IV, (LONG)276L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str927, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str928, F_IV, (LONG)61440L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str929, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str930, F_IV, (LONG)1538L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str931, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str932, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str933, F_IV, (LONG)782L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str934, F_IV, (LONG)66L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str935, F_IV, (LONG)347L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str936, F_IV, (LONG)81L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str937, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str938, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str939, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str940, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str941, F_IV, (LONG)183L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str942, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str943, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str944, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str945, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str946, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str947, F_IV, (LONG)44L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str948, F_IV, (LONG)258L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str949, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str950, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str951, F_IV, (LONG)49152L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str952, F_IV, (LONG)43L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str953, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str954, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str955, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str956, F_IV, (LONG)67108864L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str957, F_IV, (LONG)71L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str958, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str959, F_IV, (LONG)164L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str960, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str961, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str962, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str963, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str964, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str965, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str966, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str967, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str968, F_IV, (LONG)252L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str969, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str970, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str971, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str972, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str973, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str974, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str975, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str976, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str977, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str978, F_IV, (LONG)160L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str979, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str980, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str981, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str982, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str983, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str984, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str985, F_IV, (LONG)40L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str986, F_IV, (LONG)55L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str987, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str988, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str989, F_IV, (LONG)144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str990, F_IV, (LONG)551L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str991, F_IV, (LONG)1280L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str992, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str993, F_IV, (LONG)32748L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str994, F_IV, (LONG)544L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str995, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str996, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str997, F_IV, (LONG)1807L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str998, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str999, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1000, F_IV, (LONG)1032L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1001, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1002, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1003, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1004, F_IV, (LONG)791L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1005, F_IV, (LONG)268435456L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1006, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1007, F_IV, (LONG)1054L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1008, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1009, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1010, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1011, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1012, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1013, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1014, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1015, F_IV, (LONG)294L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1016, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1017, F_IV, (LONG)40L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1018, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1019, F_IV, (LONG)41L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1020, F_IV, (LONG)168L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1021, F_IV, (LONG)106L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1022, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1023, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1024, F_IV, (LONG)162L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1025, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1026, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1027, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1028, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1029, F_IV, (LONG)148L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1030, F_IV, (LONG)1045L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1031, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1032, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1033, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1034, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1035, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1036, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1037, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1038, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1039, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1040, F_IV, (LONG)418L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1041, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1042, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1043, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1044, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1045, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1046, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1047, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1048, F_IV, (LONG)536870912L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1049, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1050, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1051, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1052, F_IV, (LONG)44L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1053, F_IV, (LONG)52L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1054, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1055, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1056, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1057, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1058, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1059, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1060, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1061, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1062, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1063, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1064, F_IV, (LONG)405L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1065, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1066, F_IV, (LONG)293L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1067, F_IV, (LONG)78L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1068, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1069, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1070, F_IV, (LONG)531L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1071, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1072, F_IV, (LONG)525L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1073, F_IV, (LONG)46L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1074, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1075, F_IV, (LONG)2097152L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1076, F_IV, (LONG)408L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1077, F_IV, (LONG)46L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1078, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1079, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1080, F_IV, (LONG)-12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1081, F_IV, (LONG)32750L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1082, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1083, F_IV, (LONG)6684742L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1084, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1085, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1086, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1087, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1088, F_IV, (LONG)1281L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1089, F_IV, (LONG)149L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1090, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1091, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1092, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1093, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1094, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1095, F_IV, (LONG)23L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1096, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1097, F_IV, (LONG)-18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1098, F_IV, (LONG)51L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1099, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1100, F_IV, (LONG)-521L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1101, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1102, F_IV, (LONG)278L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1103, F_IV, (LONG)254L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1104, F_IV, (LONG)1124L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1105, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1106, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1107, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1108, F_IV, (LONG)265L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1109, F_IV, (LONG)228L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1110, F_IV, (LONG)643L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1111, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1112, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1113, F_IV, (LONG)65L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1114, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1115, F_IV, (LONG)55L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1116, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1117, F_IV, (LONG)-21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1118, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1119, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1120, F_IV, (LONG)183L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1121, F_IV, (LONG)180L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1122, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1123, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1124, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1125, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1126, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1127, F_IV, (LONG)549L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1128, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1129, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1130, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1131, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1132, F_IV, (LONG)864L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1133, F_IV, (LONG)235L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1134, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1135, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1136, F_IV, (LONG)72L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1137, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1138, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1139, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1140, F_IV, (LONG)189L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1141, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1142, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1143, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1144, F_IV, (LONG)120L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1145, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1146, F_IV, (LONG)132L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1147, F_IV, (LONG)65540L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1148, F_IV, (LONG)88L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1149, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1150, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1151, F_IV, (LONG)57L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1152, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1153, F_IV, (LONG)563L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1154, F_IV, (LONG)1030L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1155, F_IV, (LONG)772L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1156, F_IV, (LONG)61792L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1157, F_IV, (LONG)339L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1158, F_IV, (LONG)532L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1159, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1160, F_IV, (LONG)-8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1161, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1162, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1163, F_IV, (LONG)1537L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1164, F_IV, (LONG)217L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1165, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1166, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1167, F_IV, (LONG)240L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1168, F_IV, (LONG)180L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1169, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1170, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1171, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1172, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1173, F_IV, (LONG)524L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1174, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1175, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1176, F_IV, (LONG)164L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1177, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1178, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1179, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1180, F_IV, (LONG)47L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1181, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1182, F_IV, (LONG)99L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1183, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1184, F_IV, (LONG)1073741824L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1185, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1186, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1187, F_IV, (LONG)1040L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1188, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1189, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1190, F_IV, (LONG)1796L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1191, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1192, F_IV, (LONG)43L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1193, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1194, F_IV, (LONG)45L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1195, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1196, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1197, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1198, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1199, F_IV, (LONG)1049L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1200, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1201, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1202, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1203, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1204, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1205, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1206, F_IV, (LONG)42L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1207, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1208, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1209, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1210, F_IV, (LONG)327L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1211, F_IV, (LONG)255L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1212, F_IV, (LONG)25L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1213, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1214, F_IV, (LONG)32766L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1215, F_IV, (LONG)1805L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1216, F_IV, (LONG)60L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1217, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1218, F_IV, (LONG)391L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1219, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1220, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1221, F_IV, (LONG)320L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1222, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1223, F_IV, (LONG)4194304L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1224, F_IV, (LONG)-14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1225, F_IV, (LONG)1052L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1226, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1227, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1228, F_IV, (LONG)182L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1229, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1230, F_IV, (LONG)84L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1231, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1232, F_IV, (LONG)61776L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1233, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1234, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1235, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1236, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1237, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1238, F_IV, (LONG)79L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1239, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1240, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1241, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1242, F_IV, (LONG)5898313L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1243, F_IV, (LONG)92L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1244, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1245, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1246, F_IV, (LONG)32742L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1247, F_UV, (LONG)2147483648UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1248, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1249, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1250, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1251, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1252, F_IV, (LONG)36L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1253, F_IV, (LONG)220L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1254, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1255, F_IV, (LONG)783L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1256, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1257, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1258, F_IV, (LONG)269L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1259, F_IV, (LONG)61456L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1260, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1261, F_IV, (LONG)201L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1262, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1263, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1264, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1265, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1266, F_IV, (LONG)552L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1267, F_IV, (LONG)384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1268, F_IV, (LONG)-34L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1269, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1270, F_IV, (LONG)119L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1271, F_IV, (LONG)387L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1272, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1273, F_IV, (LONG)421L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1274, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1275, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1276, F_IV, (LONG)323L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1277, F_IV, (LONG)79L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1278, F_IV, (LONG)1050L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1279, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1280, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1281, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1282, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1283, F_IV, (LONG)528L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1284, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1285, F_IV, (LONG)37L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1286, F_IV, (LONG)50L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1287, F_IV, (LONG)200L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1288, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1289, F_IV, (LONG)61552L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1290, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1291, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1292, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1293, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1294, F_IV, (LONG)16777216L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1295, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1296, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1297, F_IV, (LONG)-16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1298, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1299, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1300, F_IV, (LONG)534L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1301, F_IV, (LONG)5637L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1302, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1303, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1304, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1305, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1306, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1307, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1308, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1309, F_IV, (LONG)32650L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1310, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1311, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1312, F_IV, (LONG)247L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1313, F_IV, (LONG)1041L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1314, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1315, F_IV, (LONG)330L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1316, F_IV, (LONG)368L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1317, F_IV, (LONG)225L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1318, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1319, F_IV, (LONG)406L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1320, F_IV, (LONG)210L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1321, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1322, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1323, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1324, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1325, F_IV, (LONG)65001L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1326, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1327, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1328, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1329, F_IV, (LONG)78L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1330, F_IV, (LONG)-16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1331, F_IV, (LONG)87L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1332, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1333, F_IV, (LONG)181L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1334, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1335, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1336, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1337, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1338, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1339, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1340, F_IV, (LONG)13369376L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1341, F_IV, (LONG)896L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1342, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1343, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1344, F_IV, (LONG)230L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1345, F_IV, (LONG)25L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1346, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1347, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1348, F_IV, (LONG)97L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1349, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1350, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1351, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1352, F_IV, (LONG)233L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1353, F_IV, (LONG)780L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1354, F_IV, (LONG)773L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1355, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1356, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1357, F_IV, (LONG)114L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1358, F_IV, (LONG)334L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1359, F_IV, (LONG)777L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1360, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1361, F_IV, (LONG)56L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1362, F_IV, (LONG)85L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1363, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1364, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1365, F_IV, (LONG)225L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1366, F_IV, (LONG)253L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1367, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1368, F_IV, (LONG)47L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1369, F_IV, (LONG)22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1370, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1371, F_IV, (LONG)61728L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1372, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1373, F_IV, (LONG)43L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1374, F_IV, (LONG)37L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1375, F_IV, (LONG)32642L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1376, F_IV, (LONG)513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1377, F_IV, (LONG)1792L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1378, F_IV, (LONG)80L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1379, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1380, F_IV, (LONG)33554432L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1381, F_IV, (LONG)82L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1382, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1383, F_IV, (LONG)33554432L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1384, F_IV, (LONG)35L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1385, F_IV, (LONG)240L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1386, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1387, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1388, F_IV, (LONG)657L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1389, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1390, F_IV, (LONG)76L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1391, F_IV, (LONG)102L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1392, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1393, F_IV, (LONG)190L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1394, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1395, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1396, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1397, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1398, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1399, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1400, F_IV, (LONG)32736L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1401, F_IV, (LONG)160L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1402, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1403, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1404, F_IV, (LONG)355L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1405, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1406, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1407, F_IV, (LONG)135L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1408, F_IV, (LONG)369L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1409, F_IV, (LONG)1028L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1410, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1411, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1412, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1413, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1414, F_IV, (LONG)179L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1415, F_IV, (LONG)279L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1416, F_IV, (LONG)216L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1417, F_IV, (LONG)32741L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1418, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1419, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1420, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1421, F_IV, (LONG)127L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1422, F_IV, (LONG)371L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1423, F_IV, (LONG)5570569L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1424, F_IV, (LONG)54L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1425, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1426, F_IV, (LONG)77L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1427, F_IV, (LONG)44L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1428, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1429, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1430, F_IV, (LONG)-17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1431, F_IV, (LONG)32751L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1432, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1433, F_IV, (LONG)423L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1434, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1435, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1436, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1437, F_IV, (LONG)61824L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1438, F_IV, (LONG)1048576L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1439, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1440, F_IV, (LONG)80L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1441, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1442, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1443, F_IV, (LONG)32753L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1444, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1445, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1446, F_IV, (LONG)35L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1447, F_IV, (LONG)80L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1448, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1449, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1450, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1451, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1452, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1453, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1454, F_IV, (LONG)32749L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1455, F_IV, (LONG)1047L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1456, F_IV, (LONG)274L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1457, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1458, F_IV, (LONG)98L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1459, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1460, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1461, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1462, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1463, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1464, F_IV, (LONG)-12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1465, F_IV, (LONG)113L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1466, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1467, F_IV, (LONG)24L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1468, F_IV, (LONG)129L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1469, F_IV, (LONG)370L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1470, F_IV, (LONG)781L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1471, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1472, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1473, F_IV, (LONG)-16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1474, F_IV, (LONG)33L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1475, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1476, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1477, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1478, F_IV, (LONG)235L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1479, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1480, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1481, F_IV, (LONG)248L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1482, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1483, F_IV, (LONG)32747L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1484, F_IV, (LONG)514L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1485, F_IV, (LONG)178L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1486, F_IV, (LONG)31L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1487, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1488, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1489, F_IV, (LONG)774L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1490, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1491, F_IV, (LONG)117L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1492, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1493, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1494, F_IV, (LONG)74L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1495, F_IV, (LONG)412L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1496, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1497, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1498, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1499, F_IV, (LONG)5636L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1500, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1501, F_IV, (LONG)67L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1502, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1503, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1504, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1505, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1506, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1507, F_IV, (LONG)40L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1508, F_IV, (LONG)228L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1509, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1510, F_IV, (LONG)35L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1511, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1512, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1513, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1514, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1515, F_IV, (LONG)776L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1516, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1517, F_IV, (LONG)646L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1518, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1519, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1520, F_IV, (LONG)131072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1521, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1522, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1523, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1524, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1525, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1526, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1527, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1528, F_IV, (LONG)32512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1529, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1530, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1531, F_IV, (LONG)398L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1532, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1533, F_IV, (LONG)21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1534, F_IV, (LONG)-520L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1535, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1536, F_IV, (LONG)3342344L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1537, F_IV, (LONG)1808L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1538, F_IV, (LONG)32513L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1539, F_IV, (LONG)1803L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1540, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1541, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1542, F_IV, (LONG)983040L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1543, F_IV, (LONG)277L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1544, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1545, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1546, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1547, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1548, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1549, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1550, F_IV, (LONG)122L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1551, F_IV, (LONG)3072L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1552, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1553, F_IV, (LONG)12288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1554, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1555, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1556, F_IV, (LONG)161L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1557, F_IV, (LONG)61488L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1558, F_IV, (LONG)64512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1559, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1560, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1561, F_UV, (LONG)4278190080UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1562, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1563, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1564, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1565, F_IV, (LONG)-520L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1566, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1567, F_IV, (LONG)44L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1568, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1569, F_IV, (LONG)85L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1570, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1571, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1572, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1573, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1574, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1575, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1576, F_IV, (LONG)88L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1577, F_IV, (LONG)13565952L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1578, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1579, F_IV, (LONG)533L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1580, F_IV, (LONG)166L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1581, F_IV, (LONG)326L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1582, F_IV, (LONG)219L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1583, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1584, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1585, F_IV, (LONG)39L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1586, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1587, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1588, F_IV, (LONG)32516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1589, F_IV, (LONG)4457256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1590, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1591, F_IV, (LONG)170L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1592, F_IV, (LONG)32644L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1593, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1594, F_IV, (LONG)54L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1595, F_IV, (LONG)516L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1596, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1597, F_IV, (LONG)356L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1598, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1599, F_IV, (LONG)329L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1600, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1601, F_IV, (LONG)656L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1602, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1603, F_IV, (LONG)345L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1604, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1605, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1606, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1607, F_IV, (LONG)244L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1608, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1609, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1610, F_IV, (LONG)1025L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1611, F_IV, (LONG)67L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1612, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1613, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1614, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1615, F_IV, (LONG)67108864L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1616, F_UV, (LONG)4294967295UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1617, F_IV, (LONG)49L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1618, F_IV, (LONG)-4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1619, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1620, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1621, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1622, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1623, F_IV, (LONG)229L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1624, F_IV, (LONG)68L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1625, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1626, F_IV, (LONG)770L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1627, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1628, F_IV, (LONG)4096L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1629, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1630, F_IV, (LONG)83L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1631, F_IV, (LONG)530L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1632, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1633, F_IV, (LONG)18L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1634, F_IV, (LONG)134217728L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1635, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1636, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1637, F_IV, (LONG)414L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1638, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1639, F_IV, (LONG)53L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1640, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1641, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1642, F_IV, (LONG)561L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1643, F_IV, (LONG)82L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1644, F_IV, (LONG)-6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1645, F_IV, (LONG)125L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1646, F_IV, (LONG)165L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1647, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1648, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1649, F_IV, (LONG)1027L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1650, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1651, F_IV, (LONG)49L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1652, F_IV, (LONG)32752L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1653, F_IV, (LONG)393L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1654, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1655, F_IV, (LONG)767L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1656, F_IV, (LONG)32515L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1657, F_IV, (LONG)32512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1658, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1659, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1660, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1661, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1662, F_IV, (LONG)103L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1663, F_IV, (LONG)176L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1664, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1665, F_IV, (LONG)95L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1666, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1667, F_IV, (LONG)26L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1668, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1669, F_IV, (LONG)8194L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1670, F_IV, (LONG)206L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1671, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1672, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1673, F_IV, (LONG)22L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1674, F_IV, (LONG)32643L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1675, F_IV, (LONG)32514L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1676, F_IV, (LONG)394L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1677, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1678, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1679, F_IV, (LONG)32768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1680, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1681, F_IV, (LONG)192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1682, F_IV, (LONG)545L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1683, F_IV, (LONG)58L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1684, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1685, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1686, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1687, F_IV, (LONG)529L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1688, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1689, F_IV, (LONG)32648L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1690, F_IV, (LONG)259L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1691, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1692, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1693, F_IV, (LONG)230L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1694, F_IV, (LONG)-21L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1695, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1696, F_IV, (LONG)32740L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1697, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1698, F_IV, (LONG)68L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1699, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1700, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1701, F_IV, (LONG)71L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1702, F_IV, (LONG)207L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1703, F_IV, (LONG)12L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1704, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1705, F_IV, (LONG)161L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1706, F_IV, (LONG)771L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1707, F_IV, (LONG)3145731L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1708, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1709, F_IV, (LONG)185L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1710, F_IV, (LONG)389L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1711, F_IV, (LONG)102L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1712, F_IV, (LONG)263L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1713, F_IV, (LONG)-13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1714, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1715, F_IV, (LONG)344L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1716, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1717, F_IV, (LONG)130L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1718, F_IV, (LONG)61472L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1719, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1720, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1721, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1722, F_IV, (LONG)32645L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1723, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1724, F_IV, (LONG)86L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1725, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1726, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1727, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1728, F_IV, (LONG)348L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1729, F_IV, (LONG)335L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1730, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1731, F_IV, (LONG)193L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1732, F_IV, (LONG)400L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1733, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1734, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1735, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1736, F_IV, (LONG)65L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1737, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1738, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1739, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1740, F_IV, (LONG)768L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1741, F_IV, (LONG)537L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1742, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1743, F_IV, (LONG)46L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1744, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1745, F_IV, (LONG)194L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1746, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1747, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1748, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1749, F_IV, (LONG)32000L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1750, F_IV, (LONG)32645L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1751, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1752, F_IV, (LONG)211L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1753, F_IV, (LONG)523L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1754, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1755, F_IV, (LONG)673L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1756, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1757, F_IV, (LONG)648L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1758, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1759, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1760, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1761, F_IV, (LONG)175L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1762, F_IV, (LONG)292L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1763, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1764, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1765, F_IV, (LONG)167L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1766, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1767, F_IV, (LONG)1029L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1768, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1769, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1770, F_IV, (LONG)32758L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1771, F_IV, (LONG)103L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1772, F_IV, (LONG)61696L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1773, F_IV, (LONG)689L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1774, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1775, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1776, F_IV, (LONG)32746L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1777, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1778, F_IV, (LONG)58L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1779, F_IV, (LONG)-15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1780, F_IV, (LONG)1793L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1781, F_IV, (LONG)134217728L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1782, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1783, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1784, F_IV, (LONG)70L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1785, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1786, F_IV, (LONG)1802L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1787, F_IV, (LONG)48L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1788, F_IV, (LONG)171L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1789, F_IV, (LONG)562L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1790, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1791, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1792, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1793, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1794, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1795, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1796, F_IV, (LONG)83L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1797, F_IV, (LONG)8193L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1798, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1799, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1800, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1801, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1802, F_IV, (LONG)-522L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1803, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1804, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1805, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1806, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1807, F_IV, (LONG)1114278L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1808, F_UV, (LONG)2156396544UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1809, F_IV, (LONG)118L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1810, F_IV, (LONG)8913094L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1811, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1812, F_IV, (LONG)124L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1813, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1814, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1815, F_IV, (LONG)16452105L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1816, F_IV, (LONG)70L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1817, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1818, F_IV, (LONG)61584L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1819, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1820, F_IV, (LONG)-3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1821, F_IV, (LONG)19L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1822, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1823, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1824, F_IV, (LONG)65538L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1825, F_IV, (LONG)70L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1826, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1827, F_IV, (LONG)191L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1828, F_IV, (LONG)-2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1829, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1830, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1831, F_IV, (LONG)32743L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1832, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1833, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1834, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1835, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1836, F_IV, (LONG)333L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1837, F_IV, (LONG)553L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1838, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1839, F_IV, (LONG)386L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1840, F_IV, (LONG)61536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1841, F_IV, (LONG)173L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1842, F_IV, (LONG)72L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1843, F_IV, (LONG)38L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1844, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1845, F_IV, (LONG)27L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1846, F_IV, (LONG)1033L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1847, F_IV, (LONG)226L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1848, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1849, F_IV, (LONG)332L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1850, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1851, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1852, F_IV, (LONG)109L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1853, F_IV, (LONG)37L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1854, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1855, F_IV, (LONG)234L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1856, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1857, F_IV, (LONG)388L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1858, F_IV, (LONG)3L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1859, F_IV, (LONG)273L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1860, F_IV, (LONG)-6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1861, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1862, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1863, F_IV, (LONG)32760L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1864, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1865, F_IV, (LONG)65536L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1866, F_IV, (LONG)39L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1867, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1868, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1869, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1870, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1871, F_IV, (LONG)519L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1872, F_IV, (LONG)38L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1873, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1874, F_IV, (LONG)-20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1875, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1876, F_IV, (LONG)3840L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1877, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1878, F_IV, (LONG)265L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1879, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1880, F_IV, (LONG)56L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1881, F_IV, (LONG)236L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1882, F_IV, (LONG)704L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1883, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1884, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1885, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1886, F_IV, (LONG)246L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1887, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1888, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1889, F_IV, (LONG)548L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1890, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1891, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1892, F_IV, (LONG)25L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1893, F_IV, (LONG)2097152L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1894, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1895, F_IV, (LONG)256L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1896, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1897, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1898, F_IV, (LONG)36L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1899, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1900, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1901, F_IV, (LONG)101L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1902, F_IV, (LONG)410L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1903, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1904, F_IV, (LONG)176L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1905, F_IV, (LONG)197L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1906, F_IV, (LONG)61472L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1907, F_IV, (LONG)2048L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1908, F_IV, (LONG)1042L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1909, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1910, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1911, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1912, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1913, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1914, F_IV, (LONG)1795L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1915, F_IV, (LONG)28L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1916, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1917, F_IV, (LONG)221L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1918, F_IV, (LONG)224L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1919, F_IV, (LONG)68L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1920, F_IV, (LONG)1809L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1921, F_IV, (LONG)33L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1922, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1923, F_IV, (LONG)86L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1924, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1925, F_IV, (LONG)735L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1926, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1927, F_IV, (LONG)76L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1928, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1929, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1930, F_IV, (LONG)186L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1931, F_IV, (LONG)-10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1932, F_IV, (LONG)413L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1933, F_IV, (LONG)166L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1934, F_IV, (LONG)11L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1935, F_IV, (LONG)30L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1936, F_IV, (LONG)1029L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1937, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1938, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1939, F_IV, (LONG)524288L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1940, F_IV, (LONG)47L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1941, F_IV, (LONG)53L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1942, F_IV, (LONG)32754L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1943, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1944, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1945, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1946, F_IV, (LONG)9L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1947, F_UV, (LONG)4294967295UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1948, F_IV, (LONG)392L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1949, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1950, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1951, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1952, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1953, F_IV, (LONG)55L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1954, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1955, F_IV, (LONG)1804L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1956, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1957, F_UV, (LONG)2147483648UL},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1958, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1959, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1960, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1961, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1962, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1963, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1964, F_IV, (LONG)61488L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1965, F_IV, (LONG)512L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1966, F_IV, (LONG)1037L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1967, F_IV, (LONG)15L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1968, F_IV, (LONG)1027L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1969, F_IV, (LONG)642L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1970, F_IV, (LONG)10L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1971, F_IV, (LONG)1024L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1972, F_IV, (LONG)522L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1973, F_IV, (LONG)521L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1974, F_IV, (LONG)20L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1975, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1976, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1977, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1978, F_IV, (LONG)1036L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1979, F_IV, (LONG)1031L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1980, F_IV, (LONG)14L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1981, F_IV, (LONG)402L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1982, F_IV, (LONG)126L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1983, F_IV, (LONG)350L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1984, F_IV, (LONG)188L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1985, F_IV, (LONG)29L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1986, F_IV, (LONG)64L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1987, F_IV, (LONG)342L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1988, F_IV, (LONG)101L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1989, F_IV, (LONG)16L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1990, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1991, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1992, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1993, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1994, F_IV, (LONG)100L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1995, F_IV, (LONG)-8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1996, F_IV, (LONG)32646L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1997, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1998, F_IV, (LONG)128L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str1999, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2000, F_IV, (LONG)32514L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2001, F_IV, (LONG)4L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2002, F_IV, (LONG)32L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2003, F_IV, (LONG)13L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2004, F_IV, (LONG)7L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2005, F_IV, (LONG)785L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2006, F_IV, (LONG)262144L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2007, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2008, F_IV, (LONG)32642L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2009, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2010, F_IV, (LONG)1801L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2011, F_IV, (LONG)5L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2012, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2013, F_IV, (LONG)2L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2014, F_IV, (LONG)16384L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2015, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2016, F_IV, (LONG)1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2017, F_IV, (LONG)241L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2018, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2019, F_IV, (LONG)8192L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2020, F_IV, (LONG)-1L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2021, F_IV, (LONG)6L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2022, F_IV, (LONG)61520L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2023, F_IV, (LONG)0L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2024, F_IV, (LONG)422L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2025, F_IV, (LONG)17L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2026, F_IV, (LONG)416L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2027, F_IV, (LONG)8L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2028, F_IV, (LONG)338L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2029, F_IV, (LONG)32737L},
  {(USHORT)(INT_PTR)&((struct stringpool_t *)0)->str2030, F_IV, (LONG)249L},
};

/* lookup function from hash\lookupa.c */
#define mix(a,b,c) \
{ \
  a -= b; a -= c; a ^= (c>>13); \
  b -= c; b -= a; b ^= (a<<8); \
  c -= a; c -= b; c ^= (b>>13); \
  a -= b; a -= c; a ^= (c>>12);  \
  b -= c; b -= a; b ^= (a<<16); \
  c -= a; c -= b; c ^= (b>>5); \
  a -= b; a -= c; a ^= (c>>3);  \
  b -= c; b -= a; b ^= (a<<10); \
  c -= a; c -= b; c ^= (b>>15); \
}

static ULONG lookup(LPSTR k, ULONG length, ULONG level)
{
  ULONG a,b,c,len;

  /* Set up the internal state */
  len = length;
  a = b = 0x9e3779b9;  /* the golden ratio; an arbitrary value */
  c = level;           /* the previous hash value */

  /*---------------------------------------- handle most of the key */
  while (len >= 12) {
    a += (k[0] +((ULONG)k[1]<<8) +((ULONG)k[2]<<16) +((ULONG)k[3]<<24));
    b += (k[4] +((ULONG)k[5]<<8) +((ULONG)k[6]<<16) +((ULONG)k[7]<<24));
    c += (k[8] +((ULONG)k[9]<<8) +((ULONG)k[10]<<16)+((ULONG)k[11]<<24));
    mix(a,b,c);
    k += 12; len -= 12;
  }

  /*------------------------------------- handle the last 11 bytes */
  c += length;
  switch(len) {            /* all the case statements fall through */
    case 11: c+=((ULONG)k[10]<<24);
    case 10: c+=((ULONG)k[9]<<16);
    case 9 : c+=((ULONG)k[8]<<8);
      /* the first byte of c is reserved for the length */
    case 8 : b+=((ULONG)k[7]<<24);
    case 7 : b+=((ULONG)k[6]<<16);
    case 6 : b+=((ULONG)k[5]<<8);
    case 5 : b+=k[4];
    case 4 : a+=((ULONG)k[3]<<24);
    case 3 : a+=((ULONG)k[2]<<16);
    case 2 : a+=((ULONG)k[1]<<8);
    case 1 : a+=k[0];
     /* case 0: nothing left to add */
  }
  mix(a,b,c);
  /*-------------------------------------------- report the result */
  return c;
}

/* the hash function */
static ULONG phash(LPSTR key, STRLEN len)
{
  ULONG val = lookup(key, len, PHASHSALT);
  return((val>>23)^tab[val&0x1ff]);
}
